#!/usr/bin/ruby

#
# ----------------------------------------------------------------------------
# CONFIGURATION
# ----------------------------------------------------------------------------
#

# When checking to see if the job is enabled, or running, what do we look for?
JOB_NAME = 'overnight_search_combo'

# Where are the output files located?
OUTPUT_DIRECTORY = "/usr/local/search/data/run.output"
#OUTPUT_DIRECTORY = "C:\\Search_Stuff\\Monitoring\\CGI to show progress"

# What is the pattern to match when looking for filenames?
FILENAME_MATCHER = /.*overnight_search_combo.*/

#
START_TIME_MATCHER = /^([-T:0-9]{19}).*Output is directed to/

#
END_TIME_MATCHER = /^([-T:0-9]{19}).*Return from 'overnight_search_combo.rb'/

#
OAI_COUNT_MATCHER = /Harvested a total of ([0-9]+) OAI records/

#
WRITE_DELETE_MATCHER = /Lucene index activity: ([0-9]+) deletes, ([0-9]+) writes./ 

#
CONTENT_COUNT_MATCHER = /Processed [0-9]+ responses; stored ([0-9]+) change records/

#
OPTIMIZE_MATCHER = /Return from 'search\/optimize_search_index.rb'/

#
RSYNC_MATCHER = /rsync on lucene directory complete/

#
ORPHAN_MATCHER = /FieldFrequency for 'metadataSource' -- ([0-9]): ([0-9]+)/

#
ERROR_MATCHER = /ERROR/

#
WARN_MATCHER = /WARN/

#
# ----------------------------------------------------------------------------
# METHODS
# ----------------------------------------------------------------------------
#

#  Get an array of all of the filenames.
def get_log_files()
  files = []
  Dir.foreach(OUTPUT_DIRECTORY) do |filename|
    if FILENAME_MATCHER.match(filename)
      files.push(filename)
    end
  end
  return files.sort.reverse
end

def get_current_status()
  process_lines = `ps -ef | grep searchd`
  job_running = process_lines.include?(JOB_NAME)
  
  return job_running
end

#  Write the boilerplate at the top of the page.
def write_page_opening()
  host_name = `hostname`
  host_name = host_name[0, host_name.index(".")]

  puts <<HERE
Content-type: text/html

<html>
  <head>
    <title>History of Search Index update jobs - #{host_name}</title>
    <style  TYPE="text/css">
      body { 
        background-color: #ddddff }
      h1 { 
        border: thick groove black;
        padding: 5px 10px 5px 10px;
        background-color: white }
      th, td {
        border: thin solid black;
        padding: 2px 5px 2px 5px;
        background-color: white }
      td {
        font-family: sans-serif }
      .legend {
        padding-top: 8;
        padding-bottom: 8;
        font-family: sans-serif }
      .code {
        font-family: monospace;
        font-weight: bolder;
        padding-left: 10 }
      div .status {
        font-family: sans-serif;
        font-size: larger}
      span .status {
        font-weight: bolder}
    </style> 
  </head>
  <body>
    <h1>History of Search Index update jobs - #{host_name}</h1>
HERE
end

def write_current_status()
  job_running = get_current_status()
  
  running_string = job_running ? "Running" : "Not Running"
  
  puts <<HERE
    <div class="status">Update job is currently <span class="status">#{running_string}</span>.</div>
    <br/>
HERE
end

#  Write the top of the table, with header row.
def write_table_opening()
  puts <<HERE
    <table>
      <tr>
        <th>Start time</th>
        <th>End time</th>
        <th># OAI records</th>
        <th>Lucene Writes</th>
        <th>Lucene Deletes</th>
        <th># Content updates</th>
        <th>Optimize?</th>
        <th>Rsync?</th>
        <th># Orphans</th>
        <th># Errors</th>
        <th># Warnings</th>
      </tr>
HERE
end

#  Scan through the file grabbing data, and write it out in a table row
def write_table_row_from_file(filename)
  Dir.chdir(OUTPUT_DIRECTORY)
  file = File.new(filename)
  start_time, end_time, oai_count, write_count, delete_count, content_count, optimize, rsync, orphan_count, error_count, warn_count = scan_file(file)
  
  puts <<HERE
      <tr>
        <td>#{start_time}</td>
        <td>#{end_time}</td>
        <td align="right">#{oai_count}</td>
        <td align="right">#{write_count}</td>
        <td align="right">#{delete_count}</td>
        <td align="right">#{content_count}</td>
        <td align="center">#{optimize}</td>
        <td align="center">#{rsync}</td>
        <td align="right">#{orphan_count}</td>
        <td align="right">#{error_count}</td>
        <td align="right">#{warn_count}</td>
      </tr>
HERE
end

def scan_file(file) 
  start_time = ""
  end_time = ""
  oai_count = ""
  write_count = ""
  delete_count = ""
  content_count = ""
  optimize = ""
  rsync = ""
  orphan_count = ""
  error_count = 0
  warn_count = 0
  
  file.each_line do |line|
    m = START_TIME_MATCHER.match(line)
    if m != nil 
      start_time = m[1]
    end
    
    m = END_TIME_MATCHER.match(line)
    if m != nil 
      end_time = m[1]
    end
    
    m = OAI_COUNT_MATCHER.match(line)
    if m != nil 
      oai_count = m[1]
    end
    
    m = WRITE_DELETE_MATCHER.match(line)
    if m != nil 
      write_count = m[2]
      delete_count = m[1]
    end
    
    m = CONTENT_COUNT_MATCHER.match(line)
    if m != nil 
      content_count = m[1]
    end
    
    m = OPTIMIZE_MATCHER.match(line)
    if m != nil 
      optimize = "Y"
    end
    
    m = RSYNC_MATCHER.match(line)
    if m != nil 
      rsync = "Y"
    end
    
    m = ORPHAN_MATCHER.match(line)
    if m != nil
      if m[1] == "0"
        orphan_count = m[2]
      else
        orphan_count = 0
      end
    end
    
    m = ERROR_MATCHER.match(line)
    if m != nil
      error_count += 1
    end
    
    m = WARN_MATCHER.match(line)
    if m != nil
      warn_count += 1
    end
    
  end
  
  return start_time, end_time, oai_count, write_count, delete_count, content_count, optimize, rsync, orphan_count, error_count, warn_count
end

#  Write the bottom of the table
def write_table_closing()
  puts <<HERE
    </table>
HERE
end

#  Write the boilerplate at the bottom of the page.
def write_page_closing()
  puts <<HERE
    <br/>
    <div class="legend">Log files directory: <span class="code">#{OUTPUT_DIRECTORY}</span></div>
    <div class="legend">Filenames matching this pattern: <span class="code">#{FILENAME_MATCHER.inspect}</span></div>
  </body>
</html>
HERE
end


#
# ----------------------------------------------------------------------------
# MAIN ROUTINE
# ----------------------------------------------------------------------------
#

begin
  log_files = get_log_files()
  
  write_page_opening()
  write_current_status()
  write_table_opening()
  
  log_files.each do |filename| 
    write_table_row_from_file(filename)
  end
  
  write_table_closing()
  write_page_closing()
rescue
  puts $!
end
