/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package org.nsdl.search.collContext;

import org.nsdl.search.lucene.LuceneFieldSpec;
import org.nsdl.searchtools.common.InstanceFactory;
import org.nsdl.searchtools.common.ListsMap;

/**
 * A self-filling cache of Collection Records and their data fields.
 * 
 * This abstract class provides the factory method and the interface.
 */
public abstract class CollRecCache {
	// ----------------------------------------------------------------------
	// Factory
	// ----------------------------------------------------------------------

	private static final Class<?>[] PARAMETER_TYPES = new Class[0];
	private static final Object[] PARAMETER_VALUES = new Object[0];

	/**
	 * Get an object that instantiates CollRecCache.
	 */
	public static CollRecCache getInstance() {
		return InstanceFactory.getInstance(CollRecCache.class, CollectionFieldsCache.class,
				PARAMETER_TYPES, PARAMETER_VALUES);
	}

	// ----------------------------------------------------------------------
	// Abstract interface
	// ----------------------------------------------------------------------

	/**
	 * Given a collection record OAI ID, return a map of lucene fields and
	 * values containing the collection record information to be added to the
	 * Lucene document for an item record.
	 */
	public abstract ListsMap<LuceneFieldSpec, String> getCollContextFieldInfos(
			String collectionRecordOaiId);

}
