/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package org.nsdl.search.collContext;

import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DCT_ACCESS_RIGHTS;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DCT_ALTERNATIVE;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DCT_AUDIENCE;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DCT_AUDIENCE_NSDL_EDLEVEL;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DCT_EDLEVEL;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DCT_EDLEVEL_NSDL_EDLEVEL;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DCT_LICENSE;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DCT_MEDIATOR;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DC_DESCRIPTION;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DC_RIGHTS;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DC_TITLE;

import org.nsdl.search.lucene.LuceneFieldSpec;

/**
 * Specify the Lucene fields that are inherited from Collection Context.
 * 
 * @author jblake
 */
public class CollectionContextFieldSpecs {
	public static final String COLLECTION_FIELD_PREFIX = "coll.";

	public static final LuceneFieldSpec CC_DCT_AUDIENCE = fromStandardField(
			DCT_AUDIENCE, 1.0F);
	public static final LuceneFieldSpec CC_DCT_AUDIENCE_NSDL_EDLEVEL = fromStandardField(
			DCT_AUDIENCE_NSDL_EDLEVEL, 1.0F);
	public static final LuceneFieldSpec CC_DCT_EDLEVEL = fromStandardField(
			DCT_EDLEVEL, 1.0F);
	public static final LuceneFieldSpec CC_DCT_EDLEVEL_NSDL_EDLEVEL = fromStandardField(
			DCT_EDLEVEL_NSDL_EDLEVEL, 1.0F);
	public static final LuceneFieldSpec CC_DCT_MEDIATOR = fromStandardField(
			DCT_MEDIATOR, 1.0F);
	public static final LuceneFieldSpec CC_DC_DESCRIPTION = fromStandardField(
			DC_DESCRIPTION, 0.8F);
	public static final LuceneFieldSpec CC_DC_RIGHTS = fromStandardField(
			DC_RIGHTS, 0.3F);
	public static final LuceneFieldSpec CC_DCT_ACCESS_RIGHTS = fromStandardField(
			DCT_ACCESS_RIGHTS, 0.3F);
	public static final LuceneFieldSpec CC_DCT_LICENSE = fromStandardField(
			DCT_LICENSE, 0.3F);
	public static final LuceneFieldSpec CC_DC_TITLE = fromStandardField(
			DC_TITLE, 0.8F);
	public static final LuceneFieldSpec CC_DCT_ALTERNATIVE = fromStandardField(
			DCT_ALTERNATIVE, 0.8F);

	/**
	 * Fields that show up in items as collection context are derived from
	 * standard fields in the collection records themselves.
	 * 
	 * Collection context fields are not derived, or else what's the point? How
	 * is the boost determined? By guessing?
	 */
	private static LuceneFieldSpec fromStandardField(LuceneFieldSpec spec,
			float boost) {
		return new LuceneFieldSpec(COLLECTION_FIELD_PREFIX + spec.getName(),
				spec.getStore(), spec.getIndex(), spec.isCaseFold(), boost,
				spec.getCompoundField(), spec.isStemmable(),
				spec.isTokenized(), false, true);
	}
}
