/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package org.nsdl.search.collContext;

import static org.nsdl.search.config.OaiMetadataElements.MD_DCT_ACCESS_RIGHTS;
import static org.nsdl.search.config.OaiMetadataElements.MD_DCT_ALTERNATIVE;
import static org.nsdl.search.config.OaiMetadataElements.MD_DCT_AUDIENCE;
import static org.nsdl.search.config.OaiMetadataElements.MD_DCT_AUDIENCE_NSDL_EDLEVEL;
import static org.nsdl.search.config.OaiMetadataElements.MD_DCT_EDLEVEL;
import static org.nsdl.search.config.OaiMetadataElements.MD_DCT_EDLEVEL_NSDL_EDLEVEL;
import static org.nsdl.search.config.OaiMetadataElements.MD_DCT_LICENSE;
import static org.nsdl.search.config.OaiMetadataElements.MD_DCT_MEDIATOR;
import static org.nsdl.search.config.OaiMetadataElements.MD_DC_DESCRIPTION;
import static org.nsdl.search.config.OaiMetadataElements.MD_DC_RIGHTS;
import static org.nsdl.search.config.OaiMetadataElements.MD_DC_TITLE;

import java.util.Collections;
import java.util.HashSet;
import java.util.Set;

import org.nsdl.search.processoai.MetadataElementSpec;

/**
 * The metadata elements that we will inherit from Collection OAI records.
 * 
 * @author jblake
 */
public final class CollectionContextMetadataElements {
	private static final Set<MetadataElementSpec> allSpecs = initializeAllSpecs();

	private static Set<MetadataElementSpec> initializeAllSpecs() {
		Set<MetadataElementSpec> specs = new HashSet<MetadataElementSpec>();

		/* audience */
		specs.add(MD_DCT_AUDIENCE);
		specs.add(MD_DCT_AUDIENCE_NSDL_EDLEVEL);
		specs.add(MD_DCT_EDLEVEL);
		specs.add(MD_DCT_EDLEVEL_NSDL_EDLEVEL);
		specs.add(MD_DCT_MEDIATOR);

		/* description */
		specs.add(MD_DC_DESCRIPTION);

		/* rights */
		specs.add(MD_DC_RIGHTS);
		specs.add(MD_DCT_ACCESS_RIGHTS);
		specs.add(MD_DCT_LICENSE);

		/* title */
		specs.add(MD_DC_TITLE);
		specs.add(MD_DCT_ALTERNATIVE);

		return Collections.unmodifiableSet(specs);
	}

	/**
	 * Get the set of all specs.
	 */
	public static Set<MetadataElementSpec> getAllSpecs() {
		return allSpecs;
	}

	private CollectionContextMetadataElements() {
		// nothing to instantiate here.
	}
}
