/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package org.nsdl.search.collContext;

import static org.nsdl.search.collContext.CollectionContextFieldSpecs.CC_DCT_ACCESS_RIGHTS;
import static org.nsdl.search.collContext.CollectionContextFieldSpecs.CC_DCT_ALTERNATIVE;
import static org.nsdl.search.collContext.CollectionContextFieldSpecs.CC_DCT_AUDIENCE;
import static org.nsdl.search.collContext.CollectionContextFieldSpecs.CC_DCT_AUDIENCE_NSDL_EDLEVEL;
import static org.nsdl.search.collContext.CollectionContextFieldSpecs.CC_DCT_EDLEVEL;
import static org.nsdl.search.collContext.CollectionContextFieldSpecs.CC_DCT_EDLEVEL_NSDL_EDLEVEL;
import static org.nsdl.search.collContext.CollectionContextFieldSpecs.CC_DCT_LICENSE;
import static org.nsdl.search.collContext.CollectionContextFieldSpecs.CC_DCT_MEDIATOR;
import static org.nsdl.search.collContext.CollectionContextFieldSpecs.CC_DC_DESCRIPTION;
import static org.nsdl.search.collContext.CollectionContextFieldSpecs.CC_DC_RIGHTS;
import static org.nsdl.search.collContext.CollectionContextFieldSpecs.CC_DC_TITLE;
import static org.nsdl.search.config.OaiMetadataElements.MD_DCT_ACCESS_RIGHTS;
import static org.nsdl.search.config.OaiMetadataElements.MD_DCT_ALTERNATIVE;
import static org.nsdl.search.config.OaiMetadataElements.MD_DCT_AUDIENCE;
import static org.nsdl.search.config.OaiMetadataElements.MD_DCT_AUDIENCE_NSDL_EDLEVEL;
import static org.nsdl.search.config.OaiMetadataElements.MD_DCT_EDLEVEL;
import static org.nsdl.search.config.OaiMetadataElements.MD_DCT_EDLEVEL_NSDL_EDLEVEL;
import static org.nsdl.search.config.OaiMetadataElements.MD_DCT_LICENSE;
import static org.nsdl.search.config.OaiMetadataElements.MD_DCT_MEDIATOR;
import static org.nsdl.search.config.OaiMetadataElements.MD_DC_DESCRIPTION;
import static org.nsdl.search.config.OaiMetadataElements.MD_DC_RIGHTS;
import static org.nsdl.search.config.OaiMetadataElements.MD_DC_TITLE;

import org.nsdl.search.oai.AbstractMetadataMapping;

/**
 * <p>
 * Connect the metadata elements in the OAI with the fields in the Lucene index
 * that they feed directly into - for the purpose inheriting Collection info.
 * </p>
 * <p>
 * Data that is acquired in the regular harvest is not specified here. That data
 * requires a separate set of metadata mappings.
 * </p>
 * 
 * @author jblake
 */
public class CollectionMetadataMapping extends AbstractMetadataMapping {
	private static final CollectionMetadataMapping instance = new CollectionMetadataMapping();

	public static CollectionMetadataMapping getInstance() {
		return instance;
	}

	private CollectionMetadataMapping() {
		/* audience */
		addMapping(CC_DCT_AUDIENCE, MD_DCT_AUDIENCE);
		addMapping(CC_DCT_AUDIENCE_NSDL_EDLEVEL, MD_DCT_AUDIENCE_NSDL_EDLEVEL);
		addMapping(CC_DCT_EDLEVEL, MD_DCT_EDLEVEL);
		addMapping(CC_DCT_EDLEVEL_NSDL_EDLEVEL, MD_DCT_EDLEVEL_NSDL_EDLEVEL);
		addMapping(CC_DCT_MEDIATOR, MD_DCT_MEDIATOR);

		/* description */
		addMapping(CC_DC_DESCRIPTION, MD_DC_DESCRIPTION);

		/* rights */
		addMapping(CC_DC_RIGHTS, MD_DC_RIGHTS);
		addMapping(CC_DCT_ACCESS_RIGHTS, MD_DCT_ACCESS_RIGHTS);
		addMapping(CC_DCT_LICENSE, MD_DCT_LICENSE);

		/* title */
		addMapping(CC_DC_TITLE, MD_DC_TITLE);
		addMapping(CC_DCT_ALTERNATIVE, MD_DCT_ALTERNATIVE);
	}
}
