/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package org.nsdl.search.config;

import javax.xml.namespace.NamespaceContext;

import org.nsdl.search.processoai.MetadataElementSpec;
import org.nsdl.search.util.XmlNamespaceUtil;

/**
 * 
 * @author jblake
 */
public class OaiMetadataElements {
	private static final NamespaceContext context = XmlNamespaceUtil
			.getNamespaceContext();

	/* accessibility */
	public static final MetadataElementSpec MD_DCT_ACCESSIBILITY = buildSpec(
			"accessibility", "dct");

	/* accrualMethod */
	public static final MetadataElementSpec MD_DCT_ACCRUAL_METHOD = buildSpec(
			"accrualMethod", "dct");

	/* accrualPeriodicity */
	public static final MetadataElementSpec MD_DCT_ACCRUAL_PERIODICITY = buildSpec(
			"accrualPeriodicity", "dct");

	/* accrualPolicy */
	public static final MetadataElementSpec MD_DCT_ACCRUAL_POLICY = buildSpec(
			"accrualPolicy", "dct");

	/* audience */
	public static final MetadataElementSpec MD_DCT_AUDIENCE = buildSpec(
			"audience", "dct");
	public static final MetadataElementSpec MD_DCT_AUDIENCE_NSDL_AUDIENCE = buildSpec(
			"audience", "dct", "NSDLAudience", "nsdl_dc");
	public static final MetadataElementSpec MD_DCT_AUDIENCE_NSDL_EDLEVEL = buildSpec(
			"audience", "dct", "NSDLEdLevel", "nsdl_dc");
	public static final MetadataElementSpec MD_DCT_EDLEVEL = buildSpec(
			"educationLevel", "dct");
	public static final MetadataElementSpec MD_DCT_EDLEVEL_NSDL_EDLEVEL = buildSpec(
			"educationLevel", "dct", "NSDLEdLevel", "nsdl_dc");
	public static final MetadataElementSpec MD_DCT_MEDIATOR = buildSpec(
			"mediator", "dct");

	/* contributor */
	public static final MetadataElementSpec MD_DC_CONTRIBUTOR = buildSpec(
			"contributor", "dc");

	/* coverage */
	public static final MetadataElementSpec MD_DC_COVERAGE = buildSpec(
			"coverage", "dc");
	public static final MetadataElementSpec MD_DC_COVERAGE_BOX = buildSpec(
			"coverage", "dc", "Box", "dct");
	public static final MetadataElementSpec MD_DC_COVERAGE_ISO3166 = buildSpec(
			"coverage", "dc", "ISO3166", "dct");
	public static final MetadataElementSpec MD_DC_COVERAGE_POINT = buildSpec(
			"coverage", "dc", "Point", "dct");
	public static final MetadataElementSpec MD_DC_COVERAGE_TGN = buildSpec(
			"coverage", "dc", "TGN", "dct");
	public static final MetadataElementSpec MD_DC_COVERAGE_ISO8601 = buildSpec(
			"coverage", "dc", "ISO8601", "dct");
	public static final MetadataElementSpec MD_DC_COVERAGE_PERIOD = buildSpec(
			"coverage", "dc", "Period", "dct");
	public static final MetadataElementSpec MD_DC_COVERAGE_W3CDTF = buildSpec(
			"coverage", "dc", "W3CDTF", "dct");
	public static final MetadataElementSpec MD_DCT_SPATIAL = buildSpec(
			"spatial", "dct");
	public static final MetadataElementSpec MD_DCT_SPATIAL_BOX = buildSpec(
			"spatial", "dct", "Box", "dct");
	public static final MetadataElementSpec MD_DCT_SPATIAL_ISO3166 = buildSpec(
			"spatial", "dct", "ISO3166", "dct");
	public static final MetadataElementSpec MD_DCT_SPATIAL_POINT = buildSpec(
			"spatial", "dct", "Point", "dct");
	public static final MetadataElementSpec MD_DCT_SPATIAL_TGN = buildSpec(
			"spatial", "dct", "TGN", "dct");
	public static final MetadataElementSpec MD_DCT_TEMPORAL = buildSpec(
			"temporal", "dct");
	public static final MetadataElementSpec MD_DCT_TEMPORAL_ISO8601 = buildSpec(
			"temporal", "dct", "ISO8601", "dct");
	public static final MetadataElementSpec MD_DCT_TEMPORAL_PERIOD = buildSpec(
			"temporal", "dct", "Period", "dct");
	public static final MetadataElementSpec MD_DCT_TEMPORAL_W3CDTF = buildSpec(
			"temporal", "dct", "W3CDTF", "dct");

	/* creator */
	public static final MetadataElementSpec MD_DC_CREATOR = buildSpec(
			"creator", "dc");

	/* date */
	public static final MetadataElementSpec MD_DC_DATE = buildSpec("date", "dc");
	public static final MetadataElementSpec MD_DC_DATE_ISO8601 = buildSpec(
			"date", "dc", "ISO8601", "dct");
	public static final MetadataElementSpec MD_DC_DATE_PERIOD = buildSpec(
			"date", "dc", "Period", "dct");
	public static final MetadataElementSpec MD_DC_DATE_W3CDTF = buildSpec(
			"date", "dc", "W3CDTF", "dct");
	public static final MetadataElementSpec MD_DCT_AVAILABLE = buildSpec(
			"available", "dct");
	public static final MetadataElementSpec MD_DCT_AVAILABLE_ISO8601 = buildSpec(
			"available", "dct", "ISO8601", "dct");
	public static final MetadataElementSpec MD_DCT_AVAILABLE_PERIOD = buildSpec(
			"available", "dct", "Period", "dct");
	public static final MetadataElementSpec MD_DCT_AVAILABLE_W3CDTF = buildSpec(
			"available", "dct", "W3CDTF", "dct");
	public static final MetadataElementSpec MD_DCT_CREATED = buildSpec(
			"created", "dct");
	public static final MetadataElementSpec MD_DCT_CREATED_ISO8601 = buildSpec(
			"created", "dct", "ISO8601", "dct");
	public static final MetadataElementSpec MD_DCT_CREATED_PERIOD = buildSpec(
			"created", "dct", "Period", "dct");
	public static final MetadataElementSpec MD_DCT_CREATED_W3CDTF = buildSpec(
			"created", "dct", "W3CDTF", "dct");
	public static final MetadataElementSpec MD_DCT_DATE_ACCEPTED = buildSpec(
			"dateAccepted", "dct");
	public static final MetadataElementSpec MD_DCT_DATE_ACCEPTED_ISO8601 = buildSpec(
			"dateAccepted", "dct", "ISO8601", "dct");
	public static final MetadataElementSpec MD_DCT_DATE_ACCEPTED_PERIOD = buildSpec(
			"dateAccepted", "dct", "Period", "dct");
	public static final MetadataElementSpec MD_DCT_DATE_ACCEPTED_W3CDTF = buildSpec(
			"dateAccepted", "dct", "W3CDTF", "dct");
	public static final MetadataElementSpec MD_DCT_DATE_COPYRIGHTED = buildSpec(
			"dateCopyrighted", "dct");
	public static final MetadataElementSpec MD_DCT_DATE_COPYRIGHTED_ISO8601 = buildSpec(
			"dateCopyrighted", "dct", "ISO8601", "dct");
	public static final MetadataElementSpec MD_DCT_DATE_COPYRIGHTED_PERIOD = buildSpec(
			"dateCopyrighted", "dct", "Period", "dct");
	public static final MetadataElementSpec MD_DCT_DATE_COPYRIGHTED_W3CDTF = buildSpec(
			"dateCopyrighted", "dct", "W3CDTF", "dct");
	public static final MetadataElementSpec MD_DCT_DATE_SUBMITTED = buildSpec(
			"dateSubmitted", "dct");
	public static final MetadataElementSpec MD_DCT_DATE_SUBMITTED_ISO8601 = buildSpec(
			"dateSubmitted", "dct", "ISO8601", "dct");
	public static final MetadataElementSpec MD_DCT_DATE_SUBMITTED_PERIOD = buildSpec(
			"dateSubmitted", "dct", "Period", "dct");
	public static final MetadataElementSpec MD_DCT_DATE_SUBMITTED_W3CDTF = buildSpec(
			"dateSubmitted", "dct", "W3CDTF", "dct");
	public static final MetadataElementSpec MD_DCT_ISSUED = buildSpec("issued",
			"dct");
	public static final MetadataElementSpec MD_DCT_ISSUED_ISO8601 = buildSpec(
			"issued", "dct", "ISO8601", "dct");
	public static final MetadataElementSpec MD_DCT_ISSUED_PERIOD = buildSpec(
			"issued", "dct", "Period", "dct");
	public static final MetadataElementSpec MD_DCT_ISSUED_W3CDTF = buildSpec(
			"issued", "dct", "W3CDTF", "dct");
	public static final MetadataElementSpec MD_DCT_MODIFIED = buildSpec(
			"modified", "dct");
	public static final MetadataElementSpec MD_DCT_MODIFIED_ISO8601 = buildSpec(
			"modified", "dct", "ISO8601", "dct");
	public static final MetadataElementSpec MD_DCT_MODIFIED_PERIOD = buildSpec(
			"modified", "dct", "Period", "dct");
	public static final MetadataElementSpec MD_DCT_MODIFIED_W3CDTF = buildSpec(
			"modified", "dct", "W3CDTF", "dct");
	public static final MetadataElementSpec MD_DCT_VALID = buildSpec("valid",
			"dct");
	public static final MetadataElementSpec MD_DCT_VALID_ISO8601 = buildSpec(
			"valid", "dct", "ISO8601", "dct");
	public static final MetadataElementSpec MD_DCT_VALID_PERIOD = buildSpec(
			"valid", "dct", "Period", "dct");
	public static final MetadataElementSpec MD_DCT_VALID_W3CDTF = buildSpec(
			"valid", "dct", "W3CDTF", "dct");

	/* description */
	public static final MetadataElementSpec MD_DC_DESCRIPTION = buildSpec(
			"description", "dc");
	public static final MetadataElementSpec MD_DCT_ABSTRACT = buildSpec(
			"abstract", "dct");
	public static final MetadataElementSpec MD_DCT_TABLE_OF_CONTENTS = buildSpec(
			"tableOfContents", "dct");

	/* format */
	public static final MetadataElementSpec MD_DC_FORMAT = buildSpec("format",
			"dc");
	public static final MetadataElementSpec MD_DC_FORMAT_IMT = buildSpec(
			"format", "dc", "IMT", "dct");
	public static final MetadataElementSpec MD_DCT_EXTENT = buildSpec("extent",
			"dct");
	public static final MetadataElementSpec MD_DCT_MEDIUM = buildSpec("medium",
			"dct");
	public static final MetadataElementSpec MD_DCT_MEDIUM_IMT = buildSpec(
			"medium", "dct", "IMT", "dct");

	/* identifier */
	public static final MetadataElementSpec MD_DC_IDENTIFIER = buildSpec(
			"identifier", "dc");
	public static final MetadataElementSpec MD_DC_IDENTIFIER_URI = buildSpec(
			"identifier", "dc", "URI", "dct");
	public static final MetadataElementSpec MD_DC_IDENTIFIER_ISBN = buildSpec(
			"identifier", "dc", "ISBN", "dct");
	public static final MetadataElementSpec MD_DC_IDENTIFIER_ISSN = buildSpec(
			"identifier", "dc", "ISSN", "dct");
	public static final MetadataElementSpec MD_DCT_BIBLIOGRAPHIC_CITATION = buildSpec(
			"bibliographicCitation", "dct");

	/* instructionalMethod */
	public static final MetadataElementSpec MD_DCT_INSTRUCTIONAL_METHOD = buildSpec(
			"instructionalMethod", "dct");

	/* interactivityLevel */
	public static final MetadataElementSpec MD_IEEE_INTERACTIVITY_LEVEL = buildSpec(
			"interactivityLevel", "ieee");

	/* interactivityType */
	public static final MetadataElementSpec MD_IEEE_INTERACTIVITY_TYPE = buildSpec(
			"interactivityType", "ieee");

	/* language */
	public static final MetadataElementSpec MD_DC_LANGUAGE = buildSpec(
			"language", "dc");
	public static final MetadataElementSpec MD_DC_LANGUAGE_ISO639_2 = buildSpec(
			"language", "dc", "ISO639-2", "dct");
	public static final MetadataElementSpec MD_DC_LANGUAGE_RFC3066 = buildSpec(
			"language", "dc", "RFC3066", "dct");

	/* provenance */
	public static final MetadataElementSpec MD_DCT_PROVENANCE = buildSpec(
			"provenance", "dct");

	/* publisher */
	public static final MetadataElementSpec MD_DC_PUBLISHER = buildSpec(
			"publisher", "dc");

	/* relation */
	public static final MetadataElementSpec MD_DC_RELATION = buildSpec(
			"relation", "dc");
	public static final MetadataElementSpec MD_DC_RELATION_URI = buildSpec(
			"relation", "dc", "URI", "dct");
	public static final MetadataElementSpec MD_DCT_CONFORMS_TO = buildSpec(
			"conformsTo", "dct");
	public static final MetadataElementSpec MD_DCT_CONFORMS_TO_URI = buildSpec(
			"conformsTo", "dct", "URI", "dct");
	public static final MetadataElementSpec MD_DCT_HAS_FORMAT = buildSpec(
			"hasFormat", "dct");
	public static final MetadataElementSpec MD_DCT_HAS_FORMAT_URI = buildSpec(
			"hasFormat", "dct", "URI", "dct");
	public static final MetadataElementSpec MD_DCT_HAS_PART = buildSpec(
			"hasPart", "dct");
	public static final MetadataElementSpec MD_DCT_HAS_PART_URI = buildSpec(
			"hasPart", "dct", "URI", "dct");
	public static final MetadataElementSpec MD_DCT_HAS_VERSION = buildSpec(
			"hasVersion", "dct");
	public static final MetadataElementSpec MD_DCT_HAS_VERSION_URI = buildSpec(
			"hasVersion", "dct", "URI", "dct");
	public static final MetadataElementSpec MD_DCT_IS_FORMAT_OF = buildSpec(
			"isFormatOf", "dct");
	public static final MetadataElementSpec MD_DCT_IS_FORMAT_OF_URI = buildSpec(
			"isFormatOf", "dct", "URI", "dct");
	public static final MetadataElementSpec MD_DCT_IS_PART_OF = buildSpec(
			"isPartOf", "dct");
	public static final MetadataElementSpec MD_DCT_IS_PART_OF_URI = buildSpec(
			"isPartOf", "dct", "URI", "dct");
	public static final MetadataElementSpec MD_DCT_IS_REFERENCED_BY = buildSpec(
			"isReferencedBy", "dct");
	public static final MetadataElementSpec MD_DCT_IS_REFERENCED_BY_URI = buildSpec(
			"isReferencedBy", "dct", "URI", "dct");
	public static final MetadataElementSpec MD_DCT_IS_REPLACED_BY = buildSpec(
			"isReplacedBy", "dct");
	public static final MetadataElementSpec MD_DCT_IS_REPLACED_BY_URI = buildSpec(
			"isReplacedBy", "dct", "URI", "dct");
	public static final MetadataElementSpec MD_DCT_IS_REQUIRED_BY = buildSpec(
			"isRequiredBy", "dct");
	public static final MetadataElementSpec MD_DCT_IS_REQUIRED_BY_URI = buildSpec(
			"isRequiredBy", "dct", "URI", "dct");
	public static final MetadataElementSpec MD_DCT_IS_VERSION_OF = buildSpec(
			"isVersionOf", "dct");
	public static final MetadataElementSpec MD_DCT_IS_VERSION_OF_URI = buildSpec(
			"isVersionOf", "dct", "URI", "dct");
	public static final MetadataElementSpec MD_DCT_REFERENCES = buildSpec(
			"references", "dct");
	public static final MetadataElementSpec MD_DCT_REFERENCES_URI = buildSpec(
			"references", "dct", "URI", "dct");
	public static final MetadataElementSpec MD_DCT_REPLACES = buildSpec(
			"replaces", "dct");
	public static final MetadataElementSpec MD_DCT_REPLACES_URI = buildSpec(
			"replaces", "dct", "URI", "dct");
	public static final MetadataElementSpec MD_DCT_REQUIRES = buildSpec(
			"requires", "dct");
	public static final MetadataElementSpec MD_DCT_REQUIRES_URI = buildSpec(
			"requires", "dct", "URI", "dct");

	/* rights */
	public static final MetadataElementSpec MD_DC_RIGHTS = buildSpec("rights",
			"dc");
	public static final MetadataElementSpec MD_DC_RIGHTS_URI = buildSpec(
			"rights", "dc", "URI", "dct");
	public static final MetadataElementSpec MD_DCT_ACCESS_RIGHTS = buildSpec(
			"accessRights", "dct");
	public static final MetadataElementSpec MD_DCT_ACCESS_RIGHTS_NSDL_ACCESS = buildSpec(
			"accessRights", "dct", "NSDLAccess", "nsdl_dc");
	public static final MetadataElementSpec MD_DCT_ACCESS_RIGHTS_URI = buildSpec(
			"accessRights", "dct", "URI", "dct");
	public static final MetadataElementSpec MD_DCT_LICENSE = buildSpec(
			"license", "dct");
	public static final MetadataElementSpec MD_DCT_LICENSE_URI = buildSpec(
			"license", "dct", "URI", "dct");

	/* rightsHolder */
	public static final MetadataElementSpec MD_DCT_RIGHTS_HOLDER = buildSpec(
			"rightsHolder", "dct");

	/* source */
	public static final MetadataElementSpec MD_DC_SOURCE = buildSpec("source",
			"dc");
	public static final MetadataElementSpec MD_DC_SOURCE_URI = buildSpec(
			"source", "dc", "URI", "dct");

	/*
	 * subject (tokenize-able fields also mapped to "subject" field for nsdl.org
	 * searches
	 */
	public static final MetadataElementSpec MD_DC_SUBJECT = buildSpec(
			"subject", "dc");
	public static final MetadataElementSpec MD_DC_SUBJECT_DDC = buildSpec(
			"subject", "dc", "DDC", "dct");
	public static final MetadataElementSpec MD_DC_SUBJECT_GEM = buildSpec(
			"subject", "dc", "GEM", "nsdl_dc");
	public static final MetadataElementSpec MD_DC_SUBJECT_LCC = buildSpec(
			"subject", "dc", "LCC", "dct");
	public static final MetadataElementSpec MD_DC_SUBJECT_LCSH = buildSpec(
			"subject", "dc", "LCSH", "dct");
	public static final MetadataElementSpec MD_DC_SUBJECT_MESH = buildSpec(
			"subject", "dc", "MESH", "dct");
	public static final MetadataElementSpec MD_DC_SUBJECT_UDC = buildSpec(
			"subject", "dc", "UDC", "dct");

	/* title */
	public static final MetadataElementSpec MD_DC_TITLE = buildSpec("title",
			"dc");
	public static final MetadataElementSpec MD_DCT_ALTERNATIVE = buildSpec(
			"alternative", "dct");

	/* type */
	public static final MetadataElementSpec MD_DC_TYPE = buildSpec("type", "dc");
	public static final MetadataElementSpec MD_DC_TYPE_DCMITYPE = buildSpec(
			"type", "dc", "DCMIType", "dct");
	public static final MetadataElementSpec MD_DC_TYPE_NSDLTYPE = buildSpec(
			"type", "dc", "NSDLType", "nsdl_dc");

	/* typicalLearningTime */
	public static final MetadataElementSpec MD_IEEE_TYPICAL_LEARNING_TIME = buildSpec(
			"typicalLearningTime", "ieee");

	/**
	 * Build a spec with no encoding.
	 */
	private static MetadataElementSpec buildSpec(String name, String namespace) {
		return buildSpec(name, namespace, null, null);
	}

	/**
	 * Build a spec with encoding.
	 */
	private static MetadataElementSpec buildSpec(String name, String namespace,
			String encoding, String encodingNamespace) {
		String nsUri = (namespace == null) ? null : context
				.getNamespaceURI(namespace);
		String encodingUri = (encodingNamespace == null) ? null : context
				.getNamespaceURI(encodingNamespace);
		return MetadataElementSpec.getInstance(name, nsUri, encoding,
				encodingUri);
	}

	private OaiMetadataElements() {
		// nothing to instantiate here.
	}
}
