/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package org.nsdl.search.lucene.searchdoc;

import java.util.Date;

/**
 * Specified a congtent object for the SearchDocument.
 * 
 * @author jblake
 */
public interface SearchDocumentContent {
	/**
	 * Does this object contain valid data? Do we have content for this
	 * document? If not, don't call the other methods. They may return empty
	 * values or nulls, or throw {@link IllegalStateException}s.
	 */
	boolean isValid();

	/**
	 * The title of the HTML page for the resource.
	 */
	String getTitle();

	/**
	 * The parsed text of the HTML page for the resource.
	 */
	String getText();

	/**
	 * The MIME type of the HTML page for the resource.
	 */
	String getContentType();

	/**
	 * The date that the resource content was most recently fetched.
	 */
	Date getFetchDate();

	/**
	 * As best we can tell, the date when the resource content was most recently
	 * modified. (If the provider doesn't give this date, we will use the fetch
	 * date.)
	 */
	Date getModifiedDate();
}
