/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package org.nsdl.search.lucene.searchdoc;

import java.util.Date;

import org.apache.log4j.Logger;
import org.nsdl.search.config.MetadataMapping;
import org.nsdl.search.lucene.LuceneFieldSpec;
import org.nsdl.search.processoai.MetadataElementSpec;
import org.nsdl.search.processoai.OaiCollectionInfo;
import org.nsdl.search.processoai.OaiHarvestRecord;
import org.nsdl.searchtools.common.ListsMap;

/**
 * Loads a {@link SearchDocumentMetadata} object from an
 * {@link OaiHarvestRecord}.
 * 
 * @author jblake
 */
public class SearchDocumentMetadataLoader {
	private static final Logger LOG = Logger
			.getLogger(SearchDocumentMetadataLoader.class);

	private Date oaiDateStamp;
	private OaiCollectionInfo collInfo;
	private ListsMap<LuceneFieldSpec, String> fields;

	/**
	 * Create a collection of Lucene fields from the OAI data.
	 */
	public void load(OaiHarvestRecord oai) {
		oaiDateStamp = oai.getOaiRecDate();

		// Load the collection brand info.
		collInfo = oai.getCollectionInfo();

		/*
		 * Get the MetadataElements from the OAI record. For each one, find the
		 * correspoding LuceneFieldSpec, and copy the metadata values into the
		 * search document.
		 */
		MetadataMapping mapping = MetadataMapping.getInstance();
		fields = new ListsMap<LuceneFieldSpec, String>();
		for (MetadataElementSpec mdEl : oai.getFieldKeys()) {
			LuceneFieldSpec luceneSpec = mapping.getLuceneSpec(mdEl);
			if (luceneSpec == null) {
				LOG.warn("No LuceneFieldSpec for this Metadata:" + mdEl
						+ ", contained in " + oai.getOaiRecId());
			} else {
				for (String value : oai.getFieldValues(mdEl)) {
					fields.addValue(luceneSpec, value);
				}
			}
		}
	}

	/**
	 * Get the fields that were loaded from the OAI record.
	 */
	public ListsMap<LuceneFieldSpec, String> getFields() {
		return this.fields;
	}

	public Date getOaiDateStamp() {
		return this.oaiDateStamp;
	}

	public OaiCollectionInfo getCollInfo() {
		return collInfo;
	}

}
