/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package org.nsdl.search.lucene.wrapper;

import org.nsdl.searchtools.common.InstanceFactory;

/**
 * <p>
 * Given a query and some content, identify the best passages of that content
 * with the query terms highlighted.
 * </p>
 * <p>
 * The methods only have package access, since this is really an ancillary class
 * to {@link IndexWrapperImpl}.
 * </p>
 * 
 * @author jblake
 */
public abstract class BestPassageGenerator {

	// ----------------------------------------------------------------------
	// Factory
	// ----------------------------------------------------------------------

	private static final Class<?>[] PARAMETER_TYPES = new Class[0];
	private static final Object[] PARAMETER_VALUES = new Object[0];

	/**
	 * Get an object that instantiates DateUtil.
	 */
	static BestPassageGenerator getInstance() {
		return InstanceFactory.getInstance(BestPassageGenerator.class,
				BestPassageGeneratorImpl.class, PARAMETER_TYPES,
				PARAMETER_VALUES);
	}

	// ----------------------------------------------------------------------
	// Abstract interface
	// ----------------------------------------------------------------------

	abstract String getHighlightedBestPassage(IndexWrapperQuery query,
			String content);
}
