/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package org.nsdl.search.lucene.wrapper;

import java.io.File;
import java.util.Collection;
import java.util.Date;

/**
 * A lump of information about the current Lucene index.
 * 
 * @author jblake
 */
public abstract class IndexSummaryInfo {
	/**
	 * Lucene version number when the current IndexReader was opened.
	 */
	public abstract long getVersion();

	/**
	 * Last modified date on the lucene index directory.
	 */
	public abstract Date getLastModified();

	/**
	 * How many active docs are in the index?
	 */
	public abstract int getNumDocs();

	/**
	 * Where is the index directory stored?
	 */
	public abstract File getIndexDirectory();

	/**
	 * List the names of the stored fields (available for results).
	 */
	public abstract Collection<String> getStoredFieldNames();

	/**
	 * List the names of the searchable fields (indexed).
	 */
	public abstract Collection<String> getSearchableFieldNames();

	/**
	 * List the names of all fields.
	 */
	public abstract Collection<String> getFieldNames();

}
