/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package org.nsdl.search.lucene.wrapper;

/**
 * Configuration parameters for the Lucene {@link IndexWrapper}.
 * 
 * @author jblake
 */
public interface IndexWrapperConfig {

	/**
	 * Where is the lucene index located?
	 * 
	 * @return the full path to the index directory.
	 */
	String getLuceneIndexDirectory();

	/**
	 * What field in the index acts as the unique ID for search documents?
	 * 
	 * @return the name of the field.
	 */
	String getDocIdFieldName();

	/**
	 * How many writes and/or deletes can be cached in the {@link IndexWrapper}
	 * before it flushes them to the index?
	 */
	int getMaximumCachedWrites();

	/**
	 * How long should we wait for more activity before refreshing the searcher?
	 * (The searcher will also be refreshed when the cache is flushed.)
	 * 
	 * @return the interval, in millis.
	 */
	long getInactivityThreshold();

}
