/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package org.nsdl.search.lucene.wrapper;

/**
 * A recorder for index events.
 * 
 * @author jblake
 */
public interface IndexWrapperListener {

	/** The types of index events that we record. */
	enum EventType {
		/** Client code called {@link IndexWrapper#synchronize()}. */
		USER_SYNCHRONIZE,
		/** Cache contents exceed the configured limit. */
		CACHE_FULL,
		/** No writing for a while, so flush pending changes. */
		INACTIVITY,
		/** Index was not synchronized before Java VM shut down. */
		FINALIZE
	}

	/** An implementation of the listener that doesn't do anything. */
	IndexWrapperListener NULL_LISTENER = new IndexWrapperListener() {
		public void recordEvent(EventType type, int pendingDeletes,
				int pendingWrites) {
		}
	};

	/** An event occurred - write it down. */
	void recordEvent(EventType type, int pendingDeletes, int pendingWrites);
}
