/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package org.nsdl.search.oai;

import java.util.HashMap;
import java.util.Map;

import org.nsdl.search.lucene.LuceneFieldSpec;
import org.nsdl.search.processoai.MetadataElementSpec;

/**
 * A correspondence between metadata elements in an OAI response and fields in
 * the Lucene search index. Concrete sub-classes may overlap and even have
 * apparent conflicts, since an OAI response element may correspond to one field
 * in a given context (e.g., loading a record) and another field in a different
 * context (e.g., inheriting from collection).
 * 
 * @author jblake
 */
public abstract class AbstractMetadataMapping {
	// TODO: Are any of these maps unnecessary?

	private final Map<LuceneFieldSpec, MetadataElementSpec> byField;

	private final Map<MetadataElementSpec, LuceneFieldSpec> byMetadataSpec;

	protected AbstractMetadataMapping() {
		byField = new HashMap<LuceneFieldSpec, MetadataElementSpec>();
		byMetadataSpec = new HashMap<MetadataElementSpec, LuceneFieldSpec>();
	}

	protected void addMapping(LuceneFieldSpec luceneField,
			MetadataElementSpec metadataElement) {
		byField.put(luceneField, metadataElement);
		byMetadataSpec.put(metadataElement, luceneField);
	}

	public MetadataElementSpec getMetadataSpec(LuceneFieldSpec field) {
		return byField.get(field);
	}

	public LuceneFieldSpec getLuceneSpec(MetadataElementSpec mdSpec) {
		return byMetadataSpec.get(mdSpec);
	}

}
