/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package org.nsdl.search.oai.harvest;

import java.io.File;
import java.io.FileNotFoundException;
import java.util.List;

import org.nsdl.searchtools.common.InstanceFactory;
import org.nsdl.searchtools.common.history.HistoryFile;

/**
 * A wrapper around the parent directory that contains all harvest directories.
 * 
 * @author jblake
 */
public abstract class HarvestWrapper {
	// ----------------------------------------------------------------------
	// Factory
	// ----------------------------------------------------------------------

	private static final Class<?>[] PARAMETER_TYPES = new Class[] { File.class,
			HistoryFile.class };

	/**
	 * Get an object that instantiates HarvestWrapper, given the parent
	 * directory for the harvests, and the history file where we record which
	 * harvests have been indexed.
	 */
	public static HarvestWrapper getInstance(File harvestParentDirectory,
			HistoryFile historyFile) {
		return InstanceFactory.getInstance(HarvestWrapper.class,
				HarvestWrapperImpl.class, PARAMETER_TYPES, new Object[] {
						harvestParentDirectory, historyFile });
	}

	// ----------------------------------------------------------------------
	// Abstract interface
	// ----------------------------------------------------------------------

	/**
	 * What parent directory was this built around?
	 */
	public abstract File getHarvestParentDirectory();
	
	/**
	 * Find the specified harvest directory, and create a wrapper around it.
	 * 
	 * The directory name can be specified either as a full path (absolute or
	 * relative to the current directory), or as relative to the harvest parent
	 * directory.
	 */
	public abstract HarvestDirectoryWrapper getDirectoryWrapper(
			String directoryName) throws FileNotFoundException;

	/**
	 * Look at the indexedHarvests file in the current search index directory,
	 * and figure out which harvest should be indexed next.
	 * 
	 * @return null, if all harvests have been indexed.
	 */
	public abstract HarvestDirectoryWrapper getOldestUnindexedDirectory();

	/**
	 * Get a list of all the wrappers of unindexed harvest directories, sorted
	 * by age, oldest first.
	 */
	public abstract List<HarvestDirectoryWrapper> getUnindexedDirectories();
}
