/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package org.nsdl.search.processoai;

/**
 * Of the information in a
 * {@link org.nsdl.search.lucene.searchdoc.SearchDocumentMetadata
 * SearchDocumentMetadata} object, the items that represent the NSDL Collection
 * that supplied the metadata.
 * 
 * @author jblake
 */
public class OaiCollectionInfo {
	private final String collectionOaiId;
	private final String imageUrl;
	private final String imageWidth;
	private final String imageHeight;
	private final String imageAltText;

	public OaiCollectionInfo(String collectionOaiId, String imageUrl,
			String imageWidth, String imageHeight, String imageAltText) {
		this.collectionOaiId = collectionOaiId;
		this.imageUrl = imageUrl;
		this.imageWidth = imageWidth;
		this.imageHeight = imageHeight;
		this.imageAltText = imageAltText;
	}

	public String getImageAltText() {
		return imageAltText;
	}

	public String getImageHeight() {
		return imageHeight;
	}

	public String getImageUrl() {
		return imageUrl;
	}

	public String getImageWidth() {
		return imageWidth;
	}

	public String getCollectionOaiId() {
		return collectionOaiId;
	}

	@Override
	public boolean equals(Object other) {
		if (this == other) {
			return true;
		}
		if (other == null) {
			return false;
		}
		if (!this.getClass().equals(other.getClass())) {
			return false;
		}

		OaiCollectionInfo that = (OaiCollectionInfo) other;
		return equivalent(this.collectionOaiId, that.collectionOaiId)
				&& equivalent(this.imageUrl, that.imageUrl)
				&& equivalent(this.imageWidth, that.imageWidth)
				&& equivalent(this.imageHeight, that.imageHeight)
				&& equivalent(this.imageAltText, that.imageAltText);
	}

	private boolean equivalent(Object o1, Object o2) {
		return (o1 == null) ? (o2 == null) : o1.equals(o2);
	}

	/**
	 * The OAI ID of the Collection is likely sufficient for hashing.
	 */
	@Override
	public int hashCode() {
		return this.collectionOaiId.hashCode();
	}

	/**
	 * Convert to string for debugging.
	 */
	@Override
	public String toString() {
		return "OaiCollectionInfo[collectionOaiId=" + collectionOaiId
				+ ", imageUrl=" + imageUrl + ", imageWidth=" + imageWidth
				+ ", imageHeight=" + imageHeight + ", imageAltText="
				+ imageAltText + "]";
	}

}
