/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package org.nsdl.search.processoai;

import java.io.IOException;

import org.nsdl.search.oai.process.OaiIndexingListener;
import org.nsdl.search.oai.process.OaiRecordIndexerImpl;
import org.nsdl.searchtools.common.InstanceFactory;

/**
 * Takes the contents of an OAI record from the parser and applies it to the
 * lucene index.
 * 
 * @author jblake
 */
public abstract class OaiRecordIndexer {

	// ----------------------------------------------------------------------
	// Factory
	// ----------------------------------------------------------------------

	private static final Class<?>[] PARAMETER_TYPES = new Class[0];
	private static final Object[] PARAMETER_VALUES = new Object[0];

	/**
	 * Get an object that instantiates IndexWrapper.
	 */
	public static OaiRecordIndexer getInstance() {
		return InstanceFactory.getInstance(OaiRecordIndexer.class,
				OaiRecordIndexerImpl.class, PARAMETER_TYPES, PARAMETER_VALUES);
	}

	// ----------------------------------------------------------------------
	// Abstract interface
	// ----------------------------------------------------------------------

	public abstract void setListener(OaiIndexingListener listener);

	public abstract void indexRecord(OaiHarvestRecord oaiContents)
			throws IOException;
}
