/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package org.nsdl.search.rest3;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;

import org.nsdl.search.generated.rest.ErrorCodeType;
import org.nsdl.searchtools.common.http.RequestHelper;

/**
 * An exception that the Search servlets can throw, and that can be handled by a
 * standard error page.
 * 
 * @author jblake
 */
public class SearchServletException extends ServletException {
	private final String requestUrl;
	private final ErrorCodeType code;

	/**
	 * @param request
	 *            The current HTTP request, so we can get the request URL.
	 * @param code
	 *            A schema-valid error code.
	 * @param message
	 *            A text message for the user, explaining the nature of the
	 *            problem.
	 */
	public SearchServletException(HttpServletRequest request,
			ErrorCodeType code, String message) {
		super(message);
		this.requestUrl = RequestHelper.assembleRequestUrl(request);
		this.code = code;
	}

	/**
	 * @param request
	 *            The current HTTP request, so we can get the request URL.
	 * @param code
	 *            A schema-valid error code.
	 * @param message
	 *            A text message for the user, explaining the nature of the
	 *            problem.
	 * @param cause
	 *            The original cause of the problem.
	 */
	public SearchServletException(HttpServletRequest request,
			ErrorCodeType code, String message, Throwable cause) {
		this(request, code, message);
		super.initCause(cause);
	}

	public String getRequestUrl() {
		return requestUrl;
	}

	public ErrorCodeType getCode() {
		return code;
	}
}
