/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package org.nsdl.search.rest3.responses;

import javax.servlet.http.HttpServletRequest;

import org.nsdl.search.generated.rest.GetDocumentDocumentType;
import org.nsdl.search.generated.rest.GetDocumentResponseType;
import org.nsdl.search.generated.rest.ObjectFactory;
import org.nsdl.search.lucene.wrapper.SearchResult;
import org.nsdl.search.lucene.wrapper.SearchResults;

/**
 * A response object for the <code>/getDocument</code> request.
 * 
 * @author jblake
 */
class GetDocumentResponse extends AbstractDocumentResponse {

	public GetDocumentResponse(HttpServletRequest request,
			SearchResults searchResults) {
		super(request);

		getDocRoot().setGetDocument(
				processGetDocumentResponse(getFactory(), searchResults));
	}

	/**
	 * Gather the search results info for a GET_DOCUMENT.
	 */
	private GetDocumentResponseType processGetDocumentResponse(
			ObjectFactory factory, SearchResults searchResults) {
		GetDocumentResponseType gdrt = factory.createGetDocumentResponseType();
		for (SearchResult searchResult : searchResults) {
			gdrt.setDocument(processGetDocumentResult(factory, searchResult));
			break;
		}
		return gdrt;
	}

	/**
	 * Process a single search result for GET_DOCUMENT.
	 */
	private GetDocumentDocumentType processGetDocumentResult(
			ObjectFactory factory, SearchResult searchResult) {
		GetDocumentDocumentType gddt = factory.createGetDocumentDocumentType();
		gddt.setHeader(processDocumentHeader(factory, searchResult
				.getDocument()));
		gddt.setFields(processSearchDocumentFields(factory, searchResult));
		return gddt;
	}

}
