/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package org.nsdl.search.rest3.responses;

import java.math.BigInteger;

import javax.servlet.http.HttpServletRequest;
import javax.xml.bind.JAXBElement;
import javax.xml.namespace.QName;

import org.nsdl.search.generated.rest.DescriptionType;
import org.nsdl.search.generated.rest.IndexInfoResponseType;
import org.nsdl.search.generated.rest.NsdlDcType;
import org.nsdl.search.generated.rest.SimpleLiteral;
import org.nsdl.search.lucene.wrapper.IndexSummaryInfo;
import org.nsdl.search.util.Config;
import org.nsdl.search.util.SearchServiceConfig;
import org.nsdl.search.util.XmlNamespaceUtil;
import org.nsdl.searchtools.common.http.RequestHelper;

/**
 * A response object for the <code>/indexInfo</code> request.
 * 
 * @author jblake
 */
class IndexInfoResponse extends SearchServiceResponse {

	public IndexInfoResponse(IndexSummaryInfo indexInfo, HttpServletRequest req) {
		super(req);

		IndexInfoResponseType iirt = getFactory().createIndexInfoResponseType();
		iirt.setBaseURL(RequestHelper.extractBaseUrl(req));

		iirt.setIndexLastUpdated(indexInfo.getLastModified());

		iirt.setNumberOfRecords(BigInteger.valueOf(indexInfo.getNumDocs()));

		SearchServiceConfig searchConfig = Config.getInstance()
				.getSearchServiceConfig();

		iirt.setSearchServiceName(searchConfig.getServiceName());
		iirt.getDescription().add(
				buildDescriptionElement(searchConfig.getServiceDescription()));

		getDocRoot().setIndexInfo(iirt);
	}

	/**
	 * A "dc:description" element inside a "nsdl_dc:nsdl_dc" element.
	 */
	private DescriptionType buildDescriptionElement(String descriptionText) {
		SimpleLiteral literal = getFactory().createSimpleLiteral();
		literal.setValue(descriptionText);
		JAXBElement<SimpleLiteral> element = new JAXBElement<SimpleLiteral>(
				new QName(XmlNamespaceUtil.NS_DUBLIN_CORE, "description"),
				SimpleLiteral.class, literal);

		NsdlDcType nsdlDcT = getFactory().createNsdlDcType();
		nsdlDcT.getAny().add(element);
		JAXBElement<NsdlDcType> element2 = new JAXBElement<NsdlDcType>(
				new QName(XmlNamespaceUtil.NS_NSDL_DC, "nsdl_dc"),
				NsdlDcType.class, nsdlDcT);

		DescriptionType dt = getFactory().createDescriptionType();
		dt.setAny(element2);
		return dt;
	}
}
