/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package org.nsdl.search.rest3.responses;

import javax.servlet.http.HttpServletRequest;

import org.nsdl.search.generated.rest.ObjectFactory;
import org.nsdl.search.generated.rest.ResourceTextResponseType;
import org.nsdl.search.generated.rest.ResourceTextResponseType.Resource;
import org.nsdl.search.lucene.searchdoc.SearchDocument;
import org.nsdl.search.lucene.wrapper.SearchResult;
import org.nsdl.search.lucene.wrapper.SearchResults;

/**
 * A response object for the <code>/resourceText</code> request.
 * 
 * @author jblake
 */
public class ResourceTextResponse extends SearchServiceResponse {

	public ResourceTextResponse(HttpServletRequest req,
			SearchResults searchResults) {
		super(req);

		getDocRoot().setResourceText(
				processResourceTextResponse(getFactory(), searchResults));
	}

	/**
	 * Gather the search results info for a RESOURCE_TEXT.
	 */
	private ResourceTextResponseType processResourceTextResponse(
			ObjectFactory factory, SearchResults searchResults) {
		ResourceTextResponseType rtrt = factory
				.createResourceTextResponseType();
		for (SearchResult searchResult : searchResults) {
			rtrt.setResource(processResourceTextResult(factory, searchResult));
			break;
		}
		return rtrt;
	}

	/**
	 * Process a single search result for RESOURCE_TEXT.
	 */
	private Resource processResourceTextResult(ObjectFactory factory,
			SearchResult searchResult) {
		SearchDocument document = searchResult.getDocument();
		String text = (document.hasContent()) ? document.getContent().getText()
				: "";

		Resource rtrtr = factory.createResourceTextResponseTypeResource();
		rtrtr.setHeader(processDocumentHeader(factory, document));
		rtrtr.setParsedText(text);
		return rtrtr;
	}

}
