/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package org.nsdl.search.rest3.responses;

import java.io.OutputStream;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.JAXBException;

import org.nsdl.searchtools.common.InstanceFactory;

/**
 * Unpacks JAXBElement objects, encodes them as XML, and writes them.
 * 
 * @author jblake
 */
public abstract class ResponseMarshaller {

	// ----------------------------------------------------------------------
	// Factory
	// ----------------------------------------------------------------------

	private static final Class<?>[] PARAMETER_TYPES = new Class[] { ResponseMarshallerType.class };

	/**
	 * Get an object that instantiates ResponseMarshaller.
	 */
	public static ResponseMarshaller getInstance(ResponseMarshallerType type) {
		return InstanceFactory.getInstance(ResponseMarshaller.class,
				ResponseMarshallerImpl.class, PARAMETER_TYPES,
				new Object[] { type });
	}

	// ----------------------------------------------------------------------
	// Abstract interface
	// ----------------------------------------------------------------------

	/**
	 * <p>
	 * Convert a top-level JAXB object to XML and write it out.
	 * </p>
	 * <p>
	 * Note that we write it to an {@link OutputStream}, rather than a
	 * {@link java.io.Writer Writer}, because when we go to an
	 * {@link OutputStream}, JAXB will escape special characters to produce
	 * valid XML like <code>&amp;#x1824;</code> or <code>&amp;quot;</code>.
	 * </p>
	 * 
	 * @param responseObject
	 *            the data object to be converted to XML
	 * @param output
	 *            the destination to write the XML
	 */
	public abstract void marshal(JAXBElement<?> responseObject,
			OutputStream output) throws JAXBException;

}
