/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package org.nsdl.search.rest3.responses;

import javax.xml.bind.Marshaller;
import javax.xml.bind.PropertyException;

import org.nsdl.search.util.XmlNamespaceUtil;

/**
 * Provide for a limited set of response marshallers, each with its own
 * initialization.
 * 
 * @author jblake
 */
public enum ResponseMarshallerType {
	/** A standard Search-REST type of response. */
	REST("org.nsdl.search.generated.rest") {
		public void initializeMarshaller(Marshaller marshaller)
				throws PropertyException {
			makeItPretty(marshaller);
			setThePrefixes(marshaller);

			// Show the preferred schema location(s).
			marshaller.setProperty(Marshaller.JAXB_SCHEMA_LOCATION,
					XmlNamespaceUtil.NS_NSDL_SEARCH_REST + " "
							+ XmlNamespaceUtil.SL_NSDL_SEARCH_REST);

		}
	},

	/** An RSS2-based response. */
	RSS2("org.nsdl.search.generated.rss2") {
		public void initializeMarshaller(Marshaller marshaller)
				throws PropertyException {
			makeItPretty(marshaller);
			setThePrefixes(marshaller);
		}
	};

	private final String contextPath;

	private ResponseMarshallerType(String contextPath) {
		this.contextPath = contextPath;
	}

	public String getContextPath() {
		return contextPath;
	}

	public abstract void initializeMarshaller(Marshaller marshaller)
			throws PropertyException;

	/**
	 * Set the marshaller to produce line-feeds and indentation in the XML.
	 */
	private static void makeItPretty(Marshaller marshaller)
			throws PropertyException {
		marshaller.setProperty(Marshaller.JAXB_FORMATTED_OUTPUT, Boolean.TRUE);
	}

	/**
	 * Set the marshaller to use our preferred set of namespace prefixes.
	 */
	private static void setThePrefixes(Marshaller marshaller) {
		XmlNamespaceUtil.setPrefixMapping(marshaller);
	}

}
