/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package org.nsdl.search.rest3.responses;

import java.text.ParseException;
import java.util.Date;

import org.nsdl.searchtools.common.DateUtil;

/**
 * Parsing and printing methods for the RSS-based JAXB-generated classes to use
 * when the defaults aren't suitable.
 * 
 * @author jblake
 */
public class Rss2Format {
	/**
	 * Marshall a Date object.
	 */
	public static String printDate(Date date) {
		return DateUtil.getInstance().formatDate(date,
				DateUtil.RFC822_DATE_TIME);
	}

	/**
	 * Unmarshall a Date object.
	 */
	public static Date parseDate(String dateString) {
		try {
			return DateUtil.getInstance().parseDate(dateString,
					DateUtil.RFC822_DATE_TIME);
		} catch (ParseException e) {
			throw new IllegalArgumentException("Can't parse this date: "
					+ dateString, e);
		}
	}

	/**
	 * No need to create instances - all methods are static.
	 */
	private Rss2Format() {
		// Nothing to instantiate.
	}
}
