/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package org.nsdl.search.rest3.responses;

import java.io.OutputStream;
import java.math.BigDecimal;

import javax.servlet.http.HttpServletRequest;
import javax.xml.bind.JAXBElement;
import javax.xml.bind.JAXBException;

import org.nsdl.search.generated.rss2.ObjectFactory;
import org.nsdl.search.generated.rss2.TRss;
import org.nsdl.search.lucene.wrapper.SearchResults;

/**
 * 
 * @author jblake
 */
public class RssResponse {

	// ----------------------------------------------------------------------
	// Factory methods for the various response types.
	// ----------------------------------------------------------------------

	public static RssResponse produceRssSearchResponse(
			SearchResults searchResults, HttpServletRequest req) {
		return new RssQueryResponse(req, searchResults);
	}

	// ----------------------------------------------------------------------

	private final ObjectFactory factory;
	private final TRss docRoot;
	private final JAXBElement<TRss> responseObject;

	/**
	 * Protected. Use one of the factory methods to create an instance of a
	 * subclass.
	 */
	@SuppressWarnings("unused")
	protected RssResponse(HttpServletRequest request) {
		factory = new ObjectFactory();
		docRoot = prepareDocumentRoot(factory);
		this.responseObject = factory.createRss(docRoot);
	}

	/**
	 * Populate the root of the document with URL and time. The body of the
	 * response depends on the type, and is not done here.
	 */
	private TRss prepareDocumentRoot(ObjectFactory factory) {
		TRss docRoot = factory.createTRss();
		docRoot.setVersion(new BigDecimal("2.0"));
		return docRoot;
	}

	/**
	 * Serialize this object to the output stream.
	 */
	public void marshall(OutputStream output) throws JAXBException {
		ResponseMarshaller.getInstance(ResponseMarshallerType.RSS2).marshal(
				this.responseObject, output);
	}

	protected ObjectFactory getFactory() {
		return factory;
	}

	protected TRss getDocRoot() {
		return docRoot;
	}

}
