/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package org.nsdl.search.rest3.responses;

import java.math.BigInteger;
import java.util.List;

import javax.servlet.http.HttpServletRequest;

import org.apache.log4j.Logger;
import org.nsdl.search.generated.rest.ObjectFactory;
import org.nsdl.search.generated.rest.SearchDocumentType;
import org.nsdl.search.generated.rest.SearchResponseType;
import org.nsdl.search.generated.rest.SearchResultsInfoType;
import org.nsdl.search.generated.rest.SearchResponseType.Results;
import org.nsdl.search.lucene.searchdoc.SearchDocument;
import org.nsdl.search.lucene.wrapper.SearchResult;
import org.nsdl.search.lucene.wrapper.SearchResults;

/**
 * A response object for the <code>/search</code> request.
 * 
 * @author jblake
 */
class StandardQueryResponse extends AbstractDocumentResponse {
	private static final Logger LOG = Logger.getLogger(StandardQueryResponse.class);

	public StandardQueryResponse(HttpServletRequest request, SearchResults searchResults) {
		super(request);

		getDocRoot().setSearchResults(
				processSearchResponse(getFactory(), searchResults));
	}

	/**
	 * Populate the results of a QUERY.
	 */
	private SearchResponseType processSearchResponse(ObjectFactory factory,
			SearchResults results) {
		SearchResponseType srt = factory.createSearchResponseType();
		srt.setResultsInfo(processResultsInfo(factory, results));
		srt.setResults(processSearchResults(factory, results));
		return srt;
	}

	/**
	 * Gather the search results info for a QUERY: number of results, number
	 * skipped, number returned.
	 */
	private SearchResultsInfoType processResultsInfo(ObjectFactory factory,
			SearchResults results) {
		SearchResultsInfoType resultsInfo = factory
				.createSearchResultsInfoType();
		resultsInfo.setTotalNumResults(BigInteger.valueOf(results
				.getTotalCount()));
		resultsInfo.setNumSkipped(BigInteger.valueOf(results.getSkipCount()));
		resultsInfo
				.setNumReturned(BigInteger.valueOf(results.getReturnCount()));
		return resultsInfo;
	}

	/**
	 * Gather all of the search results themselves for a QUERY.
	 */
	private Results processSearchResults(ObjectFactory factory,
			SearchResults results) {
		Results resultHolder = factory.createSearchResponseTypeResults();
		List<SearchDocumentType> documentList = resultHolder.getDocument();
		for (SearchResult result : results) {
			documentList.add(processSearchResult(result, factory));
		}
		return resultHolder;
	}

	/**
	 * Gather a search result document for QUERY or GET_DOCUMENT.
	 */
	private SearchDocumentType processSearchResult(SearchResult result,
			ObjectFactory factory) {
		SearchDocument doc = result.getDocument();
		LOG.debug("Processing SearchDocument: " + doc);

		SearchDocumentType docHolder = factory.createSearchDocumentType();
		docHolder.setPosition(BigInteger.valueOf(result.getPosition()));
		docHolder.setScore(result.getScore());
		docHolder.setHeader(processDocumentHeader(factory, doc));
		docHolder.setFields(processSearchDocumentFields(factory, result));
		return docHolder;
	}

}
