/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package org.nsdl.search.rest3.servlets;

import java.io.IOException;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.xml.bind.JAXBException;

import org.apache.log4j.Logger;
import org.nsdl.search.generated.rest.ErrorCodeType;
import org.nsdl.search.lucene.wrapper.IndexSummaryInfo;
import org.nsdl.search.lucene.wrapper.IndexWrapper;
import org.nsdl.search.rest3.SearchServletException;
import org.nsdl.search.rest3.responses.SearchServiceResponse;

/**
 * Synchronize the {@link IndexWrapper} with the index, so we have the latest
 * and greatest info to tell the folks.
 * 
 * @author jblake
 */
public class IndexInfoServlet extends AbstractSearchServlet {
	@SuppressWarnings("unused")
	private static final Logger LOG = Logger.getLogger(IndexInfoServlet.class);

	@Override
	protected void doGet(HttpServletRequest req, HttpServletResponse resp)
			throws ServletException, IOException {
		try {
			IndexWrapper.getInstance().synchronize();
			IndexSummaryInfo info = IndexWrapper.getInstance().getIndexInfo();
			SearchServiceResponse ssr = SearchServiceResponse.produceIndexInfo(
					info, req);
			ssr.marshall(resp.getOutputStream());
		} catch (JAXBException e) {
			throw new SearchServletException(req, ErrorCodeType.SYSTEM_PROBLEM,
					"Problem while marshalling search results.", e);
		} finally {
			// don't close the writer here - the error page will need to write
			// to the response if there is an error.
		}
	}

}
