/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */


package org.nsdl.search.rest3.servlets;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.PrintWriter;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.log4j.Logger;

/**
 * Display the buildlevel file in response to request.
 * 
 * @author jblake
 */
public class VersionServlet extends AbstractSearchServlet {
	public static final String BUILDLEVEL_FILE_PARAMETER_NAME = "buildlevel_file";

	private static final Logger LOG = Logger.getLogger(VersionServlet.class);

	@Override
	protected void doGet(HttpServletRequest req, HttpServletResponse resp)
			throws ServletException, IOException {

		String filename = getInitParameter(BUILDLEVEL_FILE_PARAMETER_NAME);
		if (filename == null) {
			throw new ServletException("Init parameter '"
					+ BUILDLEVEL_FILE_PARAMETER_NAME
					+ "' was not supplied in web.xml");
		}

		InputStream stream = this.getClass().getResourceAsStream(filename);
		if (stream == null) {
			throw new IOException("File '" + filename + "' not found");
		}

		PrintWriter writer = resp.getWriter();
		BufferedReader reader = null;
		try {
			reader = new BufferedReader(new InputStreamReader(stream));
			writeFromReader(reader, writer);
		} finally {
			if (reader != null) {
				try {
					reader.close();
				} catch (IOException e) {
					LOG.error(e);
				}
			}
			// don't close the writer here - the error page will need to write
			// to the response if there is an error.
		}
	}

	/**
	 * Copy the entire file to output as an XML response.
	 */
	private void writeFromReader(BufferedReader reader, PrintWriter writer)
			throws IOException {
		char[] buffer = new char[4096];
		int howMany;
		while ((howMany = reader.read(buffer)) > -1) {
			writer.write(buffer, 0, howMany);
		}
	}
}



