/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package org.nsdl.search.util;

import org.nsdl.search.content.ContentCacheConfig;
import org.nsdl.search.lucene.wrapper.IndexWrapperConfig;
import org.nsdl.search.oai.harvest.HarvestWrapperConfig;
import org.nsdl.searchtools.common.InstanceFactory;

/**
 * A central location for Configuration information. This the abstract
 * interface/factory.
 * 
 * @author jblake
 */
public abstract class Config {

	// ----------------------------------------------------------------------
	// Factory
	// ----------------------------------------------------------------------

	private static final Class<?>[] PARAMETER_TYPES = new Class[0];
	private static final Object[] PARAMETER_VALUES = new Object[0];

	/**
	 * Get an object that instantiates Config.
	 */
	public static Config getInstance() {
		return InstanceFactory.getInstance(Config.class, ConfigImpl.class,
				PARAMETER_TYPES, PARAMETER_VALUES);
	}

	// ----------------------------------------------------------------------
	// Abstract interface
	// ----------------------------------------------------------------------

	public abstract void setSearchServiceConfig(SearchServiceConfig config);

	public abstract SearchServiceConfig getSearchServiceConfig();

	public abstract void setIndexWrapperConfig(IndexWrapperConfig config);

	public abstract IndexWrapperConfig getIndexWrapperConfig();

	public abstract void setHarvestWrapperConfig(HarvestWrapperConfig config);

	public abstract HarvestWrapperConfig getHarvestWrapperConfig();

	public abstract void setContentCacheConfig(ContentCacheConfig config);

	public abstract ContentCacheConfig getContentCacheConfig();

}
