/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package org.nsdl.search.util;

import org.nsdl.search.content.ContentCacheConfig;
import org.nsdl.search.lucene.wrapper.IndexWrapperConfig;
import org.nsdl.search.oai.harvest.HarvestWrapperConfig;

/**
 * A central location for Configuration information. This is the default
 * implementation for {@link #Config}.
 * 
 * @author jblake
 */
public class ConfigImpl extends Config {
	private static final ConfigImpl instance = new ConfigImpl();

	public static ConfigImpl getInstance() {
		return instance;
	}

	private SearchServiceConfig searchServiceConfig;
	private IndexWrapperConfig indexWrapperConfig;
	private HarvestWrapperConfig harvestWrapperConfig;
	private ContentCacheConfig contentCacheConfig;

	private ConfigImpl() {
		// Keep it private to enforce the factory pattern.
	}

	public SearchServiceConfig getSearchServiceConfig() {
		return searchServiceConfig;
	}

	public void setSearchServiceConfig(SearchServiceConfig searchServiceConfig) {
		this.searchServiceConfig = searchServiceConfig;
	}

	public IndexWrapperConfig getIndexWrapperConfig() {
		return indexWrapperConfig;
	}

	public void setIndexWrapperConfig(IndexWrapperConfig indexWrapperConfig) {
		this.indexWrapperConfig = indexWrapperConfig;
	}

	public HarvestWrapperConfig getHarvestWrapperConfig() {
		return harvestWrapperConfig;
	}

	public void setHarvestWrapperConfig(
			HarvestWrapperConfig harvestWrapperConfig) {
		this.harvestWrapperConfig = harvestWrapperConfig;
	}

	public ContentCacheConfig getContentCacheConfig() {
		return contentCacheConfig;
	}

	public void setContentCacheConfig(ContentCacheConfig contentCacheConfig) {
		this.contentCacheConfig = contentCacheConfig;
	}
}
