/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package org.nsdl.search.utilities.indexcleaner;

import java.io.File;

import org.nsdl.searchtools.common.parameters.AbstractParameterParser;

/**
 * Only need one parameter for the cleaning process - the location of the index.
 * 
 * @author jblake
 */
public class IndexCleanerParameters extends AbstractParameterParser {
	public static final String PARM_INDEX = "-indexDirectory";
	private static final String[] ALL_PARMS = new String[] { PARM_INDEX };

	private final File indexDirectory;

	/**
	 * Validate the arguments and store the values.
	 */
	public IndexCleanerParameters(String[] args) {
		buildParameterMap(args);

		rejectUnrecognizedParms(ALL_PARMS);

		this.indexDirectory = findIndexDirectory();
	}

	private File findIndexDirectory() {
		File indexDirectory = new File(getRequiredParameterValue(PARM_INDEX));
		if (!indexDirectory.exists()) {
			throw problem("Index directory '" + indexDirectory.getPath()
					+ "' does not exist.");
		}
		if (!indexDirectory.isDirectory()) {
			throw problem("Index directory '" + indexDirectory.getPath()
					+ "' is not a directory.");
		}
		return indexDirectory;
	}

	/**
	 * Explain how it should have been done.
	 */
	@Override
	protected void usage() {
		System.out.println("usage: IndexCleaner "
				+ "-indexDirectory {fullPath} ");
	}

	public File getIndexDirectory() {
		return this.indexDirectory;
	}

	public String toString() {
		return "IndexCleanerParameters[indexDirectory="
				+ indexDirectory.getPath() + "]";
	}
}
