/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package org.nsdl.search.utilities.lucenescan;

import java.io.PrintWriter;
import java.util.Enumeration;

import org.apache.lucene.document.Document;
import org.apache.lucene.document.Field;

/**
 * Interface for the classes that summarize the contents of the Lucene index.
 * 
 * @author jblake
 */
public abstract class DocumentScanner {

	/**
	 * Called for each document that has not been marked as deleted.
	 */
	public abstract void add(Document doc, PrintWriter writer);

	/**
	 * Called at the end of the scan, to allow printing any summary stats that
	 * were collected.
	 */
	public abstract void print(PrintWriter writer);

	/**
	 * Isolate the unchecked cast.
	 */
	@SuppressWarnings("unchecked")
	protected Enumeration<Field> getFieldsFromDocument(Document doc) {
		return doc.fields();
	}

	/**
	 * Get the resourceIdentifier from the document - if none, return the default value.
	 */
	protected String getResourceIdentifier(Document doc, String defaultValue) {
		String[] ids = doc.getValues("resourceIdentifier");
		if ((ids == null) || (ids.length == 0)) {
			return defaultValue;
		} else {
			return ids[0];
		}
	}

}
