/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package org.nsdl.search.utilities.lucenescan;

/**
 * Encapsulate the summary statistics about the scan as a whole. Total number of
 * docs, start time, etc.
 * 
 * TODO: add start time and stop time.
 */
public class LuceneScanStats {
	private long numberOfDocuments;
	private long numberOfDocumentsToScan;
	private long numberOfDeletedDocuments;
	private long numberOfActiveDocuments;

	public void setNumberOfDocuments(long numberOfDocuments) {
		this.numberOfDocuments = numberOfDocuments;
	}

	public void incrementNumberOfDeletedDocuments() {
		this.numberOfDeletedDocuments++;
	}

	public void incrementNumberOfActiveDocuments() {
		this.numberOfActiveDocuments++;
	}

	public long getNumberOfDocuments() {
		return numberOfDocuments;
	}

	public long getNumberOfActiveDocuments() {
		return numberOfActiveDocuments;
	}

	public long getNumberOfDeletedDocuments() {
		return numberOfDeletedDocuments;
	}

	public long getNumberOfDocumentsToScan() {
		return numberOfDocumentsToScan;
	}

	public void limitNumberOfDocumentsToScan(long maxDocs) {
		this.numberOfDocumentsToScan = Math
				.min(this.numberOfDocuments, maxDocs);
	}

	public boolean isScanningComplete() {
		return this.numberOfActiveDocuments >= this.numberOfDocumentsToScan;
	}

}
