/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package org.nsdl.search.utilities.lucenescan.datescanner;

import java.io.IOException;
import java.io.PrintWriter;
import java.util.Map;

import org.nsdl.search.utilities.lucenescan.DocumentScanner;
import org.nsdl.search.utilities.lucenescan.LuceneScan;
import org.nsdl.search.utilities.lucenescan.LuceneScanArguments;
import org.nsdl.search.utilities.lucenescan.LuceneScanStats;
import org.nsdl.search.utilities.lucenescan.LuceneScanUsageException;

/**
 * Create histograms for each of the date fields over the last 30 days.
 * 
 * @author jblake
 */
public class AllDatesScan extends LuceneScan {
	private final DocumentScanner[] scanners = new DocumentScanner[]{
			new ThirtyDayScanner("documentCreated"),
			new ThirtyDayScanner("documentLastUpdated"),
			new ThirtyDayScanner("metadataLastModified"),
			new ThirtyDayScanner("contentLastFetched"),
			new ThirtyDayScanner("contentLastModified")};

	@SuppressWarnings("unused")
	public AllDatesScan(Map<String, String> options)
			throws LuceneScanUsageException, IOException {
	}

	@Override
	protected DocumentScanner[] getScanners() {
		return scanners;
	}

	@Override
	protected void printFooter(LuceneScanStats stats, PrintWriter writer) {
	}

	@Override
	protected void printHeader(LuceneScanArguments arguments,
			LuceneScanStats stats, PrintWriter writer) {
	}

}
