/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package org.nsdl.search.utilities.lucenescan.describeinfo;

import java.io.PrintWriter;
import java.util.Collection;

import org.apache.lucene.document.Document;
import org.apache.lucene.document.Field;
import org.nsdl.search.utilities.data.FieldHelper;
import org.nsdl.search.utilities.data.FixedRangeHistogram;
import org.nsdl.search.utilities.data.Histogram;
import org.nsdl.search.utilities.lucenescan.DocumentScanner;

/**
 * Build a histogram with the lengths of all the dc:description fields.
 * 
 * @author jblake
 */
public class DescriptionLengthScanner extends DocumentScanner {
	private FixedRangeHistogram<Integer> lengths = new FixedRangeHistogram<Integer>(
			new Integer[]{0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15,
					16, 17, 18, 19, 20, 30, 40, 50, 60, 70, 80, 90, 100, 200,
					300, 400, 500, 600, 700, 800, 900, 1000, 2000});

	public void add(Document doc, PrintWriter writer) {
		Field[] fields = doc.getFields("dc:description");
		Collection<String> values = FieldHelper.parseFieldValues(fields);
		for (String value : values) {
			lengths.countThis(value.length());
		}
	}

	public void print(PrintWriter writer) {
		writer.println("Histogram of dc:description fields by length");
		writer.println("       count --- length");
		for (Histogram.Bucket bucket : lengths.getBuckets()) {
			writer.format("%1$,12d --- %2$s\n", bucket.getCount(), bucket
					.getLegend());
		}
		writer.println();
	}

}
