/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package org.nsdl.search.utilities.lucenescan.fieldcounter;

import java.io.PrintWriter;
import java.util.Enumeration;
import java.util.Map;
import java.util.TreeMap;

import org.apache.lucene.document.Document;
import org.apache.lucene.document.Field;
import org.nsdl.search.utilities.lucenescan.DocumentScanner;

/**
 * 
 * @author jblake
 */
public class FieldCountScanner extends DocumentScanner {
	private final Map<String, FieldInfo> fieldInfoMap;

	public FieldCountScanner() {
		this.fieldInfoMap = new TreeMap<String, FieldInfo>();
	}

	/**
	 * For each document, get the list of fields. If this is the first time that
	 * a field has appeared, create a new info object. Otherwise, just update
	 * the count.
	 */
	public void add(Document doc, PrintWriter writer) {
		Enumeration<Field> fields = getFieldsFromDocument(doc);
		while (fields.hasMoreElements()) {
			Field field = fields.nextElement();
			String name = field.name();

			if (!fieldInfoMap.containsKey(name)) {
				fieldInfoMap.put(name, new FieldInfo(field));
			}

			fieldInfoMap.get(name).incrementCount();
		}
	}

	/**
	 * Print the results. For each field, print the count, the field name, and
	 * the field attributes.
	 */
	public void print(PrintWriter writer) {
		int maxNameLength = 0;
		for (String name : fieldInfoMap.keySet()) {
			maxNameLength = Math.max(maxNameLength, name.length());
		}

		for (String name : fieldInfoMap.keySet()) {
			FieldInfo info = fieldInfoMap.get(name);
			writer.format("%1$,12d %2$-" + maxNameLength + "s -- %3$s\n", info
					.getCount(), name, info.formatAttributes());
		}
	}

}
