/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package org.nsdl.search.utilities.lucenescan.fieldfrequency;

import java.io.IOException;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import org.nsdl.search.utilities.lucenescan.DocumentScanner;
import org.nsdl.search.utilities.lucenescan.LuceneScan;
import org.nsdl.search.utilities.lucenescan.LuceneScanArguments;
import org.nsdl.search.utilities.lucenescan.LuceneScanStats;
import org.nsdl.search.utilities.lucenescan.LuceneScanUsageException;

/**
 * For a given field name, find out how many records have none of those fields,
 * how many have 1, how many have 2, etc.
 * 
 * @author jblake
 */
public class FieldFrequency extends LuceneScan {
	private final List<FieldFrequencyScanner> scanners = new ArrayList<FieldFrequencyScanner>();

	/**
	 * Create a scanner for each provided field name.
	 */
	public FieldFrequency(Map<String, String> options)
			throws LuceneScanUsageException, IOException {
		for (String name : getFieldNamesFromOptions(options)) {
			if (name.length() > 0) {
				scanners.add(new FieldFrequencyScanner(name));
			}
		}
	}

	/**
	 * Get the scanners as an array.
	 */
	@Override
	protected DocumentScanner[] getScanners() {
		return scanners.toArray(new DocumentScanner[scanners.size()]);
	}

	@Override
	protected void printHeader(LuceneScanArguments arguments,
			LuceneScanStats stats, PrintWriter writer) {
	}

	@Override
	protected void printFooter(LuceneScanStats stats, PrintWriter writer) {
	}

}
