/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package org.nsdl.search.utilities.lucenescan.fieldfrequency;

import java.io.PrintWriter;

import org.apache.lucene.document.Document;
import org.nsdl.search.utilities.lucenescan.DocumentScanner;

/**
 * For a given field name, how many records have zero values for that field? How
 * many have 1 value? 2 values?
 * 
 * @author jblake
 */
public class FieldFrequencyScanner extends DocumentScanner {
	private static final int MAX_COUNTER = 12;

	private final String fieldName;

	private int[] counters = new int[MAX_COUNTER];
	private int overmaxCounter;
	private int largestNumberOfValues;

	public FieldFrequencyScanner(String fieldName) {
		this.fieldName = fieldName;
	}

	@Override
	public void add(Document doc, PrintWriter writer) {
		String[] values = doc.getValues(this.fieldName);
		if (values == null) {
			// if the field isn't present, there are 0 values;
			bumpCounter(0);
		} else {
			bumpCounter(values.length);
		}
	}

	private void bumpCounter(final int which) {
		if (which > largestNumberOfValues) {
			largestNumberOfValues = which;
		}

		if (which < MAX_COUNTER) {
			counters[which]++;
		} else {
			overmaxCounter++;
		}
	}

	@Override
	public void print(PrintWriter writer) {
		writer.print("FieldFrequency for '" + this.fieldName + "' -- ");

		for (int i = 0; i < counters.length; i++) {
			if (counters[i] != 0) {
				writer.print(i + ": " + counters[i] + "  ");
			}
		}

		if (overmaxCounter > 0) {
			writer.print("more: " + overmaxCounter + " (largest count="
					+ largestNumberOfValues + ")");
		}

		writer.println();
		writer.println();
	}

}
