/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package org.nsdl.search.utilities.lucenescan.fieldvaluesdetails;

import java.io.IOException;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import org.nsdl.search.utilities.lucenescan.DocumentScanner;
import org.nsdl.search.utilities.lucenescan.LuceneScan;
import org.nsdl.search.utilities.lucenescan.LuceneScanArguments;
import org.nsdl.search.utilities.lucenescan.LuceneScanStats;
import org.nsdl.search.utilities.lucenescan.LuceneScanUsageException;

/**
 * Specify one or more field names and an optional maximum number of values, and
 * see the raw values for those fields, along with the url and update date on
 * each document that contains the field.
 * 
 * @author jblake
 */
public class FieldValuesDetails extends LuceneScan {
	private static final int MAX_VALUES = 5000;
	private static final String OPTION_MAX_VALUES = "-maxValues";

	private final int maxValues;
	private final FVDScanner[] scanners;

	public FieldValuesDetails(Map<String, String> options)
			throws LuceneScanUsageException, IOException {
		this.maxValues = getMaxValuesFromOptions(options);
		this.scanners = getFieldValuesScanners(options);
	}

	private int getMaxValuesFromOptions(Map<String, String> options)
			throws LuceneScanUsageException {
		String optionString = options.get(OPTION_MAX_VALUES);
		options.remove(OPTION_MAX_VALUES);
		if (optionString == null) {
			return MAX_VALUES;
		}
		try {
			return Integer.parseInt(optionString);
		} catch (NumberFormatException e) {
			throw new LuceneScanUsageException("'" + OPTION_MAX_VALUES
					+ "' option requires an integer value.", "");
		}
	}

	private FVDScanner[] getFieldValuesScanners(
			Map<String, String> options) throws LuceneScanUsageException {
		List<FVDScanner> list = new ArrayList<FVDScanner>();
		for (String name : getFieldNamesFromOptions(options)) {
			if (name.length() > 0) {
				list.add(new FVDScanner(name, this.maxValues));
			}
		}

		return list.toArray(new FVDScanner[list.size()]);
	}

	@Override
	protected DocumentScanner[] getScanners() {
		return this.scanners;
	}

	@Override
	protected void printFooter(LuceneScanStats stats, PrintWriter writer) {
	}

	@Override
	protected void printHeader(LuceneScanArguments arguments,
			LuceneScanStats stats, PrintWriter writer) {
	}

}
