/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package org.nsdl.search.utilities.lucenescan.fieldvalueshistogram;

import java.io.IOException;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import org.nsdl.search.utilities.lucenescan.DocumentScanner;
import org.nsdl.search.utilities.lucenescan.LuceneScan;
import org.nsdl.search.utilities.lucenescan.LuceneScanArguments;
import org.nsdl.search.utilities.lucenescan.LuceneScanStats;
import org.nsdl.search.utilities.lucenescan.LuceneScanUsageException;

/**
 * Look at one or more fields and make a histogram showing the frequency of
 * specific field values. The list of values may be truncated at 5000 (or some
 * such value), but if it is you will see a message to that effect.
 * 
 * @author jblake
 */
public class FieldValuesHistogram extends LuceneScan {
	private final FieldValuesScanner[] scanners;

	public FieldValuesHistogram(Map<String, String> options)
			throws LuceneScanUsageException, IOException {
		this.scanners = getFieldValuesScanners(options);
	}

	private FieldValuesScanner[] getFieldValuesScanners(
			Map<String, String> options) throws LuceneScanUsageException {
		List<FieldValuesScanner> list = new ArrayList<FieldValuesScanner>();
		String[] namesArray = getFieldNamesFromOptions(options);

		for (String name : namesArray) {
			if (name.length() > 0) {
				list.add(new FieldValuesScanner(name));
			}
		}

		return list.toArray(new FieldValuesScanner[list.size()]);
	}

	@Override
	protected DocumentScanner[] getScanners() {
		return this.scanners;
	}

	@Override
	protected void printFooter(LuceneScanStats stats, PrintWriter writer) {
	}

	@Override
	protected void printHeader(LuceneScanArguments arguments,
			LuceneScanStats stats, PrintWriter writer) {
	}

}
