/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package org.nsdl.search.utilities.lucenescan.missingfields;

import java.io.PrintWriter;

import org.apache.log4j.Logger;
import org.apache.lucene.document.Document;
import org.nsdl.search.utilities.lucenescan.DocumentScanner;

/**
 * 
 * @author jblake
 */
public class MissingFieldScanner extends DocumentScanner {
	@SuppressWarnings("unused")
	private static final Logger LOG = Logger
			.getLogger(MissingFieldScanner.class);

	private final PrintWriter outputWriter;
	private final String[] fieldNames;

	public MissingFieldScanner(PrintWriter outputWriter, String[] fieldNames) {
		this.outputWriter = outputWriter;
		this.fieldNames = fieldNames;
	}

	/**
	 * When a record comes in, look at the fields for each fieldname. If no
	 * fields are present for a name, or if all values are empty for that
	 * fieldname, write a message.
	 */
	@Override
	public void add(Document doc, PrintWriter writer) {
		for (String fieldName : fieldNames) {
			if (getValuesLength(doc, fieldName) == 0) {
				printMessage(doc, fieldName);
			}
		}
	}

	/**
	 * Get all of the fields with this name in this document, and add up the
	 * lengths of the field values.
	 */
	private int getValuesLength(Document doc, String fieldName) {
		String[] values = doc.getValues(fieldName);
		int valueLength = 0;
		if (values != null) {
			for (String value : values) {
				if (value != null) {
					valueLength += value.length();
				}
			}
		}
		return valueLength;
	}

	/**
	 * The field we looked for was missing and/or empty. Complain.
	 */
	private void printMessage(Document doc, String fieldName) {
		outputWriter.println("'" + fieldName + "' missing for '"
				+ getResourceIdentifier(doc, "NO IDENTIFIER") + "'");
	}

	@Override
	public void print(PrintWriter writer) {
	}
}
