/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package org.nsdl.search.utilities.lucenescan.normalizerdump;

import java.io.PrintWriter;
import java.util.Arrays;

import org.apache.log4j.Logger;
import org.apache.lucene.document.Document;
import org.nsdl.search.utilities.lucenescan.DocumentScanner;

/**
 * 
 * @author jblake
 */
public class NormalizedUrlScanner extends DocumentScanner {
	private static final Logger LOG = Logger
			.getLogger(NormalizedUrlScanner.class);

	private final PrintWriter outputWriter;

	public NormalizedUrlScanner(PrintWriter outputWriter) {
		this.outputWriter = outputWriter;
	}

	/**
	 * Compare the resourceIdentifier to the raw URLs in the metadata sources.
	 * If they are different, print them.
	 */
	@Override
	public void add(Document doc, PrintWriter writer) {
		String[] ids = doc.getValues("resourceIdentifier");
		if ((ids == null) || (ids.length == 0)) {
			LOG.warn("Document has no resourceIdentifier: " + doc);
			return;
		}
		String resourceIdentifier = ids[0];

		String[] sources = doc.getValues("metadataSource");
		if ((sources == null) || (sources.length == 0)) {
			LOG.warn("Document has no metadataSource: " + doc);
			return;
		}

		for (String sourceField : sources) {
			String[] parts = sourceField.split(" ~\\^ ");
			if (parts.length != 3) {
				LOG.warn("Can't parse metadataSource field: '" + sourceField
						+ "' to parts: " + Arrays.deepToString(parts));
				return;
			}
			String rawUrl = parts[2];

			if (!rawUrl.equals(resourceIdentifier)) {
				outputWriter.println(resourceIdentifier + " " + rawUrl);
			}
		}

	}

	public void print(PrintWriter writer) {
	}

}
