/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package org.nsdl.search.utilities.lucenescan.protocolcounter;

import java.io.PrintWriter;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

import org.apache.lucene.document.Document;
import org.apache.lucene.document.Field;
import org.nsdl.search.utilities.data.DiscreteValuesHistogram;
import org.nsdl.search.utilities.data.Histogram.Bucket;
import org.nsdl.search.utilities.lucenescan.DocumentScanner;

/**
 * 
 * @author jblake
 */
public class ProtocolCountScanner extends DocumentScanner {
	private final DiscreteValuesHistogram<String> protocolCounts;
	private final Pattern pattern;
	private int recordCount;

	ProtocolCountScanner() {
		this.protocolCounts = new DiscreteValuesHistogram<String>();
		this.pattern = Pattern.compile("([^:/]*)://.*");
	}

	/**
	 * Check the resource identifier for each document, and find out what
	 * protocol the URL has. Tally the protocol, or if we can't find one, tally
	 * that too.
	 */
	public void add(Document doc, PrintWriter writer) {
		recordCount++;

		Field[] fields = doc.getFields("resourceIdentifier");
		if (fields != null) {
			for (Field field : fields) {
				Matcher matcher = pattern.matcher(field.stringValue());
				if (matcher.find()) {
					protocolCounts.countThis(matcher.group(1));
				} else {
					protocolCounts.countThis("_unknown_");
				}
			}
		}
	}

	/**
	 * Print the results.
	 */
	public void print(PrintWriter writer) {
		writer.println("Protocol counts for " + recordCount + " records.");
		writer.println("---------------------------------------");
		for (Bucket bucket : protocolCounts.getBuckets()) {
			writer.format("%1$,12d -- '%2$s'\n", bucket.getCount(), bucket
					.getLegend());
		}
	}

}
