/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package org.nsdl.search.utilities.lucenescan.recorddumper;

import java.io.PrintWriter;
import java.util.Enumeration;
import java.util.List;
import java.util.regex.Pattern;

import org.apache.lucene.document.Document;
import org.apache.lucene.document.Field;
import org.nsdl.search.utilities.data.FieldHelper;
import org.nsdl.search.utilities.lucenescan.DocumentScanner;

/**
 * Do a full dump of all records whose identifiers match the provided list, or
 * match the regular expression.
 * 
 * @author jblake
 */
public class RecordDumpScanner extends DocumentScanner {
	private final List<String> identifiers;
	private final Pattern pattern;

	public RecordDumpScanner(List<String> identifiers, Pattern pattern) {
		this.identifiers = identifiers;
		this.pattern = pattern;
	}

	public void add(Document doc, PrintWriter writer) {
		Field[] fields = doc.getFields("resourceIdentifier");
		for (String fieldValue : FieldHelper.parseFieldValues(fields)) {
			if (identifiers.contains(fieldValue)) {
				dumpRecord(fieldValue, doc, writer);
				break;
			}
			if (pattern.matcher(fieldValue).find()) {
				dumpRecord(fieldValue, doc, writer);
				break;
			}
		}
	}

	private void dumpRecord(String identifier, Document doc, PrintWriter writer) {
		writer.println("Dump record " + identifier);
		Enumeration<Field> fields = getFieldsFromDocument(doc);
		while (fields.hasMoreElements()) {
			Field field = fields.nextElement();
			writer.println(field);
		}
		writer.println();
	}

	public void print(PrintWriter writer) {
	}

}
