/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package org.nsdl.search.utilities.lucenescan.recorddumper;

import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.regex.Pattern;

import org.nsdl.search.utilities.lucenescan.DocumentScanner;
import org.nsdl.search.utilities.lucenescan.LuceneScan;
import org.nsdl.search.utilities.lucenescan.LuceneScanArguments;
import org.nsdl.search.utilities.lucenescan.LuceneScanStats;
import org.nsdl.search.utilities.lucenescan.LuceneScanUsageException;

/**
 * 
 * @author jblake
 */
public class RecordDumper extends LuceneScan {
	private static final String OPTION_IDENTIFIER = "-identifier";

	private final List<String> identifiers;
	private final Pattern pattern;
	private final RecordDumpScanner scanner;

	public RecordDumper(Map<String, String> options)
			throws LuceneScanUsageException {
		String values = options.get(OPTION_IDENTIFIER);
		options.remove(OPTION_IDENTIFIER);

		String patternString = getPatternFromOptions(options);

		if ((values == null) && (patternString == null)) {
			throw new LuceneScanUsageException("Requires either '"
					+ OPTION_IDENTIFIER + "' or '" + OPTION_PATTERN
					+ "' option.", "BOGUS USAGE MESSAGE");
			// KLUGE how to do the real usage message for sub-options?
		}
		if (LuceneScanArguments.NO_VALUE.equals(values)) {
			throw new LuceneScanUsageException("'" + OPTION_IDENTIFIER
					+ "' option requires a value.", "");
			// KLUGE ditto.
		}

		if (values == null) {
			this.identifiers = new ArrayList<String>();
		} else {
			this.identifiers = new ArrayList<String>(Arrays.asList(values
					.split(",")));
		}
		this.pattern = (patternString == null) ? null : Pattern
				.compile(patternString);

		this.scanner = new RecordDumpScanner(identifiers, pattern);
	}

	@Override
	protected DocumentScanner[] getScanners() {
		return new DocumentScanner[] { this.scanner };
	}

	@Override
	protected void printFooter(LuceneScanStats stats, PrintWriter writer) {
	}

	@Override
	protected void printHeader(LuceneScanArguments arguments,
			LuceneScanStats stats, PrintWriter writer) {
		if (identifiers.size() > 0) {
			String message = "Dumping records with these identifiers\n"
					+ identifiers;
			if (pattern == null) {
				message += "\nor with identifiers matching this pattern: "
						+ pattern;
			}
			writer.println(message);
		} else {
			writer.println("Dumping records with identifiers matching "
					+ "this pattern: " + pattern);
		}
	}
}
