/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package org.nsdl.search.utilities.lucenescan.recordsbyvalue;

import java.io.PrintWriter;
import java.util.Arrays;
import java.util.List;
import java.util.Map;

import org.nsdl.search.utilities.lucenescan.DocumentScanner;
import org.nsdl.search.utilities.lucenescan.LuceneScan;
import org.nsdl.search.utilities.lucenescan.LuceneScanArguments;
import org.nsdl.search.utilities.lucenescan.LuceneScanStats;
import org.nsdl.search.utilities.lucenescan.LuceneScanUsageException;

/**
 * Identify all records that have the specifed value in the specified fields.
 */
public class RecordsByValue extends LuceneScan {
	private static final String OPTION_VALUE = "-value";

	private final RecordsByValueScanner scanner;
	private final List<String> fields;
	private final String matcher;
	private final boolean isPattern;

	public RecordsByValue(Map<String, String> options)
			throws LuceneScanUsageException {
		this.fields = Arrays.asList(getFieldNamesFromOptions(options));
		String pattern = getPatternFromOptions(options);

		String value = options.get(OPTION_VALUE);
		options.remove(OPTION_VALUE);

		if ((value == null) && (pattern == null)) {
			throw new LuceneScanUsageException("Must have either a '"
					+ OPTION_VALUE + "' option or a '" + OPTION_PATTERN
					+ "' option.", "BOGUS USAGE MESSAGE");
			// KLUGE how to do the real usage message for sub-options?
		} else if ((value != null) && (pattern != null)) {
			throw new LuceneScanUsageException("Must not have both a '"
					+ OPTION_VALUE + "' option and a '" + OPTION_PATTERN
					+ "' option.", "BOGUS USAGE MESSAGE");
			// KLUGE how to do the real usage message for sub-options?
		} else

		if (value == null) {
			this.matcher = pattern;
			this.isPattern = true;
		} else {
			this.matcher = value;
			this.isPattern = false;
		}

		scanner = new RecordsByValueScanner(fields, this.matcher,
				this.isPattern);

	}

	@Override
	protected DocumentScanner[] getScanners() {
		return new DocumentScanner[] { scanner };
	}

	@Override
	protected void printFooter(LuceneScanStats stats, PrintWriter writer) {
	}

	@Override
	protected void printHeader(LuceneScanArguments arguments,
			LuceneScanStats stats, PrintWriter writer) {
		String message = "Looking for records where ";
		message += (fields.size() > 1) ? "these fields: " : "this field: ";
		message += fields;
		if (isPattern) {
			message += " matches this pattern: '" + matcher + "'";
		} else {
			message += " equals this value: '" + matcher + "'";
		}
		writer.println(message);
		writer.println();
	}

}
