/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package org.nsdl.search.utilities.lucenescan.recordsbyvalue;

import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.List;
import java.util.regex.Pattern;

import org.apache.lucene.document.Document;
import org.nsdl.search.utilities.data.FieldHelper;
import org.nsdl.search.utilities.lucenescan.DocumentScanner;

/**
 * List all records if any field in the record is equal to the specified value,
 * or matches the specified pattern.
 * 
 * @author jblake
 */
public class RecordsByValueScanner extends DocumentScanner {
	private final List<String> fields;
	private final String value;
	private final Pattern pattern;

	public RecordsByValueScanner(List<String> fields, String criterion,
			boolean isPattern) {
		this.fields = fields;
		if (isPattern) {
			this.value = null;
			this.pattern = Pattern.compile(criterion);
		} else {
			this.value = criterion;
			this.pattern = null;
		}

	}

	public void add(Document doc, PrintWriter writer) {
		List<String> fieldValues = new ArrayList<String>();
		for (String fieldName : fields) {
			fieldValues.addAll(FieldHelper.parseFieldValues(doc, fieldName));
		}
		// Don't write a document more than once, no matter how many fields
		// match.
		for (String fieldValue : fieldValues) {
			if ((value != null) && (value.equals(fieldValue))) {
				writeDocId(doc, writer);
				break;
			} else if ((pattern != null)
					&& (pattern.matcher(fieldValue).find())) {
				writeDocId(doc, writer);
				break;
			}
		}
	}

	private void writeDocId(Document doc, PrintWriter writer) {
		String idField = "resourceIdentifier";
		for (String id : FieldHelper.parseFieldValues(doc, idField)) {
			writer.println(id);
			break;
		}
	}

	public void print(PrintWriter writer) {
	}

}
