/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package org.nsdl.search.utilities.lucenescan.specificfieldvalues;

import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import org.nsdl.search.utilities.lucenescan.DocumentScanner;
import org.nsdl.search.utilities.lucenescan.LuceneScan;
import org.nsdl.search.utilities.lucenescan.LuceneScanArguments;
import org.nsdl.search.utilities.lucenescan.LuceneScanStats;
import org.nsdl.search.utilities.lucenescan.LuceneScanUsageException;

/**
 * 
 * @author jblake
 */
public class SpecificFieldValues extends LuceneScan {
	private static final String OPTION_SPECIFIC_VALUES = "-specificValues";

	private final List<SpecificValuesScanner> scanners = new ArrayList<SpecificValuesScanner>();

	public SpecificFieldValues(Map<String, String> options)
			throws LuceneScanUsageException {
		String[] names = getFieldNamesFromOptions(options);
		String[] values = getSpecificValuesFromOptions(options);

		for (String name : names) {
			if (name.length() > 0) {
				scanners.add(new SpecificValuesScanner(name, values));
			}
		}

	}

	/**
	 * Get an array of specific values from the option -specificValues. This
	 * field will contain a set of values delimited by commas (but not blanks).
	 * 
	 * Any underscored will be interpreted as blanks, so if you want to search
	 * for the value "higher education", it would be coded as
	 * "higher_education".
	 * 
	 * @param options
	 * @return the values that were found.
	 */
	protected String[] getSpecificValuesFromOptions(Map<String, String> options)
			throws LuceneScanUsageException {
		String values = options.get(OPTION_SPECIFIC_VALUES);
		options.remove(OPTION_SPECIFIC_VALUES);

		if (values == null) {
			throw new LuceneScanUsageException("The '" + OPTION_SPECIFIC_VALUES
					+ "' option is required.", "BOGUS USAGE MESSAGE");
			// KLUGE how to do the real usage message for sub-options?
		}
		if (LuceneScanArguments.NO_VALUE.equals(values)) {
			throw new LuceneScanUsageException("'" + OPTION_SPECIFIC_VALUES
					+ "' option requires a value.", "");
			// KLUGE ditto.
		}
		return values.replace('_', ' ').split(",");
	}

	@Override
	protected DocumentScanner[] getScanners() {
		return scanners.toArray(new SpecificValuesScanner[scanners.size()]);
	}

	@Override
	protected void printFooter(LuceneScanStats stats, PrintWriter writer) {
	}

	@Override
	protected void printHeader(LuceneScanArguments arguments,
			LuceneScanStats stats, PrintWriter writer) {
	}

}
