/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package org.nsdl.search.utilities.lucenescan.urldumper;

import java.io.PrintWriter;
import java.util.Random;

import org.apache.log4j.Logger;
import org.apache.lucene.document.Document;
import org.nsdl.search.utilities.lucenescan.DocumentScanner;

/**
 * This doesn't accumulate any statistics or anything. It just prints out the
 * resource identifier, or URL of the Lucene document.
 * 
 * @author jblake
 */
public class URLDumpScanner extends DocumentScanner {
	private static final Logger log4j = Logger.getLogger(URLDumpScanner.class);

	private final PrintWriter outputWriter;
	private final int sampleRate;
	private final Random randomizer;

	URLDumpScanner(PrintWriter outputWriter, int sampleRate) {
		this.outputWriter = outputWriter;
		this.sampleRate = sampleRate;

		if (sampleRate >= 2) {
			this.randomizer = new Random();
		} else {
			this.randomizer = null;
		}
	}

	public void add(Document doc, PrintWriter writer) {
		if (sampled()) {
			String[] values = doc.getValues("resourceIdentifier");
			if ((values != null) && (values.length > 0)) {
				this.outputWriter.println(values[0]);
			}

			if (log4j.isDebugEnabled()) {
				if (values == null) {
					log4j.debug("no resource identifier!");
				} else if (values.length == 1) {
					log4j.debug("1 resource identifier");
				} else {
					log4j.debug(values.length + " resource identifiers");
				}
			}
		}
	}

	public void print(PrintWriter writer) {
	}

	/**
	 * Dump the record if we are not randomizing, or if the randomizing pays
	 * off.
	 */
	private boolean sampled() {
		return (randomizer == null) || (randomizer.nextInt(sampleRate) == 0);
	}
}
