/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package org.nsdl.search.utilities.summary;

import java.io.PrintWriter;
import java.util.HashSet;
import java.util.Set;

import org.apache.log4j.Logger;
import org.apache.lucene.document.Document;

/**
 * Reads the URL from the ResourceIdentifier field and checks for duplicates.
 * 
 * @author jblake
 */
public class UrlUniquenessTester implements SummaryInfo {
	private static final Logger LOG = Logger
			.getLogger(UrlUniquenessTester.class);

	private final Set<String> urlSet = new HashSet<String>();

	private int recordCount;

	private int duplicateUrlCount;

	private int missingUrlCount;

	/**
	 * Tally the records as we read them. For each record, check the URL in the
	 * resourceIdentifier field, and log an error if it duplicates an earlier
	 * record.
	 */
	public void add(Document doc) {
		recordCount++;

		String[] urls = doc.getValues("resourceIdentifier");

		if ((urls == null) || (urls.length == 0)) {
			missingUrlCount++;
			return;
		}

		String url = urls[0];
		if (urlSet.contains(url)) {
			duplicateUrlCount++;
			LOG.error("Duplicate 'resourceIdentifier' field: " + url);
			return;
		}

		urlSet.add(url);
	}

	/**
	 * Print a summary of what we found.
	 */
	public void print(PrintWriter writer) {
		writer.println("UrlUniquenessTester: found " + duplicateUrlCount
				+ " duplicates and " + missingUrlCount
				+ " missing resourceIdentifier fields in " + recordCount
				+ " records.");
		writer.println();
	}
}
