/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package org.nsdl.search.utilities.updatecontent;

/**
 * Simple data about how many pages were updated with fresh contents.
 * 
 * @author jblake
 */
public class UpdateContentStats {
	/** How many change files were processed in this directory? */
	private int fileCount;

	/** How many URLs did the change files contain, total? */
	private int urlCount;

	/** How many change lines were older than their docs in the search index? */
	private int outdatedCount;

	/** How many change lines referred to URLs that were not in the index? */
	private int unknownCount;

	public int getUrlCount() {
		return urlCount;
	}

	public void incrementUrlCount() {
		urlCount++;
	}

	public int getOutdatedCount() {
		return outdatedCount;
	}

	public void incrementOutdatedCount() {
		outdatedCount++;
	}

	public int getUnknownCount() {
		return unknownCount;
	}

	public void incrementUnknownCount() {
		unknownCount++;
	}

	public int getFileCount() {
		return fileCount;
	}

	public void incrementFileCount() {
		fileCount++;
	}

	public int getActiveCount() {
		return urlCount - outdatedCount - unknownCount;
	}
}
