/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DCT_AUDIENCE;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DC_CREATOR;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DC_DESCRIPTION;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DC_FORMAT_IMT;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DC_LANGUAGE_RFC3066;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DC_PUBLISHER;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DC_SUBJECT_GEM;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DC_TITLE;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DC_TYPE_DCMITYPE;

import java.io.IOException;

import org.nsdl.search.lucene.SearchIndexFieldSpecs;
import org.nsdl.search.lucene.searchdoc.SearchDocument;
import org.nsdl.search.lucene.searchdoc.SearchDocumentMetadata;
import org.nsdl.search.lucene.wrapper.IndexWrapper;
import org.nsdl.search.lucene.wrapper.IndexWrapperConfig;
import org.nsdl.search.processoai.OaiCollectionInfo;
import org.nsdl.search.util.Config;

/**
 * Create some silly index that I can test against.
 * 
 * @author jblake
 */
public class FirstIndexCreator {
	private FirstIndexCreator() throws IOException {
		Config.getInstance().setIndexWrapperConfig(new MyConfigObject());

		OaiCollectionInfo theCollectionInfo = new OaiCollectionInfo(
				"oai:nsdl.org:crs:487693",
				"http://crs.nsdl.org/brands/487693.jpg", "100", "35",
				"Scientific American: Issue Archive");

		SearchDocumentMetadata theMetadata = new SearchDocumentMetadata(
				"oai:nsdl.org:2200-20061003233803665T",
				"http://www.sciamdigital.com/browse.cfm"
						+ "?sequencenameCHAR=item2"
						+ "&methodnameCHAR=resource_getitembrowse"
						+ "&interfacenameCHAR=browse.cfm"
						+ "&ISSUEID_CHAR=AB9F2CB9-ADA7-E562-F463B0CFD31518DE"
						+ "&ARTICLEID_CHAR=AF1FABF5-FEC3-93E4-F9C0FC5CDAE77C3B");
		theMetadata.addFieldValue(DC_CREATOR,
				"Andrew R. Blaustein and Pieter T.J. Johnson");
		theMetadata.addFieldValue(DC_DESCRIPTION, "ONE HOT SUMMER "
				+ "DAY in 1995 eight middle school children planning a simple "
				+ "study of wetland ecology began collecting leopard frogs "
				+ "from a small pond near Henderson, Minn. To their "
				+ "astonishment, one captured frog after another had five or "
				+ "more hind legs, some twisted in macabre contortions. Of "
				+ "the 22 animals they caught that day, half were severely "
				+ "deformed. A follow-up search by pollutioncontrol officials "
				+ "added to the gruesome inventory. Occasional frogs in the "
				+ "pond had no hind limbs at all or had mere nubbins where "
				+ "legs should be; others had one or two legs sprouting from "
				+ "the stomach. A few lacked an eye.The story seized "
				+ "national media attention and raised many questions-among "
				+ "them, was this an isolated occurrence or one facet of a "
				+ "widespread trend? And what caused the deformities? As "
				+ "researchers elsewhere in the country began investigating "
				+ "their local amphibian populations, it became clear that "
				+ "this bizarre collection of ailments was not confined to "
				+ "Minnesota. Since 1995, malformations have been reported in "
				+ "more than 60 species, including salamanders and toads, in "
				+ "46 states. In some local populations 80 percent of the "
				+ "animals are afflicted. International reports show that "
				+ "this phenomenon extends beyond the U.S. Surprising numbers "
				+ "of deformed amphibians have been found in Asia, Europe and "
				+ "Australia as well. Worldwide, extra legs and missing legs "
				+ "are most common.");
		theMetadata.addFieldValue(DC_FORMAT_IMT, "application/pdf");
		theMetadata.addFieldValue(DC_LANGUAGE_RFC3066, "en");
		theMetadata.addFieldValue(DC_PUBLISHER, "Scientific American, Inc.");
		theMetadata.addFieldValue(DC_SUBJECT_GEM, "Science");
		theMetadata.addFieldValue(DC_TITLE, "Explaining Frog Deformities");
		theMetadata.addFieldValue(DC_TYPE_DCMITYPE, "Text");
		theMetadata.addFieldValue(DCT_AUDIENCE, "Lifelong Learner");
		theMetadata.setCollInfo(theCollectionInfo);

		SearchDocument theDoc = new SearchDocument(
				"http://www.sciamdigital.com/browse.cfm"
						+ "?sequencenameCHAR=item2"
						+ "&methodnameCHAR=resource_getitembrowse"
						+ "&interfacenameCHAR=browse.cfm"
						+ "&ISSUEID_CHAR=AB9F2CB9-ADA7-E562-F463B0CFD31518DE"
						+ "&ARTICLEID_CHAR=AF1FABF5-FEC3-93E4-F9C0FC5CDAE77C3B");
		theDoc.addMetadataSource(theMetadata);

		IndexWrapper index = IndexWrapper.getInstance();
		index.createIndex();
		index.writeDocument(theDoc);
	}
	public static void main(String[] args) throws IOException {
		new FirstIndexCreator();
	}

	/**
	 * A Config object so I can use the {@link IndexWrapper}.
	 */
	private static class MyConfigObject implements IndexWrapperConfig {
		public String getDocIdFieldName() {
			return SearchIndexFieldSpecs.RESOURCE_IDENTIFIER.getName();
		}
		public String getLuceneIndexDirectory() {
			return "C:\\Search_stuff\\Search3\\luceneIndex";
		}
		public long getInactivityThreshold() {
			return 1000;
		}
		public int getMaximumCachedWrites() {
			return 0;
		}

	}
}
