/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package mock.org.w3c.dom;

import org.w3c.dom.Attr;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.NamedNodeMap;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;
import org.w3c.dom.TypeInfo;
import org.w3c.dom.UserDataHandler;

/**
 * 
 * @author jblake
 */
public class MockAttr implements Node, Attr {

	// ----------------------------------------------------------------------
	// Mocking infrastructure
	// ----------------------------------------------------------------------

	private final String value;

	public MockAttr(String value) {
		this.value = value;
	}

	// ----------------------------------------------------------------------
	// Mocked methods
	// ----------------------------------------------------------------------

	public String getNodeValue() {
		return this.value;
	}

	public String getValue() {
		return this.value;
	}

	// ----------------------------------------------------------------------
	// Un-implemented methods
	// ----------------------------------------------------------------------

	public Node appendChild(Node newChild) {
		throw new RuntimeException("MockAttr.appendChild() not implemented.");
	}

	public Node cloneNode(boolean deep) {
		throw new RuntimeException("MockAttr.cloneNode() not implemented.");
	}

	public short compareDocumentPosition(Node other) {
		throw new RuntimeException(
				"MockAttr.compareDocumentPosition() not implemented.");
	}

	public NamedNodeMap getAttributes() {
		throw new RuntimeException("MockAttr.getAttributes() not implemented.");
	}

	public String getBaseURI() {
		throw new RuntimeException("MockAttr.getBaseURI() not implemented.");
	}

	public NodeList getChildNodes() {
		throw new RuntimeException("MockAttr.getChildNodes() not implemented.");
	}

	public Object getFeature(String feature, String version) {
		throw new RuntimeException("MockAttr.getFeature() not implemented.");
	}

	public Node getFirstChild() {
		throw new RuntimeException("MockAttr.getFirstChild() not implemented.");
	}

	public Node getLastChild() {
		throw new RuntimeException("MockAttr.getLastChild() not implemented.");
	}

	public String getLocalName() {
		throw new RuntimeException("MockAttr.getLocalName() not implemented.");
	}

	public String getNamespaceURI() {
		throw new RuntimeException(
				"MockAttr.getNamespaceURI() not implemented.");
	}

	public Node getNextSibling() {
		throw new RuntimeException("MockAttr.getNextSibling() not implemented.");
	}

	public String getNodeName() {
		throw new RuntimeException("MockAttr.getNodeName() not implemented.");
	}

	public short getNodeType() {
		throw new RuntimeException("MockAttr.getNodeType() not implemented.");
	}

	public Document getOwnerDocument() {
		throw new RuntimeException(
				"MockAttr.getOwnerDocument() not implemented.");
	}

	public Node getParentNode() {
		throw new RuntimeException("MockAttr.getParentNode() not implemented.");
	}

	public String getPrefix() {
		throw new RuntimeException("MockAttr.getPrefix() not implemented.");
	}

	public Node getPreviousSibling() {
		throw new RuntimeException(
				"MockAttr.getPreviousSibling() not implemented.");
	}

	public String getTextContent() {
		throw new RuntimeException("MockAttr.getTextContent() not implemented.");
	}

	public Object getUserData(String key) {
		throw new RuntimeException("MockAttr.getUserData() not implemented.");
	}

	public boolean hasAttributes() {
		throw new RuntimeException("MockAttr.hasAttributes() not implemented.");
	}

	public boolean hasChildNodes() {
		throw new RuntimeException("MockAttr.hasChildNodes() not implemented.");
	}

	public Node insertBefore(Node newChild, Node refChild) {
		throw new RuntimeException("MockAttr.insertBefore() not implemented.");
	}

	public boolean isDefaultNamespace(String namespaceURI) {
		throw new RuntimeException(
				"MockAttr.isDefaultNamespace() not implemented.");
	}

	public boolean isEqualNode(Node arg) {
		throw new RuntimeException("MockAttr.isEqualNode() not implemented.");
	}

	public boolean isSameNode(Node other) {
		throw new RuntimeException("MockAttr.isSameNode() not implemented.");
	}

	public boolean isSupported(String feature, String version) {
		throw new RuntimeException("MockAttr.isSupported() not implemented.");
	}

	public String lookupNamespaceURI(String prefix) {
		throw new RuntimeException(
				"MockAttr.lookupNamespaceURI() not implemented.");
	}

	public String lookupPrefix(String namespaceURI) {
		throw new RuntimeException("MockAttr.lookupPrefix() not implemented.");
	}

	public void normalize() {
		throw new RuntimeException("MockAttr.normalize() not implemented.");
	}

	public Node removeChild(Node oldChild) {
		throw new RuntimeException("MockAttr.removeChild() not implemented.");
	}

	public Node replaceChild(Node newChild, Node oldChild) {
		throw new RuntimeException("MockAttr.replaceChild() not implemented.");
	}

	public void setNodeValue(String nodeValue) {
		throw new RuntimeException("MockAttr.setNodeValue() not implemented.");
	}

	public void setPrefix(String prefix) {
		throw new RuntimeException("MockAttr.setPrefix() not implemented.");
	}

	public void setTextContent(String textContent) {
		throw new RuntimeException("MockAttr.setTextContent() not implemented.");
	}

	public Object setUserData(String key, Object data, UserDataHandler handler) {
		throw new RuntimeException("MockAttr.setUserData() not implemented.");
	}

	public String getName() {
		throw new RuntimeException("MockAttr.getName() not implemented.");
	}

	public Element getOwnerElement() {
		throw new RuntimeException(
				"MockAttr.getOwnerElement() not implemented.");
	}

	public TypeInfo getSchemaTypeInfo() {
		throw new RuntimeException(
				"MockAttr.getSchemaTypeInfo() not implemented.");
	}

	public boolean getSpecified() {
		throw new RuntimeException("MockAttr.getSpecified() not implemented.");
	}

	public boolean isId() {
		throw new RuntimeException("MockAttr.isId() not implemented.");
	}

	public void setValue(String value) {
		throw new RuntimeException("MockAttr.setValue() not implemented.");
	}

}
