/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package mock.org.w3c.dom;

import java.util.Collections;
import java.util.HashMap;
import java.util.Map;

import org.w3c.dom.NamedNodeMap;
import org.w3c.dom.Node;

/**
 * 
 * @author jblake
 */
public class MockNamedNodeMap implements NamedNodeMap {

	// ----------------------------------------------------------------------
	// Mocking infrastructure
	// ----------------------------------------------------------------------

	private final Map<String, String> attributes;

	public MockNamedNodeMap(Map<String, String> attributes) {
		this.attributes = Collections
				.unmodifiableMap(new HashMap<String, String>(attributes));
	}

	// ----------------------------------------------------------------------
	// Mocked methods
	// ----------------------------------------------------------------------

	public Node getNamedItem(String key) {
		if (attributes.containsKey(key)) {
			return new MockAttr(attributes.get(key));
		} else {
			return null;
		}
	}

	// ----------------------------------------------------------------------
	// Un-implemented methods
	// ----------------------------------------------------------------------

	public int getLength() {
		throw new RuntimeException(
				"MockNamedNodeMap.getLength() not implemented.");
	}

	public Node getNamedItemNS(String arg0, String arg1) {
		throw new RuntimeException(
				"MockNamedNodeMap.getNamedItemNS() not implemented.");
	}

	public Node item(int arg0) {
		throw new RuntimeException("MockNamedNodeMap.item() not implemented.");
	}

	public Node removeNamedItem(String arg0) {
		throw new RuntimeException(
				"MockNamedNodeMap.removeNamedItem() not implemented.");
	}

	public Node removeNamedItemNS(String arg0, String arg1) {
		throw new RuntimeException(
				"MockNamedNodeMap.removeNamedItemNS() not implemented.");
	}

	public Node setNamedItem(Node arg0) {
		throw new RuntimeException(
				"MockNamedNodeMap.setNamedItem() not implemented.");
	}

	public Node setNamedItemNS(Node arg0) {
		throw new RuntimeException(
				"MockNamedNodeMap.setNamedItemNS() not implemented.");
	}

}
