/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package mock.org.w3c.dom;

import org.w3c.dom.Document;
import org.w3c.dom.NamedNodeMap;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;
import org.w3c.dom.Text;
import org.w3c.dom.UserDataHandler;

/**
 * 
 * @author jblake
 */
public class MockText implements Node, Text {

	// ----------------------------------------------------------------------
	// Mocking infrastructure
	// ----------------------------------------------------------------------

	private final String textValue;

	public MockText(String textValue) {
		this.textValue = textValue;
	}

	// ----------------------------------------------------------------------
	// Mocked methods
	// ----------------------------------------------------------------------

	public short getNodeType() {
		return Node.TEXT_NODE;
	}

	public String getNodeValue() {
		return this.textValue;
	}

	// ----------------------------------------------------------------------
	// Un-implemented methods
	// ----------------------------------------------------------------------

	public Node appendChild(Node newChild) {
		throw new RuntimeException("MockText.appendChild() not implemented.");
	}

	public Node cloneNode(boolean deep) {
		throw new RuntimeException("MockText.cloneNode() not implemented.");
	}

	public short compareDocumentPosition(Node other) {
		throw new RuntimeException(
				"MockText.compareDocumentPosition() not implemented.");
	}

	public NamedNodeMap getAttributes() {
		throw new RuntimeException("MockText.getAttributes() not implemented.");
	}

	public String getBaseURI() {
		throw new RuntimeException("MockText.getBaseURI() not implemented.");
	}

	public NodeList getChildNodes() {
		throw new RuntimeException("MockText.getChildNodes() not implemented.");
	}

	public Object getFeature(String feature, String version) {
		throw new RuntimeException("MockText.getFeature() not implemented.");
	}

	public Node getFirstChild() {
		throw new RuntimeException("MockText.getFirstChild() not implemented.");
	}

	public Node getLastChild() {
		throw new RuntimeException("MockText.getLastChild() not implemented.");
	}

	public String getLocalName() {
		throw new RuntimeException("MockText.getLocalName() not implemented.");
	}

	public String getNamespaceURI() {
		throw new RuntimeException(
				"MockText.getNamespaceURI() not implemented.");
	}

	public Node getNextSibling() {
		throw new RuntimeException("MockText.getNextSibling() not implemented.");
	}

	public String getNodeName() {
		throw new RuntimeException("MockText.getNodeName() not implemented.");
	}

	public Document getOwnerDocument() {
		throw new RuntimeException(
				"MockText.getOwnerDocument() not implemented.");
	}

	public Node getParentNode() {
		throw new RuntimeException("MockText.getParentNode() not implemented.");
	}

	public String getPrefix() {
		throw new RuntimeException("MockText.getPrefix() not implemented.");
	}

	public Node getPreviousSibling() {
		throw new RuntimeException(
				"MockText.getPreviousSibling() not implemented.");
	}

	public String getTextContent() {
		throw new RuntimeException("MockText.getTextContent() not implemented.");
	}

	public Object getUserData(String key) {
		throw new RuntimeException("MockText.getUserData() not implemented.");
	}

	public boolean hasAttributes() {
		throw new RuntimeException("MockText.hasAttributes() not implemented.");
	}

	public boolean hasChildNodes() {
		throw new RuntimeException("MockText.hasChildNodes() not implemented.");
	}

	public Node insertBefore(Node newChild, Node refChild) {
		throw new RuntimeException("MockText.insertBefore() not implemented.");
	}

	public boolean isDefaultNamespace(String namespaceURI) {
		throw new RuntimeException(
				"MockText.isDefaultNamespace() not implemented.");
	}

	public boolean isEqualNode(Node arg) {
		throw new RuntimeException("MockText.isEqualNode() not implemented.");
	}

	public boolean isSameNode(Node other) {
		throw new RuntimeException("MockText.isSameNode() not implemented.");
	}

	public boolean isSupported(String feature, String version) {
		throw new RuntimeException("MockText.isSupported() not implemented.");
	}

	public String lookupNamespaceURI(String prefix) {
		throw new RuntimeException(
				"MockText.lookupNamespaceURI() not implemented.");
	}

	public String lookupPrefix(String namespaceURI) {
		throw new RuntimeException("MockText.lookupPrefix() not implemented.");
	}

	public void normalize() {
		throw new RuntimeException("MockText.normalize() not implemented.");
	}

	public Node removeChild(Node oldChild) {
		throw new RuntimeException("MockText.removeChild() not implemented.");
	}

	public Node replaceChild(Node newChild, Node oldChild) {
		throw new RuntimeException("MockText.replaceChild() not implemented.");
	}

	public void setNodeValue(String nodeValue) {
		throw new RuntimeException("MockText.setNodeValue() not implemented.");
	}

	public void setPrefix(String prefix) {
		throw new RuntimeException("MockText.setPrefix() not implemented.");
	}

	public void setTextContent(String textContent) {
		throw new RuntimeException("MockText.setTextContent() not implemented.");
	}

	public Object setUserData(String key, Object data, UserDataHandler handler) {
		throw new RuntimeException("MockText.setUserData() not implemented.");
	}

	public String getWholeText() {
		throw new RuntimeException("MockText.getWholeText() not implemented.");
	}

	public boolean isElementContentWhitespace() {
		throw new RuntimeException(
				"MockText.isElementContentWhitespace() not implemented.");
	}

	public Text replaceWholeText(String arg0) {
		throw new RuntimeException(
				"MockText.replaceWholeText() not implemented.");
	}

	public Text splitText(int arg0) {
		throw new RuntimeException("MockText.splitText() not implemented.");
	}

	public void appendData(String arg0) {
		throw new RuntimeException("MockText.appendData() not implemented.");
	}

	public void deleteData(int arg0, int arg1) {
		throw new RuntimeException("MockText.deleteData() not implemented.");
	}

	public String getData() {
		throw new RuntimeException("MockText.getData() not implemented.");
	}

	public int getLength() {
		throw new RuntimeException("MockText.getLength() not implemented.");
	}

	public void insertData(int arg0, String arg1) {
		throw new RuntimeException("MockText.insertData() not implemented.");
	}

	public void replaceData(int arg0, int arg1, String arg2) {
		throw new RuntimeException("MockText.replaceData() not implemented.");
	}

	public void setData(String arg0) {
		throw new RuntimeException("MockText.setData() not implemented.");
	}

	public String substringData(int arg0, int arg1) {
		throw new RuntimeException("MockText.substringData() not implemented.");
	}

}
