/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package mock.search.collContext;

import java.util.HashMap;
import java.util.Map;

import org.nsdl.search.collContext.CollRecCache;
import org.nsdl.search.collContext.CollectionContextConstants;
import org.nsdl.search.lucene.LuceneFieldSpec;
import org.nsdl.searchtools.common.ListsMap;

/**
 * 
 * @author jblake
 */
public class MockCollRecCache extends CollRecCache {

	// ----------------------------------------------------------------------
	// Mocking infrastructure
	// ----------------------------------------------------------------------

	private static MockCollRecCache instance;

	public static MockCollRecCache getInstance() {
		if (instance == null) {
			instance = new MockCollRecCache();
		}
		return instance;
	}

	private Map<String, ListsMap<LuceneFieldSpec, String>> collectionInfo = new HashMap<String, ListsMap<LuceneFieldSpec, String>>();

	public void addCollectionInfo(String collRecOaiId,
			ListsMap<LuceneFieldSpec, String> info) {
		if (!collRecOaiId
				.equals(CollectionContextConstants.COLL_OF_COLL_OAI_ID)) {
			collectionInfo.put(collRecOaiId, info);
		}
	}

	public void reset() {
		collectionInfo.clear();
	}

	// ----------------------------------------------------------------------
	// Mocked methods
	// ----------------------------------------------------------------------

	public ListsMap<LuceneFieldSpec, String> getCollContextFieldInfos(
			String collRecOaiId) {
		ListsMap<LuceneFieldSpec, String> fields = collectionInfo
				.get(collRecOaiId);
		return (fields == null)
				? new ListsMap<LuceneFieldSpec, String>()
				: fields;
	}

	// ----------------------------------------------------------------------
	// Un-implemented methods
	// ----------------------------------------------------------------------

}
