/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package mock.search.content;

import java.util.HashMap;
import java.util.Map;

import org.nsdl.search.content.ContentCacheWrapper;
import org.nsdl.search.content.PageContent;

/**
 * 
 * @author jblake
 */
public class MockContentCacheWrapper extends ContentCacheWrapper {

	// ----------------------------------------------------------------------
	// Mocking infrastructure
	// ----------------------------------------------------------------------

	private static MockContentCacheWrapper instance;

	public static MockContentCacheWrapper getInstance() {
		if (instance == null) {
			instance = new MockContentCacheWrapper();
		}
		return instance;
	}

	public static void reset() {
		instance = null;
	}

	private final Map<String, PageContent> pages = new HashMap<String, PageContent>();

	public void addPage(String url, PageContent content) {
		pages.put(url, content);
	}

	// ----------------------------------------------------------------------
	// Mocked methods
	// ----------------------------------------------------------------------

	@Override
	public PageContent getPageContent(String pageUrl) {
		if (pages.containsKey(pageUrl)) {
			return pages.get(pageUrl);
		} else {
			return PageContent.EMPTY_CONTENT;
		}
	}

	// ----------------------------------------------------------------------
	// Un-implemented methods
	// ----------------------------------------------------------------------

}
