/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package mock.search.lucene;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import org.nsdl.search.lucene.wrapper.SearchResult;
import org.nsdl.search.lucene.wrapper.SearchResults;

/**
 * An implementation of {@link SearchResults}, for use in unit tests.
 * 
 * @author jblake
 */
public class MockSearchResults implements SearchResults {

	// ----------------------------------------------------------------------
	// Mocking infrastructure
	// ----------------------------------------------------------------------

	/**
	 * If a {@link MockIndexWrapper} needs to return no results, seed it with
	 * this.
	 */
	public static final MockSearchResults EMPTY_RESULT = new MockSearchResults(
			0, 0, new ArrayList<SearchResult>());

	private final int totalCount;
	private final int skipCount;
	private final List<SearchResult> resultList;

	public MockSearchResults(int totalCount, int skipCount,
			List<SearchResult> resultList) {
		this.totalCount = totalCount;
		this.skipCount = skipCount;
		this.resultList = resultList;
	}

	// ----------------------------------------------------------------------
	// Mocked methods
	// ----------------------------------------------------------------------

	public int getReturnCount() {
		return this.resultList.size();
	}

	public int getSkipCount() {
		return this.skipCount;
	}

	public int getTotalCount() {
		return this.totalCount;
	}

	public Iterator<SearchResult> iterator() {
		return this.resultList.iterator();
	}

	public SearchResult getResult(int index) {
		return this.resultList.get(index);
	}

	// ----------------------------------------------------------------------
	// Un-implemented methods
	// ----------------------------------------------------------------------

}
