/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package mock.search.processoai;

import static junit.framework.Assert.assertEquals;
import static junit.framework.Assert.assertNotNull;
import static junit.framework.Assert.assertNull;

import java.io.IOException;
import java.io.Reader;

import org.nsdl.search.oai.process.OaiIndexingListener;
import org.nsdl.search.processoai.OaiCollectionInfo;
import org.nsdl.search.processoai.OaiHarvestRecord;
import org.nsdl.search.processoai.OaiRecordIndexer;
import org.nsdl.search.processoai.OaiRecordsParser;
import org.nsdl.search.processoai.XmlException;
import org.xml.sax.InputSource;

/**
 * 
 * @author jblake
 */
public class MockOaiListRecordsProcessor extends OaiRecordIndexer {

	private OaiRecordsParser parser;
	private OaiHarvestRecord actual;
	public void setParser(OaiRecordsParser parser) {
		this.parser = parser;
	}

	/**
	 * When the record is parsed, ask what was in it.
	 */
	public void indexRecord(OaiHarvestRecord oaiRecord) throws IOException {
		this.actual = oaiRecord;
	}

	/**
	 * Tell the parser to process this OAI record.
	 */
	public void parseOaiResponseFromReader(Reader reader) throws XmlException {
		parser.parse(new InputSource(reader));
	}

	/**
	 * Check that the exptected result is equal to the actual result.
	 */
	public void assertExpectedResults(OaiHarvestRecord expected) {
		assertNotNull("Supposed to get a record object !", actual);
		assertEquals(expected.isDeletedRecord(), actual.isDeletedRecord());
		assertCorrectCollectionInfo(expected.getCollectionInfo(), actual
				.getCollectionInfo());
		assertEquals(expected.getOaiRecDatestamp(), actual.getOaiRecDatestamp());
		assertEquals(expected.getOaiRecId(), actual.getOaiRecId());
		assertEquals(expected.getUrlMap(), actual.getUrlMap());
		assertEquals(expected.getFieldValuesMap(), actual.getFieldValuesMap());
	}

	private void assertCorrectCollectionInfo(OaiCollectionInfo expected,
			OaiCollectionInfo actual) {
		assertEquals(expected.getImageAltText(), actual.getImageAltText());
		assertEquals(expected.getImageHeight(), actual.getImageHeight());
		assertEquals(expected.getImageUrl(), actual.getImageUrl());
		assertEquals(expected.getImageWidth(), actual.getImageWidth());
		assertEquals(expected.getCollectionOaiId(), actual.getCollectionOaiId());
	}
	
	/**
	 * Confirm that we were not asked to index any records.
	 */
	public void confirmNoRecordsIndexed() {
		assertNull("Not supposed to get a record object!", actual);
	}

	@Override
	public void setListener(OaiIndexingListener listener) {
		// We don't need no stinking listener.
	}
}
