/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package org.nsdl.search.lucene;
import static junit.framework.Assert.*;
import org.junit.Test;

/**
 * 
 * @author jblake
 */
public class TestLuceneUtil {
	@Test
	public void noChanges() {
		String raw = "a string with no special characters";
		String expected = "a string with no special characters";
		assertEquals(expected, LuceneUtil.getInstance().encodeLuceneChars(raw));
	}

	@Test
	public void manyChanges() {
		String raw = "\\ + - ! ( ) : ^ [ ] { } ~ * ?";
		String expected = "\\\\ \\+ \\- \\! \\( \\) \\: \\^ \\[ \\] \\{ \\} \\~ \\* \\?";
		assertEquals(expected, LuceneUtil.getInstance().encodeLuceneChars(raw));
	}
	
	@Test
	public void adjaceneOperatorsWithMixedSlashes() {
		String raw = "Hi ^\\+-\\ there?";
		String expected = "Hi \\^\\\\\\+\\-\\\\ there\\?";
		assertEquals(expected, LuceneUtil.getInstance().encodeLuceneChars(raw));
	}
	
	@Test
	public void doubleOperators() {
		String raw = "This && that || another.";
		String expected = "This \\&\\& that \\|\\| another.";
		assertEquals(expected, LuceneUtil.getInstance().encodeLuceneChars(raw));
	}
}
