/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package org.nsdl.search.lucene.nsdl;

import java.util.HashMap;
import java.util.Map;

import org.junit.Before;
import org.junit.Test;

/**
 * Check that the NsdlAnalyzer is being populated correctly.
 * 
 * @author jblake
 */
public class TestNsdlAnalyzerPopulation extends AbstractNsdlAnalyzerTest {
	private Map<String, String> expectedMap;

	@Before
	public void initializeExpectedMap() {
		expectedMap = new HashMap<String, String>();
		String[] keywordNames = new String[] { "dc:identifier.dct:URI",
				"dc:relation.dct:URI", "dc:rights.dct:URI",
				"dc:source.dct:URI", "dct:accessRights.dct:URI",
				"dct:license.dct:URI", "dct:conformsTo.dct:URI",
				"dct:hasFormat.dct:URI", "dct:hasPart.dct:URI",
				"dct:hasVersion.dct:URI", "dct:isFormatOf.dct:URI",
				"dct:isPartOf.dct:URI", "dct:isReferencedBy.dct:URI",
				"dct:isReplacedBy.dct:URI", "dct:isRequiredBy.dct:URI",
				"dct:isVersionOf.dct:URI", "dct:references.dct:URI",
				"dct:replaces.dct:URI", "dct:requires.dct:URI", "inCollection",
				"metadataSource", "resourceIdentifier" };
		for (String name : keywordNames) {
			expectedMap.put(name,
					"org.nsdl.search.lucene.nsdl.NsdlAnalyzer$KeywordAnalyzer");
		}

		String[] noTokenNoStemNames = new String[] {
				"coll.dct:audience.nsdl_dc:NSDLEdLevel",
				"coll.dct:educationLevel.nsdl_dc:NSDLEdLevel",
				"contentLastFetched", "contentLastModified",
				"dc:coverage.dct:ISO8601", "dc:coverage.dct:W3CDTF",
				"dc:date.dct:ISO8601", "dc:date.dct:W3CDTF",
				"dc:format.dct:IMT", "dc:identifier.dct:ISBN",
				"dc:identifier.dct:ISSN", "dc:language.dct:ISO639-2",
				"dc:language.dct:RFC3066", "dc:subject.dct:DDC",
				"dc:subject.dct:LCC", "dc:subject.dct:LCSH",
				"dc:subject.dct:MESH", "dc:subject.dct:UDC",
				"dc:subject.nsdl_dc:GEM", "dc:type.dct:DCMIType",
				"dc:type.nsdl_dc:NSDLType",
				"dct:accessRights.nsdl_dc:NSDLAccess",
				"dct:audience.nsdl_dc:NSDLAudience",
				"dct:audience.nsdl_dc:NSDLEdLevel",
				"dct:available.dct:ISO8601", "dct:available.dct:W3CDTF",
				"dct:created.dct:ISO8601", "dct:created.dct:W3CDTF",
				"dct:dateAccepted.dct:ISO8601", "dct:dateAccepted.dct:W3CDTF",
				"dct:dateCopyrighted.dct:ISO8601",
				"dct:dateCopyrighted.dct:W3CDTF",
				"dct:dateSubmitted.dct:ISO8601",
				"dct:dateSubmitted.dct:W3CDTF",
				"dct:educationLevel.nsdl_dc:NSDLEdLevel",
				"dct:issued.dct:ISO8601", "dct:issued.dct:W3CDTF",
				"dct:medium.dct:IMT", "dct:modified.dct:ISO8601",
				"dct:modified.dct:W3CDTF", "dct:temporal.dct:ISO8601",
				"dct:valid.dct:ISO8601", "dct:valid.dct:W3CDTF",
				"documentCreated", "documentLastUpdated",
				"metadataLastModified", "dct:temporal.dct:W3CDTF" };
		for (String name : noTokenNoStemNames) {
			expectedMap
					.put(name,
							"org.nsdl.search.lucene.nsdl.NsdlAnalyzer$FoldedKeywordAnalyzer");
		}

		String[] tokenNoStemNames = new String[] { "allFields",
				"coll.dc:description", "coll.dc:rights", "coll.dc:title",
				"coll.dct:accessRights", "coll.dct:alternative",
				"coll.dct:audience", "coll.dct:educationLevel",
				"coll.dct:license", "coll.dct:mediator", "compoundAgent",
				"compoundAudience", "compoundDescription", "compoundGenre",
				"compoundSubject", "compoundTitle", "content",
				"dc:contributor", "dc:coverage", "dc:coverage.dct:Box",
				"dc:coverage.dct:ISO3166", "dc:coverage.dct:Period",
				"dc:coverage.dct:Point", "dc:coverage.dct:TGN", "dc:creator",
				"dc:date", "dc:date.dct:Period", "dc:description", "dc:format",
				"dc:identifier", "dc:language", "dc:publisher", "dc:relation",
				"dc:rights", "dc:source", "dc:subject", "dc:title", "dc:type",
				"dct:abstract", "dct:accessRights", "dct:accessibility",
				"dct:accrualMethod", "dct:accrualPeriodicity",
				"dct:accrualPolicy", "dct:alternative", "dct:audience",
				"dct:available", "dct:available.dct:Period",
				"dct:bibliographicCitation", "dct:conformsTo", "dct:created",
				"dct:created.dct:Period", "dct:dateAccepted",
				"dct:dateAccepted.dct:Period", "dct:dateCopyrighted",
				"dct:dateCopyrighted.dct:Period", "dct:dateSubmitted",
				"dct:dateSubmitted.dct:Period", "dct:educationLevel",
				"dct:extent", "dct:hasFormat", "dct:hasPart", "dct:hasVersion",
				"dct:instructionalMethod", "dct:isFormatOf", "dct:isPartOf",
				"dct:isReferencedBy", "dct:isReplacedBy", "dct:isRequiredBy",
				"dct:isVersionOf", "dct:issued", "dct:issued.dct:Period",
				"dct:license", "dct:mediator", "dct:medium", "dct:modified",
				"dct:modified.dct:Period", "dct:provenance", "dct:references",
				"dct:replaces", "dct:requires", "dct:rightsHolder",
				"dct:spatial", "dct:spatial.dct:Box",
				"dct:spatial.dct:ISO3166", "dct:spatial.dct:Point",
				"dct:spatial.dct:TGN", "dct:tableOfContents", "dct:temporal",
				"dct:temporal.dct:Period", "dct:valid", "dct:valid.dct:Period",
				"default", "ieee:interactivityLevel", "ieee:interactivityType",
				"ieee:typicalLearningTime" };
		for (String name : tokenNoStemNames) {
			expectedMap.put(name,
					"org.nsdl.search.lucene.nsdl.NsdlAnalyzer$TextAnalyzer");
		}

		String[] tokenStemNames = new String[] { "allFields.Stems",
				"coll.dc:description.Stems", "coll.dc:rights.Stems",
				"coll.dc:title.Stems", "coll.dct:accessRights.Stems",
				"coll.dct:alternative.Stems", "coll.dct:audience.Stems",
				"coll.dct:educationLevel.Stems", "coll.dct:license.Stems",
				"coll.dct:mediator.Stems", "compoundAgent.Stems",
				"compoundAudience.Stems", "compoundDescription.Stems",
				"compoundGenre.Stems", "compoundSubject.Stems",
				"compoundTitle.Stems", "content.Stems", "dc:contributor.Stems",
				"dc:coverage.Stems", "dc:coverage.dct:Box.Stems",
				"dc:coverage.dct:ISO3166.Stems",
				"dc:coverage.dct:Period.Stems", "dc:coverage.dct:Point.Stems",
				"dc:coverage.dct:TGN.Stems", "dc:creator.Stems",
				"dc:date.Stems", "dc:date.dct:Period.Stems",
				"dc:description.Stems", "dc:format.Stems",
				"dc:identifier.Stems", "dc:language.Stems",
				"dc:publisher.Stems", "dc:relation.Stems", "dc:rights.Stems",
				"dc:source.Stems", "dc:subject.Stems", "dc:title.Stems",
				"dc:type.Stems", "dct:abstract.Stems",
				"dct:accessRights.Stems", "dct:accessibility.Stems",
				"dct:accrualMethod.Stems", "dct:accrualPeriodicity.Stems",
				"dct:accrualPolicy.Stems", "dct:alternative.Stems",
				"dct:audience.Stems", "dct:available.Stems",
				"dct:available.dct:Period.Stems",
				"dct:bibliographicCitation.Stems", "dct:conformsTo.Stems",
				"dct:created.Stems", "dct:created.dct:Period.Stems",
				"dct:dateAccepted.Stems", "dct:dateAccepted.dct:Period.Stems",
				"dct:dateCopyrighted.Stems",
				"dct:dateCopyrighted.dct:Period.Stems",
				"dct:dateSubmitted.Stems",
				"dct:dateSubmitted.dct:Period.Stems",
				"dct:educationLevel.Stems", "dct:extent.Stems",
				"dct:hasFormat.Stems", "dct:hasPart.Stems",
				"dct:hasVersion.Stems", "dct:instructionalMethod.Stems",
				"dct:isFormatOf.Stems", "dct:isPartOf.Stems",
				"dct:isReferencedBy.Stems", "dct:isReplacedBy.Stems",
				"dct:isRequiredBy.Stems", "dct:isVersionOf.Stems",
				"dct:issued.Stems", "dct:issued.dct:Period.Stems",
				"dct:license.Stems", "dct:mediator.Stems", "dct:medium.Stems",
				"dct:modified.Stems", "dct:modified.dct:Period.Stems",
				"dct:provenance.Stems", "dct:references.Stems",
				"dct:replaces.Stems", "dct:requires.Stems",
				"dct:rightsHolder.Stems", "dct:spatial.Stems",
				"dct:spatial.dct:Box.Stems", "dct:spatial.dct:ISO3166.Stems",
				"dct:spatial.dct:Point.Stems", "dct:spatial.dct:TGN.Stems",
				"dct:tableOfContents.Stems", "dct:temporal.Stems",
				"dct:temporal.dct:Period.Stems", "dct:valid.Stems",
				"dct:valid.dct:Period.Stems", "ieee:interactivityLevel.Stems",
				"ieee:interactivityType.Stems",
				"ieee:typicalLearningTime.Stems" };
		for (String name : tokenStemNames) {
			expectedMap
					.put(name,
							"org.nsdl.search.lucene.nsdl.NsdlAnalyzer$StemmedTextAnalyzer");
		}
	}

	/**
	 * Check to be sure that the correct fields are given the appropriate
	 * analyzers.
	 */
	@Test
	public void testProperPopulating() {
		NsdlAnalyzer analyzer = new NsdlAnalyzer();
		Map<String, String> actualMap = buildAnalyzerMap(analyzer);
		assertEqualMaps(expectedMap, actualMap);
	}
}
