/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package org.nsdl.search.lucene.searchdoc;

import static org.nsdl.search.config.OaiMetadataElements.MD_DC_CREATOR;
import static org.nsdl.search.config.OaiMetadataElements.MD_DC_DATE;
import static org.nsdl.search.config.OaiMetadataElements.MD_DC_DESCRIPTION;
import static org.nsdl.search.config.OaiMetadataElements.MD_DC_SUBJECT;
import static org.nsdl.search.config.OaiMetadataElements.MD_DC_TITLE;
import static org.nsdl.search.config.OaiMetadataElements.MD_DC_TYPE_DCMITYPE;

import java.net.MalformedURLException;
import java.text.ParseException;

import org.nsdl.search.processoai.OaiCollectionInfo;
import org.nsdl.search.processoai.OaiHarvestRecord;
import org.nsdl.searchtools.common.net.UrlUtil;

/**
 * 
 * @author jblake
 */
public class ExampleOaiDocuments {

	public static final String DOC0_IDENTIFIER0 = "http://dcr.mathdl.org/MathDL/3/"
			+ "?pa=content&sa=viewDocument&nodeId=679";
	public static final String DOC0_DATESTAMP = "2006-05-15T22:43:01Z";
	public static final String DOC0_DATE0 = "2006-10-27T10:44:02Z";
	public static final String DOC0_CREATOR0 = "Douglas Ensley, Barbara Kaskosz";
	public static final String DOC0_DESCRIPTION0 = "A forum for educators "
			+ "interested in developing classroom material using "
			+ "Macromedia Flash.";
	public static final String DOC0_SUBJECT0 = "Flash Forum Collection";
	public static final String DOC0_SUBJECT1 = "flash, developer, programming";
	public static final String DOC0_TITLE0 = "MathDL Flash Forum";
	public static final String DOC0_TYPEDMCI0 = "Collection";

	public static final OaiCollectionInfo DOC0_OAI_COLLECTION_INFO = new OaiCollectionInfo(
			"oai:nsdl.org:nsdl.nsdl:00171",
			"http://crs/nsdl.org/brrands/MathDL.jpg", "100", "34",
			"Mathematical Seicnces Digital Library");

	public static OaiHarvestRecord getDoc0() throws ParseException,
			MalformedURLException {
		OaiHarvestRecord oai = new OaiHarvestRecord();
		oai.setOaiRecDatestamp(DOC0_DATESTAMP);
		oai.addFieldValue(MD_DC_TITLE, DOC0_TITLE0);
		oai.addFieldValue(MD_DC_CREATOR, DOC0_CREATOR0);
		oai.addFieldValue(MD_DC_SUBJECT, DOC0_SUBJECT0);
		oai.addFieldValue(MD_DC_SUBJECT, DOC0_SUBJECT1);
		oai.addFieldValue(MD_DC_DESCRIPTION, DOC0_DESCRIPTION0);
		oai.addFieldValue(MD_DC_DATE, DOC0_DATE0);
		oai.addFieldValue(MD_DC_TYPE_DCMITYPE, DOC0_TYPEDMCI0);

		oai.addUrlMapping(UrlUtil.getInstance().normalize(DOC0_IDENTIFIER0),
				DOC0_IDENTIFIER0);

		oai.setCollectionInfo(DOC0_OAI_COLLECTION_INFO);
		return oai;
	}

	/** Never create an instance of this. */
	private ExampleOaiDocuments() {
		// nothing to instantiate.
	}
}
