/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package org.nsdl.search.lucene.searchdoc;

import static junit.framework.Assert.assertEquals;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DC_CREATOR;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DC_DATE;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DC_DESCRIPTION;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DC_SUBJECT;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DC_TITLE;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DC_TYPE_DCMITYPE;
import static org.nsdl.search.lucene.searchdoc.ExampleOaiDocuments.DOC0_CREATOR0;
import static org.nsdl.search.lucene.searchdoc.ExampleOaiDocuments.DOC0_DATE0;
import static org.nsdl.search.lucene.searchdoc.ExampleOaiDocuments.DOC0_DATESTAMP;
import static org.nsdl.search.lucene.searchdoc.ExampleOaiDocuments.DOC0_DESCRIPTION0;
import static org.nsdl.search.lucene.searchdoc.ExampleOaiDocuments.DOC0_OAI_COLLECTION_INFO;
import static org.nsdl.search.lucene.searchdoc.ExampleOaiDocuments.DOC0_SUBJECT0;
import static org.nsdl.search.lucene.searchdoc.ExampleOaiDocuments.DOC0_SUBJECT1;
import static org.nsdl.search.lucene.searchdoc.ExampleOaiDocuments.DOC0_TITLE0;
import static org.nsdl.search.lucene.searchdoc.ExampleOaiDocuments.DOC0_TYPEDMCI0;

import java.net.MalformedURLException;
import java.text.ParseException;

import org.junit.Before;
import org.junit.Test;
import org.nsdl.search.lucene.LuceneFieldSpec;
import org.nsdl.search.processoai.OaiHarvestRecord;
import org.nsdl.searchtools.common.DateUtil;
import org.nsdl.searchtools.common.ListsMap;

/**
 * 
 * @author jblake
 */
public class TestSearchDocumentMetadataLoader {
	SearchDocumentMetadataLoader loader;

	@Before
	public void initializeLoader() {
		loader = new SearchDocumentMetadataLoader();
	}

	@Test
	public void loadExampleOaiRecord() throws ParseException,
			MalformedURLException {
		OaiHarvestRecord oai = ExampleOaiDocuments.getDoc0();

		loader.load(oai);

		ListsMap<LuceneFieldSpec, String> expectedFields = new ListsMap<LuceneFieldSpec, String>();
		expectedFields.addValue(DC_TITLE, DOC0_TITLE0);
		expectedFields.addValue(DC_CREATOR, DOC0_CREATOR0);
		expectedFields.addValue(DC_SUBJECT, DOC0_SUBJECT0);
		expectedFields.addValue(DC_SUBJECT, DOC0_SUBJECT1);
		expectedFields.addValue(DC_DESCRIPTION, DOC0_DESCRIPTION0);
		expectedFields.addValue(DC_DATE, DOC0_DATE0);
		expectedFields.addValue(DC_TYPE_DCMITYPE, DOC0_TYPEDMCI0);

		assertDateStamp(DOC0_DATESTAMP);
		assertFieldValues(expectedFields);
		assertEquals(DOC0_OAI_COLLECTION_INFO, loader.getCollInfo());
	}

	/**
	 * @param expectedFields
	 */
	private void assertFieldValues(
			ListsMap<LuceneFieldSpec, String> expectedFields) {
		ListsMap<LuceneFieldSpec, String> actualFields = loader.getFields();
		assertEquals("field specs", expectedFields.keySet(), actualFields
				.keySet());
		for (LuceneFieldSpec spec : expectedFields.keySet()) {
			assertEquals("field values for " + spec.getName(), expectedFields
					.get(spec), actualFields.get(spec));
		}
	}

	/**
	 * @param dateStamp
	 */
	private void assertDateStamp(String dateStamp) {
		assertEquals("dateStamp", dateStamp, DateUtil.getInstance().formatDate(
				loader.getOaiDateStamp(), DateUtil.ISO8601_DATE_TIME_Z));
	}
}
