/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package org.nsdl.search.lucene.searchdoc;

import java.util.Date;

import mock.search.content.MockContentCacheWrapper;

import org.apache.lucene.document.Document;
import org.junit.Before;
import org.junit.Test;
import org.nsdl.search.SearchUnitTest;
import org.nsdl.search.content.ContentCacheWrapper;
import org.nsdl.search.content.PageContent;
import org.nsdl.search.testoaiparsing.ExpectedDocuments;

/**
 * 
 * @author jblake
 */
public class TestSearchDocumentUnloader extends SearchUnitTest {

	@Override
	protected Class<?>[][] getImplementationClasses() {
		return new Class[][]{{ContentCacheWrapper.class,
				MockContentCacheWrapper.class}};
	}

	@Before
	public void useCleanContentCacheWrapper() {
		MockContentCacheWrapper.reset();
	}

	@Test
	public void testLoadAndUnloadDocument1() {
		Document expected = ExpectedDocuments.getDocument1();
		SearchDocument searchDoc = new SearchDocument(expected);
		assertEqualLuceneDocuments(expected, searchDoc.toDocument());
	}

	@Test
	public void testLoadAndUnloadDocument1WithCC() {
		Document expected = ExpectedDocuments.getDocument1WithCC();
		SearchDocument searchDoc = new SearchDocument(expected);
		assertEqualLuceneDocuments(expected, searchDoc.toDocument());
	}

	@Test
	public void testLoadAndUnloadDocument4a() {
		Document expected = ExpectedDocuments.getDocument4a();
		SearchDocument searchDoc = new SearchDocument(expected);
		assertEqualLuceneDocuments(expected, searchDoc.toDocument());
	}

	@Test
	public void testLoadAndUnloadDocument4b() {
		Document expected = ExpectedDocuments.getDocument4b();
		SearchDocument searchDoc = new SearchDocument(expected);
		assertEqualLuceneDocuments(expected, searchDoc.toDocument());
	}

	@Test
	public void testLoadAndUnloadDocument4c() {
		Document expected = ExpectedDocuments.getDocument4c();
		SearchDocument searchDoc = new SearchDocument(expected);
		assertEqualLuceneDocuments(expected, searchDoc.toDocument());
	}

	@Test
	public void testLoadAndUnloadDocument4d() {
		Document expected = ExpectedDocuments.getDocument4d();
		SearchDocument searchDoc = new SearchDocument(expected);
		assertEqualLuceneDocuments(expected, searchDoc.toDocument());
	}

	@Test
	public void testLoadAndUnloadDocumentNQThree() {
		Document expected = ExpectedDocuments.getDocumentNQThree();
		SearchDocument searchDoc = new SearchDocument(expected);
		assertEqualLuceneDocuments(expected, searchDoc.toDocument());
	}

	@Test
	public void testLoadAndUnloadDocumentNQTwoModded() {
		Document expected = ExpectedDocuments.getDocumentNQTwoModded();
		SearchDocument searchDoc = new SearchDocument(expected);
		assertEqualLuceneDocuments(expected, searchDoc.toDocument());
	}

	@Test
	public void testLoadAndUnloadDocumentNQTwoMinusFirst() {
		Document expected = ExpectedDocuments.getDocumentNQTwoMinusFirst();
		SearchDocument searchDoc = new SearchDocument(expected);
		assertEqualLuceneDocuments(expected, searchDoc.toDocument());
	}

	@Test
	public void testLoadAndUnloadDocumentNQTwoMinusBoth() {
		Document expected = ExpectedDocuments.getDocumentNQTwoMinusBoth();
		SearchDocument searchDoc = new SearchDocument(expected);
		assertEqualLuceneDocuments(expected, searchDoc.toDocument());
	}

	@Test
	public void testLoadAndUnloadDocumentNQAll() {
		Document expected = ExpectedDocuments.getDocumentNQAll();
		SearchDocument searchDoc = new SearchDocument(expected);
		assertEqualLuceneDocuments(expected, searchDoc.toDocument());
	}

	@Test
	public void loadAndUnloadDocument1WithContent() {
		PageContent content = new PageContent("content-type", new Date(0),
				new Date(0), new Date(2000), "some silly text", "the title",
				true);
		MockContentCacheWrapper.getInstance().addPage(ExpectedDocuments.URL1,
				content);

		Document beforeContent = ExpectedDocuments.getDocument1();
		Document expected = ExpectedDocuments.getDocument1WithContent();
		SearchDocument searchDoc = new SearchDocument(beforeContent);
		assertEqualLuceneDocuments(expected, searchDoc.toDocument());
	}

}
