/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package org.nsdl.search.rest3.responses;

import static junit.framework.Assert.assertEquals;
import static junit.framework.Assert.fail;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.JAXBException;
import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.parsers.ParserConfigurationException;

import org.junit.Test;
import org.nsdl.search.generated.rest.NSDLSearchServiceType;
import org.nsdl.search.generated.rest.ObjectFactory;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.NodeList;
import org.xml.sax.InputSource;
import org.xml.sax.SAXException;

/**
 * 
 * @author jblake
 */
public class TestResponseMarshallerImpl {

	private static final char SPECIAL_CHAR = 0x1824;
	private static final String REQUEST_TEXT_WITH_SPECIAL_CHAR = "This "
			+ SPECIAL_CHAR + " request";

	@Test
	public void handlingSpecialCharacters() throws JAXBException {
		ObjectFactory factory = new ObjectFactory();

		NSDLSearchServiceType docRoot = factory.createNSDLSearchServiceType();
		docRoot.setRequest(REQUEST_TEXT_WITH_SPECIAL_CHAR);

		JAXBElement<NSDLSearchServiceType> responseObject = factory
				.createNSDLSearchService(docRoot);

		byte[] responseBytes = marshallResponseObject(responseObject);
		Document responseDoc = parseResponseBytes(responseBytes);

		NodeList requestNodes = responseDoc.getElementsByTagName("request");
		assertEquals("wrong number of request nodes", 1, requestNodes
				.getLength());

		Element requestElement = (Element) requestNodes.item(0);
		String requestText = requestElement.getTextContent();
		assertEquals("wrong text", REQUEST_TEXT_WITH_SPECIAL_CHAR, requestText);
	}

	private byte[] marshallResponseObject(
			JAXBElement<NSDLSearchServiceType> responseObject)
			throws JAXBException {
		ResponseMarshallerImpl marshaller = new ResponseMarshallerImpl(
				ResponseMarshallerType.REST);
		ByteArrayOutputStream output = new ByteArrayOutputStream();
		marshaller.marshal(responseObject, output);
		return output.toByteArray();
	}

	private Document parseResponseBytes(byte[] responseBytes) {
		Document doc = null;
		try {
			DocumentBuilderFactory docBuilderFactory = DocumentBuilderFactory
					.newInstance();
			DocumentBuilder docBuilder = docBuilderFactory.newDocumentBuilder();
			doc = docBuilder.parse(new InputSource(new ByteArrayInputStream(
					responseBytes)));
		} catch (ParserConfigurationException e) {
			e.printStackTrace();
			fail(e.toString());
		} catch (SAXException e) {
			e.printStackTrace();
			fail(e.toString());
		} catch (IOException e) {
			e.printStackTrace();
			fail(e.toString());
		}
		return doc;
	}
}
