/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package org.nsdl.search.testoaiparsing;

import static org.nsdl.search.lucene.SearchIndexFieldSpecs.ALL_FIELDS;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.COLL_IMAGE_ALT_TEXT;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.COLL_IMAGE_HEIGHT;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.COLL_IMAGE_URL;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.COLL_IMAGE_WIDTH;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.COMPOUND_AGENT;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.COMPOUND_AUDIENCE;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.COMPOUND_DESCRIPTION;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.COMPOUND_GENRE;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.COMPOUND_SUBJECT;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.COMPOUND_TITLE;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.CONTENT;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.CONTENT_LAST_FETCHED;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.CONTENT_LAST_MODIFIED;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DCT_ALTERNATIVE;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DCT_AUDIENCE;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DCT_CREATED_W3CDTF;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DCT_DATE_ACCEPTED_W3CDTF;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DCT_DATE_SUBMITTED_W3CDTF;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DCT_EDLEVEL;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DCT_EDLEVEL_NSDL_EDLEVEL;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DCT_EXTENT;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DCT_MEDIATOR;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DCT_MODIFIED_W3CDTF;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DC_CONTRIBUTOR;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DC_CREATOR;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DC_DATE;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DC_DATE_W3CDTF;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DC_DESCRIPTION;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DC_FORMAT;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DC_FORMAT_IMT;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DC_IDENTIFIER;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DC_LANGUAGE_RFC3066;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DC_PUBLISHER;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DC_RIGHTS;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DC_SUBJECT;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DC_SUBJECT_GEM;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DC_SUBJECT_LCSH;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DC_TITLE;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DC_TYPE;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DC_TYPE_DCMITYPE;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DOCUMENT_CREATED;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DOCUMENT_LAST_UPDATED;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.IN_COLLECTION;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.METADATA_LAST_MODIFIED;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.METADATA_SOURCE;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.RESOURCE_IDENTIFIER;

import org.apache.lucene.document.Document;
import org.apache.lucene.document.Field;
import org.nsdl.search.lucene.LuceneFieldSpec;

/**
 * Get all of the ugly details out of my test cases.
 * 
 * @author jblake
 */
public class ExpectedDocuments {
	public static final String URL1 = "http://dcr.mathdl.org/mathDL/3/?pa=content&sa=viewDocument&nodeId=679";
	public static final String URL4A = "http://capsules.maa.org/mathDL/20/?pa=content&sa=viewDocument&nodeId=1196";
	public static final String URL4B = "http://capsules.maa.org/mathDL/20/?pa=content&sa=viewDocument&nodeId=1197";
	public static final String URL4C = "http://mathdl.maa.org/convergence/1/convergence/1/?pa=content&sa=viewDocument&nodeId=1204";
	public static final String URL4D = "http://mathdl.maa.org/convergence/1/convergence/1/?pa=content&sa=viewDocument&nodeId=1205";
	public static Document getDocument1() {
		Document document = new Document();
		addField(document, RESOURCE_IDENTIFIER, "http://dcr.mathdl.org/mathDL/3/?pa=content&sa=viewDocument&nodeId=679");
		addField(document, DOCUMENT_CREATED, "2007-04-12T21:01:21Z");
		addField(document, METADATA_SOURCE, "oai:nsdl.org:MathDL:679 ~^ 0 ~^ http://dcr.mathdl.org/mathDL/3/?pa=content&sa=viewDocument&nodeId=679");
		addField(document, DC_SUBJECT, "0 ~^ Flash Forum Collection ~^ flash, developer, programming");
		addField(document, DC_TYPE_DCMITYPE, "Collection ~^ 0");
		addField(document, DC_DESCRIPTION, "0 ~^ A forum for educators interested in developing classroom material using Macromedia Flash.");
		addField(document, DC_CREATOR, "0 ~^ Douglas Ensley, Barbara Kaskosz");
		addField(document, DC_DATE, "0 ~^ 2006-10-27T10:44:02Z");
		addField(document, DC_TITLE, "0 ~^ MathDL Flash Forum");
		addField(document, IN_COLLECTION, "oai:nsdl.org:nsdl.nsdl:00171 ~^ 0");
		addField(document, COLL_IMAGE_URL, "0 ~^ http://crs.nsdl.org/brands/MathDL.jpg");
		addField(document, COLL_IMAGE_WIDTH, "0 ~^ 100");
		addField(document, COLL_IMAGE_HEIGHT, "0 ~^ 34");
		addField(document, COLL_IMAGE_ALT_TEXT, "0 ~^ Mathematical Sciences Digital Library");
		addField(document, COMPOUND_GENRE, "0 ~^ Collection");
		addField(document, COMPOUND_SUBJECT, "0 ~^ Flash Forum Collection ~^ flash, developer, programming");
		addField(document, COMPOUND_AGENT, "0 ~^ Douglas Ensley, Barbara Kaskosz");
		addField(document, COMPOUND_TITLE, "0 ~^ MathDL Flash Forum");
		addField(document, COMPOUND_DESCRIPTION, "0 ~^ A forum for educators interested in developing classroom material using Macromedia Flash.");
		addField(document, METADATA_LAST_MODIFIED, "2006-11-01T15:00:18Z");
		addField(document, ALL_FIELDS, "Flash Forum Collection ~^ flash, developer, programming Collection A forum for educators interested in developing classroom material using Macromedia Flash. Douglas Ensley, Barbara Kaskosz 2006-10-27T10:44:02Z MathDL Flash Forum");
		addField(document, DOCUMENT_LAST_UPDATED, "2006-11-03T02:01:55Z");
		return document;
	}

	public static Document getDocument1WithCC() {
		Document document = new Document();
		addField(document, RESOURCE_IDENTIFIER, "http://dcr.mathdl.org/mathDL/3/?pa=content&sa=viewDocument&nodeId=679");
		addField(document, DOCUMENT_CREATED, "2007-04-12T21:01:21Z");
		addField(document, METADATA_SOURCE, "oai:nsdl.org:MathDL:679 ~^ 0 ~^ http://dcr.mathdl.org/mathDL/3/?pa=content&sa=viewDocument&nodeId=679");
		addField(document, DC_SUBJECT, "0 ~^ Flash Forum Collection ~^ flash, developer, programming");
		addField(document, DC_TYPE_DCMITYPE, "Collection ~^ 0");
		addField(document, DC_DESCRIPTION, "0 ~^ A forum for educators interested in developing classroom material using Macromedia Flash.");
		addField(document, DC_CREATOR, "0 ~^ Douglas Ensley, Barbara Kaskosz");
		addField(document, DC_DATE, "0 ~^ 2006-10-27T10:44:02Z");
		addField(document, DC_TITLE, "0 ~^ MathDL Flash Forum");
		addField(document, IN_COLLECTION, "oai:nsdl.org:nsdl.nsdl:00171 ~^ 0");
		addField(document, COLL_IMAGE_URL, "0 ~^ http://crs.nsdl.org/brands/MathDL.jpg");
		addField(document, COLL_IMAGE_WIDTH, "0 ~^ 100");
		addField(document, COLL_IMAGE_HEIGHT, "0 ~^ 34");
		addField(document, COLL_IMAGE_ALT_TEXT, "0 ~^ Mathematical Sciences Digital Library");
		addField(document, DC_TITLE, "0 ~^ Welcome to MathDL -The Mathematical Sciences Digital Library");
		addField(document, DC_DESCRIPTION, "0 ~^ The Mathematical Sciences Digital Library is an online resource managed by the Mathematical Association of America with funding by the National Science Foundation, and hosted by the Math Forum. The site provides online resources for both teachers and students of collegiate mathematics, including the Journal of Online Mathematics and its Applications (JOMA), a catalog of mathematics commercial products (complete with editorial reviews, reader ratings and discussion groups), and Digital Classroom Resources (a collection of mathematics instructional material with authors' statements and reader reviews).");
		addField(document, DC_RIGHTS, "0 ~^ http://www.mathdl.org/copyright.html");
		addField(document, DCT_EDLEVEL_NSDL_EDLEVEL, "Postsecondary ~^ 0");
		addField(document, COMPOUND_GENRE, "0 ~^ Collection");
		addField(document, COMPOUND_SUBJECT, "0 ~^ Flash Forum Collection ~^ flash, developer, programming");
		addField(document, COMPOUND_AUDIENCE, "0 ~^ Postsecondary");
		addField(document, COMPOUND_AGENT, "0 ~^ Douglas Ensley, Barbara Kaskosz");
		addField(document, COMPOUND_TITLE, "0 ~^ MathDL Flash Forum Welcome to MathDL -The Mathematical Sciences Digital Library");
		addField(document, COMPOUND_DESCRIPTION, "0 ~^ A forum for educators interested in developing classroom material using Macromedia Flash. The Mathematical Sciences Digital Library is an online resource managed by the Mathematical Association of America with funding by the National Science Foundation, and hosted by the Math Forum. The site provides online resources for both teachers and students of collegiate mathematics, including the Journal of Online Mathematics and its Applications (JOMA), a catalog of mathematics commercial products (complete with editorial reviews, reader ratings and discussion groups), and Digital Classroom Resources (a collection of mathematics instructional material with authors' statements and reader reviews).");
		addField(document, METADATA_LAST_MODIFIED, "2006-11-01T15:00:18Z");
		addField(document, ALL_FIELDS, "Flash Forum Collection ~^ flash, developer, programming Collection A forum for educators interested in developing classroom material using Macromedia Flash. Douglas Ensley, Barbara Kaskosz 2006-10-27T10:44:02Z MathDL Flash Forum Welcome to MathDL -The Mathematical Sciences Digital Library The Mathematical Sciences Digital Library is an online resource managed by the Mathematical Association of America with funding by the National Science Foundation, and hosted by the Math Forum. The site provides online resources for both teachers and students of collegiate mathematics, including the Journal of Online Mathematics and its Applications (JOMA), a catalog of mathematics commercial products (complete with editorial reviews, reader ratings and discussion groups), and Digital Classroom Resources (a collection of mathematics instructional material with authors' statements and reader reviews). Postsecondary");
		addField(document, DOCUMENT_LAST_UPDATED, "2007-04-12T21:01:21Z");
		return document;
	}
	
	public static Document getDocument1WithContent() {
		Document document = getDocument1();
		addField(document, CONTENT, "some silly text");
		addField(document, ALL_FIELDS, "some silly text ~^ the title ~^ content-type");
		addField(document, COMPOUND_TITLE, "the title");
		addField(document, COMPOUND_GENRE, "content-type");
		addField(document, CONTENT_LAST_FETCHED, "1970-01-01T00:00:00Z");
		addField(document, CONTENT_LAST_MODIFIED, "1970-01-01T00:00:02Z");
		return document;
	}

	public static Document getDocument4a() {
		Document document = new Document();
		addField(document, RESOURCE_IDENTIFIER, "http://capsules.maa.org/mathDL/20/?pa=content&sa=viewDocument&nodeId=1196");
		addField(document, DOCUMENT_CREATED, "2000-01-01T01:01:01Z");
		addField(document, METADATA_SOURCE, "oai:nsdl.org:MathDL:1196 ~^ 0 ~^ http://capsules.maa.org/mathDL/20/?pa=content&sa=viewDocument&nodeId=1196");
		addField(document, DC_SUBJECT, "0 ~^ 6.1.2 Limits ~^ 6.0 Calculus ~^ 6.1 Single Variable Calculus ~^ sequences, e");
		addField(document, DC_DESCRIPTION, "0 ~^ <I>Refining the inequalities to trap the resulting sequences</I>");
		addField(document, DC_CREATOR, "0 ~^ Peter R. Mercer");
		addField(document, DC_DATE, "0 ~^ 2006-06-28T02:22:00Z");
		addField(document, DC_TITLE, "0 ~^ The Monotonicity of (1 + (1/n))<sup>n</sup> and (1 + (1/n))<sup>n+1</sup>");
		addField(document, DC_TYPE, "0 ~^ PDF");
		addField(document, IN_COLLECTION, "oai:nsdl.org:nsdl.nsdl:00171 ~^ 0");
		addField(document, COLL_IMAGE_URL, "0 ~^ http://crs.nsdl.org/brands/MathDL.jpg");
		addField(document, COLL_IMAGE_WIDTH, "0 ~^ 100");
		addField(document, COLL_IMAGE_HEIGHT, "0 ~^ 34");
		addField(document, COLL_IMAGE_ALT_TEXT, "0 ~^ Mathematical Sciences Digital Library");
		addField(document, COMPOUND_GENRE, "0 ~^ PDF");
		addField(document, COMPOUND_SUBJECT, "0 ~^ 6.1.2 Limits ~^ 6.0 Calculus ~^ 6.1 Single Variable Calculus ~^ sequences, e");
		addField(document, COMPOUND_AGENT, "0 ~^ Peter R. Mercer");
		addField(document, COMPOUND_TITLE, "0 ~^ The Monotonicity of (1 + (1/n))<sup>n</sup> and (1 + (1/n))<sup>n+1</sup>");
		addField(document, COMPOUND_DESCRIPTION, "0 ~^ <I>Refining the inequalities to trap the resulting sequences</I>");
		addField(document, METADATA_LAST_MODIFIED, "2006-11-01T15:01:32Z");
		addField(document, ALL_FIELDS, "6.1.2 Limits ~^ 6.0 Calculus ~^ 6.1 Single Variable Calculus ~^ sequences, e <I>Refining the inequalities to trap the resulting sequences</I> Peter R. Mercer 2006-06-28T02:22:00Z The Monotonicity of (1 + (1/n))<sup>n</sup> and (1 + (1/n))<sup>n+1</sup> PDF");
		addField(document, DOCUMENT_LAST_UPDATED, "2002-02-02T02:02:02Z");
		return document;
	}

	public static Document getDocument4b() {
		Document document = new Document();
		addField(document, RESOURCE_IDENTIFIER, "http://capsules.maa.org/mathDL/20/?pa=content&sa=viewDocument&nodeId=1197");
		addField(document, DOCUMENT_CREATED, "2000-01-01T01:01:01Z");
		addField(document, METADATA_SOURCE, "oai:nsdl.org:MathDL:1197 ~^ 0 ~^ http://capsules.maa.org/mathDL/20/?pa=content&sa=viewDocument&nodeId=1197");
		addField(document, DC_SUBJECT, "0 ~^ 6.0 Calculus ~^ integration, disks, shells");
		addField(document, DC_DESCRIPTION, "0 ~^ <I>The familiar integral of statistics is calculated using shells and disks.</I>");
		addField(document, DC_CREATOR, "0 ~^ Alberto L. Delgado");
		addField(document, DC_DATE, "0 ~^ 2006-06-28T02:28:09Z");
		addField(document, DC_TITLE, "0 ~^ A Calculation of the Semi-infinite Integral of e<sup>-x<sup>2</sup></sup>dx");
		addField(document, DC_TYPE, "0 ~^ PDF");
		addField(document, IN_COLLECTION, "oai:nsdl.org:nsdl.nsdl:00171 ~^ 0");
		addField(document, COLL_IMAGE_URL, "0 ~^ http://crs.nsdl.org/brands/MathDL.jpg");
		addField(document, COLL_IMAGE_WIDTH, "0 ~^ 100");
		addField(document, COLL_IMAGE_HEIGHT, "0 ~^ 34");
		addField(document, COLL_IMAGE_ALT_TEXT, "0 ~^ Mathematical Sciences Digital Library");
		addField(document, COMPOUND_GENRE, "0 ~^ PDF");
		addField(document, COMPOUND_SUBJECT, "0 ~^ 6.0 Calculus ~^ integration, disks, shells");
		addField(document, COMPOUND_AGENT, "0 ~^ Alberto L. Delgado");
		addField(document, COMPOUND_TITLE, "0 ~^ A Calculation of the Semi-infinite Integral of e<sup>-x<sup>2</sup></sup>dx");
		addField(document, COMPOUND_DESCRIPTION, "0 ~^ <I>The familiar integral of statistics is calculated using shells and disks.</I>");
		addField(document, METADATA_LAST_MODIFIED, "2006-11-01T15:01:31Z");
		addField(document, ALL_FIELDS, "6.0 Calculus ~^ integration, disks, shells <I>The familiar integral of statistics is calculated using shells and disks.</I> Alberto L. Delgado 2006-06-28T02:28:09Z A Calculation of the Semi-infinite Integral of e<sup>-x<sup>2</sup></sup>dx PDF");
		addField(document, DOCUMENT_LAST_UPDATED, "2002-02-02T02:02:02Z");
		return document;
	}

	public static Document getDocument4c() {
		Document document = new Document();
		addField(document, RESOURCE_IDENTIFIER, "http://mathdl.maa.org/convergence/1/convergence/1/?pa=content&sa=viewDocument&nodeId=1204");
		addField(document, DOCUMENT_CREATED, "2000-01-01T01:01:01Z");
		addField(document, METADATA_SOURCE, "oai:nsdl.org:MathDL:1204 ~^ 0 ~^ http://mathdl.maa.org/convergence/1/convergence/1/?pa=content&sa=viewDocument&nodeId=1204");
		addField(document, DC_DESCRIPTION, "0 ~^ The Euler Society was founded as the tercentennial of the birth of the prolific Swiss-born genius Leonhard Euler approaches. The 2006 meeting is the fifth annual meeting of the Society.");
		addField(document, DC_DATE, "0 ~^ 2006-07-06T02:24:04Z");
		addField(document, DC_TITLE, "0 ~^ Euler Society Annual Meeting");
		addField(document, DC_TYPE, "0 ~^ N/A");
		addField(document, IN_COLLECTION, "oai:nsdl.org:nsdl.nsdl:00171 ~^ 0");
		addField(document, COLL_IMAGE_URL, "0 ~^ http://crs.nsdl.org/brands/MathDL.jpg");
		addField(document, COLL_IMAGE_WIDTH, "0 ~^ 100");
		addField(document, COLL_IMAGE_HEIGHT, "0 ~^ 34");
		addField(document, COLL_IMAGE_ALT_TEXT, "0 ~^ Mathematical Sciences Digital Library");
		addField(document, COMPOUND_GENRE, "0 ~^ N/A");
		addField(document, COMPOUND_TITLE, "0 ~^ Euler Society Annual Meeting");
		addField(document, COMPOUND_DESCRIPTION, "0 ~^ The Euler Society was founded as the tercentennial of the birth of the prolific Swiss-born genius Leonhard Euler approaches. The 2006 meeting is the fifth annual meeting of the Society.");
		addField(document, METADATA_LAST_MODIFIED, "2006-11-01T15:01:31Z");
		addField(document, ALL_FIELDS, "The Euler Society was founded as the tercentennial of the birth of the prolific Swiss-born genius Leonhard Euler approaches. The 2006 meeting is the fifth annual meeting of the Society. 2006-07-06T02:24:04Z Euler Society Annual Meeting N/A");
		addField(document, DOCUMENT_LAST_UPDATED, "2002-02-02T02:02:02Z");
		return document;
	}

	public static Document getDocument4d() {
		Document document = new Document();
		addField(document, RESOURCE_IDENTIFIER, "http://mathdl.maa.org/convergence/1/convergence/1/?pa=content&sa=viewDocument&nodeId=1205");
		addField(document, DOCUMENT_CREATED, "2000-01-01T01:01:01Z");
		addField(document, METADATA_SOURCE, "oai:nsdl.org:MathDL:1205 ~^ 0 ~^ http://mathdl.maa.org/convergence/1/convergence/1/?pa=content&sa=viewDocument&nodeId=1205");
		addField(document, DC_SUBJECT, "0 ~^ Mathematics Education ~^ Geometry");
		addField(document, DC_DESCRIPTION, "0 ~^ How does geometry begin? This work explores the origins of geometry in the work of artisans.");
		addField(document, DC_CREATOR, "0 ~^ Lawrence Shirley, reviewer");
		addField(document, DC_DATE, "0 ~^ 2006-07-06T06:48:10Z");
		addField(document, DC_TITLE, "0 ~^ Awakening of Geometrical Thought in Early Culture");
		addField(document, DC_TYPE, "0 ~^ Reviews");
		addField(document, IN_COLLECTION, "oai:nsdl.org:nsdl.nsdl:00171 ~^ 0");
		addField(document, COLL_IMAGE_URL, "0 ~^ http://crs.nsdl.org/brands/MathDL.jpg");
		addField(document, COLL_IMAGE_WIDTH, "0 ~^ 100");
		addField(document, COLL_IMAGE_HEIGHT, "0 ~^ 34");
		addField(document, COLL_IMAGE_ALT_TEXT, "0 ~^ Mathematical Sciences Digital Library");
		addField(document, COMPOUND_GENRE, "0 ~^ Reviews");
		addField(document, COMPOUND_SUBJECT, "0 ~^ Mathematics Education ~^ Geometry");
		addField(document, COMPOUND_AGENT, "0 ~^ Lawrence Shirley, reviewer");
		addField(document, COMPOUND_TITLE, "0 ~^ Awakening of Geometrical Thought in Early Culture");
		addField(document, COMPOUND_DESCRIPTION, "0 ~^ How does geometry begin? This work explores the origins of geometry in the work of artisans.");
		addField(document, METADATA_LAST_MODIFIED, "2006-11-01T15:01:31Z");
		addField(document, ALL_FIELDS, "Mathematics Education ~^ Geometry How does geometry begin? This work explores the origins of geometry in the work of artisans. Lawrence Shirley, reviewer 2006-07-06T06:48:10Z Awakening of Geometrical Thought in Early Culture Reviews");
		addField(document, DOCUMENT_LAST_UPDATED, "2002-02-02T02:02:02Z");
		return document;
	}

	public static final String URLNQAll = "http://quest.arc.nasa.gov/";
	/**
	 * @return
	 */
	public static Document getDocumentNQAll() {
		Document document = new Document();
		addField(document, RESOURCE_IDENTIFIER, "http://quest.arc.nasa.gov/");
		addField(document, DOCUMENT_CREATED, "2007-05-06T23:01:21Z");

		addField(document, METADATA_SOURCE, "oai:nsdl.org:2200-20061002172429873T ~^ 0 ~^ http://quest.arc.nasa.gov/");
		addField(document, DC_PUBLISHER, "0 ~^ NASA Ames Educational Technology Team");
		addField(document, DC_TYPE_DCMITYPE, "Event ~^ 0");
		addField(document, DC_DESCRIPTION, "0 ~^ NASA Quest is dedicated to bringing NASA people and science to classrooms through the internet. NASA Quest is a resource for educators and kids interested in meeting and learning about NASA people and space science. ~^ Check out this site for activities related to NASA's science and engineering projects . Topics range from solving air traffic control problems to designing a new planet, and there's something for inquisitive minds of all ages. Also, every week you can read a bio of a NASA worker.");
		addField(document, DC_FORMAT_IMT, "text/html ~^ 0");
		addField(document, DC_CREATOR, "0 ~^ Donald James");
		addField(document, DC_LANGUAGE_RFC3066, "en ~^ 0");
		addField(document, DC_RIGHTS, "0 ~^ Has a copyright or other restriction. ~^ Copyright");
		addField(document, DC_FORMAT, "0 ~^ video/realvideo");
		addField(document, DC_IDENTIFIER, "0 ~^ compadre.org:172");
		addField(document, DCT_AUDIENCE, "0 ~^ Learner ~^ Teacher");
		addField(document, DC_TITLE, "0 ~^ NASA Quest");
		addField(document, DC_TYPE, "0 ~^ Activity ~^ Reference ~^ Curriculum support ~^ Lesson or Activity");
		addField(document, IN_COLLECTION, "oai:nsdl.org:crs:1007936 ~^ 0");
		addField(document, COLL_IMAGE_URL, "0 ~^ http://crs.nsdl.org/brands/1007936.jpg");
		addField(document, COLL_IMAGE_WIDTH, "0 ~^ 100");
		addField(document, COLL_IMAGE_HEIGHT, "0 ~^ 35");
		addField(document, COLL_IMAGE_ALT_TEXT, "0 ~^ Middle School Pathway at ENC");
		addField(document, DC_TITLE, "0 ~^ Middle School Pathway at ENC");
		addField(document, DC_DESCRIPTION, "0 ~^ The NSDL Middle School Pathway at ENC is an evolving site tailored to the needs of mathematics, science, and technology educators. On the site, ENC offers a middle school view into excellent online materials from the National Science Digital Library (NSDL). In this first phase of the project, teachers can examine three electronic publications in which content specialists spotlight superior digital resources and offer teaching tips for important topics.");
		addField(document, DCT_MEDIATOR, "0 ~^ Teachers");
		addField(document, DCT_EDLEVEL, "0 ~^ Teacher");
		// KLUGE: Where did this one come from?
		addField(document, DCT_EDLEVEL_NSDL_EDLEVEL, "Middle School ~^ 0");
		addField(document, DCT_EDLEVEL_NSDL_EDLEVEL, "Kindergarten ~^ 0");
		addField(document, DCT_EDLEVEL_NSDL_EDLEVEL, "Grade 1 ~^ 0");
		addField(document, DCT_EDLEVEL_NSDL_EDLEVEL, "Grade 2 ~^ 0");
		addField(document, DCT_EDLEVEL_NSDL_EDLEVEL, "Grade 3 ~^ 0");
		addField(document, DCT_EDLEVEL_NSDL_EDLEVEL, "Grade 4 ~^ 0");
		addField(document, DCT_EDLEVEL_NSDL_EDLEVEL, "Grade 5 ~^ 0");
		addField(document, DCT_EDLEVEL_NSDL_EDLEVEL, "Grade 6 ~^ 0");
		addField(document, DCT_EDLEVEL_NSDL_EDLEVEL, "Grade 7 ~^ 0");
		addField(document, DCT_EDLEVEL_NSDL_EDLEVEL, "Grade 8 ~^ 0");
		addField(document, DCT_EDLEVEL_NSDL_EDLEVEL, "Grade 9 ~^ 0");
		addField(document, DCT_EDLEVEL_NSDL_EDLEVEL, "Grade 10 ~^ 0");
		addField(document, DCT_EDLEVEL_NSDL_EDLEVEL, "Grade 11 ~^ 0");
		addField(document, DCT_EDLEVEL_NSDL_EDLEVEL, "Grade 12 ~^ 0");
		addField(document, DCT_CREATED_W3CDTF, "2003-10-10T18:17:16Z ~^ 0");
		addField(document, DCT_CREATED_W3CDTF, "2003-07-09T18:35:17Z ~^ 0");
		addField(document, DCT_DATE_ACCEPTED_W3CDTF, "2003-10-10T18:17:17Z ~^ 0");
		addField(document, DCT_DATE_ACCEPTED_W3CDTF, "2003-12-05T14:34:21Z ~^ 0");
		addField(document, DCT_DATE_ACCEPTED_W3CDTF, "2005-12-28T13:57:26Z ~^ 0");
		addField(document, DCT_DATE_SUBMITTED_W3CDTF, "2003-10-10T18:17:16Z ~^ 0");
		addField(document, DCT_MODIFIED_W3CDTF, "2003-12-03T19:45:46Z ~^ 0");
		
		addField(document, COMPOUND_GENRE, "0 ~^ Event text/html video/realvideo Activity ~^ Reference ~^ Curriculum support ~^ Lesson or Activity");
		addField(document, COMPOUND_AUDIENCE, "0 ~^ Learner ~^ Teacher Teachers Middle School ~^ Teacher ~^ Kindergarten ~^ Grade 1 ~^ Grade 2 ~^ Grade 3 ~^ Grade 4 ~^ Grade 5 ~^ Grade 6 ~^ Grade 7 ~^ Grade 8 ~^ Grade 9 ~^ Grade 10 ~^ Grade 11 ~^ Grade 12");
		addField(document, COMPOUND_AGENT, "0 ~^ NASA Ames Educational Technology Team Donald James");
		addField(document, COMPOUND_TITLE, "0 ~^ NASA Quest Middle School Pathway at ENC");
		addField(document, COMPOUND_DESCRIPTION, "0 ~^ NASA Quest is dedicated to bringing NASA people and science to classrooms through the internet. NASA Quest is a resource for educators and kids interested in meeting and learning about NASA people and space science. ~^ Check out this site for activities related to NASA's science and engineering projects . Topics range from solving air traffic control problems to designing a new planet, and there's something for inquisitive minds of all ages. Also, every week you can read a bio of a NASA worker. The NSDL Middle School Pathway at ENC is an evolving site tailored to the needs of mathematics, science, and technology educators. On the site, ENC offers a middle school view into excellent online materials from the National Science Digital Library (NSDL). In this first phase of the project, teachers can examine three electronic publications in which content specialists spotlight superior digital resources and offer teaching tips for important topics.");
		addField(document, ALL_FIELDS, "0 ~^ 2003-12-03T19:45:46Z ~^ 2003-10-10T18:17:16Z ~^ 2003-07-09T18:35:17Z ~^ 2003-10-10T18:17:17Z ~^ 2003-12-05T14:34:21Z ~^ 2005-12-28T13:57:26Z ~^ 2003-10-10T18:17:16Z ~^ "
				+ "Teachers ~^ Teacher ~^ Kindergarten ~^ Grade 1 ~^ Grade 2 ~^ Grade 3 ~^ Grade 4 ~^ Grade 5 ~^ Grade 6 ~^ Grade 7 ~^ Grade 8 ~^ Grade 9 ~^ Grade 10 ~^ Grade 11 ~^ Grade 12 ~^ ");

		addField(document, METADATA_SOURCE, "oai:nsdl.org:2200-20061002193307574T ~^ 1 ~^ http://quest.arc.nasa.gov/");
		addField(document, DC_SUBJECT, "1 ~^ Science - Space/Astronomy ~^ Kindergarten ~^ Early Elementary ~^ Later Elementary ~^ Middle School ~^ High School ~^ space sciences ~^ astronomy ~^ space exploration ~^ solar system");
		addField(document, DC_DESCRIPTION, "1 ~^ This site \"brings NASA people and science to K-12 classrooms via the Internet.\" The site includes chat opportunities, live broadcasts, and video series. The site provides a schedule of events with appropriate grade levels indicated and suggested classroom activities.");
		addField(document, DC_CREATOR, "1 ~^ National Aeronautics and Space Administration (NASA)");
		addField(document, DC_RIGHTS, "1 ~^ Metadata may be used without restrictions as long as the oai identifier remains attached to it.");
		addField(document, DC_TITLE, "1 ~^ NASA Quest");
		addField(document, DC_TYPE, "1 ~^ Lesson/activity plans ~^ Student Email interaction (includes Keypals, Ask an Expert services) ~^ Video");
		addField(document, IN_COLLECTION, "oai:nsdl.org:crs:4708 ~^ 1");
		addField(document, COLL_IMAGE_URL, "1 ~^ http://crs.nsdl.org/brands/merit.jpg");
		addField(document, COLL_IMAGE_WIDTH, "1 ~^ 100");
		addField(document, COLL_IMAGE_HEIGHT, "1 ~^ 35");
		addField(document, COLL_IMAGE_ALT_TEXT, "1 ~^ Michigan Teacher Network");
		addField(document, DC_TITLE, "1 ~^ Michigan Teacher Network");
		addField(document, DC_DESCRIPTION, "1 ~^ Michigan Teacher Network supports Michigan K-12 educators in the successful use of technology by providing best practice, professional development, and evaluated curriculum resources. Curriculum materials are correlated to Michigan Curriculum Framework content standards.");
		addField(document, DCT_AUDIENCE, "1 ~^ Teachers");
		addField(document, DCT_MEDIATOR, "1 ~^ Teachers");
		addField(document, DCT_EDLEVEL_NSDL_EDLEVEL, "Grades Pre-K to 12 ~^ 1");
		addField(document, COMPOUND_GENRE, "1 ~^ Lesson/activity plans ~^ Student Email interaction (includes Keypals, Ask an Expert services) ~^ Video");
		addField(document, COMPOUND_SUBJECT, "1 ~^ Science - Space/Astronomy ~^ Kindergarten ~^ Early Elementary ~^ Later Elementary ~^ Middle School ~^ High School ~^ space sciences ~^ astronomy ~^ space exploration ~^ solar system");
		addField(document, COMPOUND_AUDIENCE, "1 ~^ Teachers Teachers Grades Pre-K to 12");
		addField(document, COMPOUND_AGENT, "1 ~^ National Aeronautics and Space Administration (NASA)");
		addField(document, COMPOUND_TITLE, "1 ~^ NASA Quest Michigan Teacher Network");
		addField(document, COMPOUND_DESCRIPTION, "1 ~^ This site \"brings NASA people and science to K-12 classrooms via the Internet.\" The site includes chat opportunities, live broadcasts, and video series. The site provides a schedule of events with appropriate grade levels indicated and suggested classroom activities. Michigan Teacher Network supports Michigan K-12 educators in the successful use of technology by providing best practice, professional development, and evaluated curriculum resources. Curriculum materials are correlated to Michigan Curriculum Framework content standards.");
		addField(document, ALL_FIELDS, "1 ~^ Grades Pre-K to 12");
		
		addField(document, METADATA_SOURCE, "oai:nsdl.org:crs:4726 ~^ 2 ~^ http://quest.arc.nasa.gov/");
		addField(document, DC_PUBLISHER, "2 ~^ United States. National Aeronautics and Space Administration. Ames Research Center");
		addField(document, DC_SUBJECT, "2 ~^ NASA; education; quest; space science; science; space; education; resource; educator; teacher; kid; k-12; space team; aerospace; solar system; deep space; lesson plan; webcast; events; space shuttle; mars; rockets; astronauts; apollo; support; community; newsletters; about nasa");
		addField(document, DC_TYPE_DCMITYPE, "Collection ~^ 2");
		addField(document, DC_TYPE_DCMITYPE, "InteractiveResource ~^ 2");
		addField(document, DC_DESCRIPTION, "2 ~^ NASA Quest is dedicated to bringing NASA people and science to classrooms through the internet via Space Team Online, Aerospace Team Online, Solar System Online, and Deep Space Online. NASA Quest is the ultimate resource for educators and kids interested in meeting and learning about NASA people and space science. These NASA Quest projects allow students to share in the excitement of NASA's authentic scientific and engineering pursuits like flying the shuttle and International Space Station, exploring distant planets with amazing spacecraft, and aeronautics/airplane research.");
		addField(document, DC_FORMAT_IMT, "text/html ~^ 2");
		addField(document, DC_FORMAT_IMT, "video ~^ 2");
		addField(document, DC_DATE_W3CDTF, "2001-02-06 ~^ 2");
		addField(document, DC_SUBJECT_LCSH, "Science--Study and teaching--United States ~^ 2");
		addField(document, DC_SUBJECT_LCSH, "Solar system ~^ 2");
		addField(document, DC_SUBJECT_GEM, "Space sciences ~^ 2");
		addField(document, DC_LANGUAGE_RFC3066, "en ~^ 2");
		addField(document, DC_TITLE, "2 ~^ NASA Quest");
		addField(document, IN_COLLECTION, "oai:nsdl.org:nsdl:4002 ~^ 2");
		addField(document, DCT_EDLEVEL_NSDL_EDLEVEL, "Grades Pre-K to 12 ~^ 2");
		addField(document, DCT_MEDIATOR, "2 ~^ Teachers");
		addField(document, DCT_EXTENT, "2 ~^ 10636 bytes");
		
		addField(document, COLL_IMAGE_URL, "2 ~^ http://crs.nsdl.org/brands/nasaquest.jpg");
		addField(document, COLL_IMAGE_WIDTH, "2 ~^ 100");
		addField(document, COLL_IMAGE_HEIGHT, "2 ~^ 30");
		addField(document, COLL_IMAGE_ALT_TEXT, "2 ~^ NASA Quest");
		addField(document, COMPOUND_GENRE, "2 ~^ Collection InteractiveResource text/html video");
		addField(document, COMPOUND_SUBJECT, "2 ~^ NASA; education; quest; space science; science; space; education; resource; educator; teacher; kid; k-12; space team; aerospace; solar system; deep space; lesson plan; webcast; events; space shuttle; mars; rockets; astronauts; apollo; support; community; newsletters; about nasa Science--Study and teaching--United States Solar system Space sciences");
		addField(document, COMPOUND_AGENT, "2 ~^ United States. National Aeronautics and Space Administration. Ames Research Center");
		addField(document, COMPOUND_TITLE, "2 ~^ NASA Quest");
		addField(document, COMPOUND_DESCRIPTION, "2 ~^ NASA Quest is dedicated to bringing NASA people and science to classrooms through the internet via Space Team Online, Aerospace Team Online, Solar System Online, and Deep Space Online. NASA Quest is the ultimate resource for educators and kids interested in meeting and learning about NASA people and space science. These NASA Quest projects allow students to share in the excitement of NASA's authentic scientific and engineering pursuits like flying the shuttle and International Space Station, exploring distant planets with amazing spacecraft, and aeronautics/airplane research.");
		addField(document, COMPOUND_AUDIENCE, "2 ~^ Grades Pre-K to 12 ~^ Teachers");
		addField(document, ALL_FIELDS, "2 ~^ 10636 bytes");
		
		addField(document, METADATA_SOURCE, "oai:nsdl.org:2200-20061003055539958T ~^ 3 ~^ http://quest.arc.nasa.gov/");
		addField(document, DC_PUBLISHER, "3 ~^ NASA Ames Educational Technology Team");
		addField(document, DC_SUBJECT, "3 ~^ flight ~^ space exploration ~^ biographies ~^ Astronomy ~^ Astronomy Education");
		addField(document, DC_TYPE_DCMITYPE, "Event ~^ 3");
		addField(document, DC_DESCRIPTION, "3 ~^ NASA Quest is dedicated to bringing NASA people and science to classrooms through the internet. NASA Quest is a resource for educators and kids interested in meeting and learning about NASA people and space science. ~^ Check out this site for activities related to NASA's science and engineering projects . Topics range from solving air traffic control problems to designing a new planet, and there's something for inquisitive minds of all ages. Also, every week you can read a bio of a NASA worker.");
		addField(document, DC_FORMAT_IMT, "text/html ~^ 3");
		addField(document, DC_CREATOR, "3 ~^ Donald James");
		addField(document, DC_LANGUAGE_RFC3066, "en ~^ 3");
		addField(document, DC_RIGHTS, "3 ~^ Has a copyright or other restriction. ~^ Copyright");
		addField(document, DC_FORMAT, "3 ~^ video/realvideo");
		addField(document, DC_IDENTIFIER, "3 ~^ compadre.org:172");
		addField(document, DCT_AUDIENCE, "3 ~^ Teacher ~^ Learner");
		addField(document, DC_TITLE, "3 ~^ NASA Quest");
		addField(document, DC_TYPE, "3 ~^ Reference ~^ Curriculum support ~^ Activity");
		addField(document, IN_COLLECTION, "oai:nsdl.org:crs:439869 ~^ 3");
		addField(document, DCT_CREATED_W3CDTF, "2003-10-10T18:17:16Z ~^ 3");
		addField(document, DCT_CREATED_W3CDTF, "2003-07-09T18:35:17Z ~^ 3");
		addField(document, DCT_DATE_ACCEPTED_W3CDTF, "2003-10-10T18:17:17Z ~^ 3");
		addField(document, DCT_DATE_ACCEPTED_W3CDTF, "2003-12-05T14:34:21Z ~^ 3");
		addField(document, DCT_DATE_ACCEPTED_W3CDTF, "2005-12-28T13:57:26Z ~^ 3");
		addField(document, DCT_DATE_SUBMITTED_W3CDTF, "2003-10-10T18:17:16Z ~^ 3");
		addField(document, DCT_MODIFIED_W3CDTF, "2003-12-03T19:45:46Z ~^ 3");
		addField(document, ALL_FIELDS, "3 ~^ 2003-10-10T18:17:16Z ~^ 2003-07-09T18:35:17Z ~^ 2003-12-03T19:45:46Z");
		
		addField(document, COLL_IMAGE_URL, "3 ~^ http://crs.nsdl.org/brands/439869.jpg");
		addField(document, COLL_IMAGE_WIDTH, "3 ~^ 100");
		addField(document, COLL_IMAGE_HEIGHT, "3 ~^ 20");
		addField(document, COLL_IMAGE_ALT_TEXT, "3 ~^ comPADRE: Resources for physics and astronomy education");
		addField(document, DC_TITLE, "3 ~^ comPADRE: Resources for physics and astronomy education");
		addField(document, DC_DESCRIPTION, "3 ~^ ComPADRE is a set of communities of teachers and students in physics and astronomy, and web-based collections of resources to support their needs.  The communities supported by ComPADRE are groups that can benefit from the sharing of materials, information, and experiences in a web environment.  Example communities include teachers of specific physics or astronomy courses, societies of undergraduate physics and astronomy students, and teachers in specific grade levels, such as high school or middle school teachers.  Resources included in the collections are chosen to enhance the teaching and learning experience, and include multimedia learning objects, lesson plans, tutorials, laboratories and other student activities, and discussion forums on the use these materials.  The different collections are organized under the ComPADRE umbrella, which provides a central database (the Physical Sciences Resource Center), technical support, support for collection editors and community leaders, and the means to coordinate efforts across the communities.");
		addField(document, DCT_MEDIATOR, "3 ~^ Teachers");
		addField(document, DCT_EDLEVEL_NSDL_EDLEVEL, "High School ~^ 3");
		addField(document, DCT_EDLEVEL_NSDL_EDLEVEL, "Middle School ~^ 3");
		addField(document, DCT_EDLEVEL_NSDL_EDLEVEL, "Postsecondary ~^ 3");
		addField(document, COMPOUND_GENRE, "3 ~^ Event text/html video/realvideo Reference ~^ Curriculum support ~^ Activity");
		addField(document, COMPOUND_SUBJECT, "3 ~^ flight ~^ space exploration ~^ biographies ~^ Astronomy ~^ Astronomy Education");
		addField(document, COMPOUND_AUDIENCE, "3 ~^ Teacher ~^ Learner Teachers High School Middle School Postsecondary");
		addField(document, COMPOUND_AGENT, "3 ~^ NASA Ames Educational Technology Team Donald James");
		addField(document, COMPOUND_TITLE, "3 ~^ NASA Quest comPADRE: Resources for physics and astronomy education");
		addField(document, COMPOUND_DESCRIPTION, "3 ~^ NASA Quest is dedicated to bringing NASA people and science to classrooms through the internet. NASA Quest is a resource for educators and kids interested in meeting and learning about NASA people and space science. ~^ Check out this site for activities related to NASA's science and engineering projects . Topics range from solving air traffic control problems to designing a new planet, and there's something for inquisitive minds of all ages. Also, every week you can read a bio of a NASA worker. ComPADRE is a set of communities of teachers and students in physics and astronomy, and web-based collections of resources to support their needs.  The communities supported by ComPADRE are groups that can benefit from the sharing of materials, information, and experiences in a web environment.  Example communities include teachers of specific physics or astronomy courses, societies of undergraduate physics and astronomy students, and teachers in specific grade levels, such as high school or middle school teachers.  Resources included in the collections are chosen to enhance the teaching and learning experience, and include multimedia learning objects, lesson plans, tutorials, laboratories and other student activities, and discussion forums on the use these materials.  The different collections are organized under the ComPADRE umbrella, which provides a central database (the Physical Sciences Resource Center), technical support, support for collection editors and community leaders, and the means to coordinate efforts across the communities.");

		addField(document, METADATA_LAST_MODIFIED, "2007-04-03T01:35:50Z");
		addField(document, ALL_FIELDS, "NASA Ames Educational Technology Team flight ~^ space exploration ~^ biographies ~^ Astronomy ~^ Astronomy Education Event NASA Quest is dedicated to bringing NASA people and science to classrooms through the internet. NASA Quest is a resource for educators and kids interested in meeting and learning about NASA people and space science. ~^ Check out this site for activities related to NASA's science and engineering projects . Topics range from solving air traffic control problems to designing a new planet, and there's something for inquisitive minds of all ages. Also, every week you can read a bio of a NASA worker. text/html Donald James video/realvideo compadre.org:172 Teacher ~^ Learner NASA Quest Reference ~^ " + "Curriculum support ~^ "
				+ "Activity comPADRE: Resources for physics and astronomy education ComPADRE is a set of communities of teachers and students in physics and astronomy, and web-based collections of resources to support their needs.  The communities supported by ComPADRE are groups that can benefit from the sharing of materials, information, and experiences in a web environment.  Example communities include teachers of specific physics or astronomy courses, societies of undergraduate physics and astronomy students, and teachers in specific grade levels, such as high school or middle school teachers.  Resources included in the collections are chosen to enhance the teaching and learning experience, and include multimedia learning objects, lesson plans, tutorials, laboratories and other student activities, and discussion forums on the use these materials.  The different collections are organized under the ComPADRE umbrella, which provides a central database (the Physical Sciences Resource Center), technical support, support for collection editors and community leaders, and the means to coordinate efforts across the communities. Teachers High School Middle School Postsecondary United States. National Aeronautics and Space Administration. Ames Research Center NASA; education; quest; space science; science; space; education; resource; educator; teacher; kid; k-12; space team; aerospace; solar system; deep space; lesson plan; webcast; events; space shuttle; mars; rockets; astronauts; apollo; support; community; newsletters; about nasa Collection InteractiveResource NASA Quest is dedicated to bringing NASA people and science to classrooms through the internet via Space Team Online, Aerospace Team Online, Solar System Online, and Deep Space Online. NASA Quest is the ultimate resource for educators and kids interested in meeting and learning about NASA people and space science. These NASA Quest projects allow students to share in the excitement of NASA's authentic scientific and engineering pursuits like flying the shuttle and International Space Station, exploring distant planets with amazing spacecraft, and aeronautics/airplane research. text/html video 2001-02-06 Science--Study and teaching--United States Solar system Space sciences NASA Quest Science - Space/Astronomy ~^ "
				+ "Kindergarten ~^ Early Elementary ~^ Later Elementary ~^ Middle School ~^ High School ~^ space sciences ~^ astronomy ~^ space exploration ~^ solar system This site \"brings NASA people and science to K-12 classrooms via the Internet.\" The site includes chat opportunities, live broadcasts, and video series. The site provides a schedule of events with appropriate grade levels indicated and suggested classroom activities. National Aeronautics and Space Administration (NASA) NASA Quest Lesson/activity plans ~^ Student Email interaction (includes Keypals, Ask an Expert services) ~^ Video Michigan Teacher Network Michigan Teacher Network supports Michigan K-12 educators in the successful use of technology by providing best practice, professional development, and evaluated curriculum resources. Curriculum materials are correlated to Michigan Curriculum Framework content standards. Teachers Teachers Grades Pre-K to 12 NASA Ames Educational Technology Team Event NASA Quest is dedicated to bringing NASA people and science to classrooms through the internet. NASA Quest is a resource for educators and kids interested in meeting and learning about NASA people and space science. ~^ Check out this site for activities related to NASA's science and engineering projects . Topics range from solving air traffic control problems to designing a new planet, and there's something for inquisitive minds of all ages. Also, every week you can read a bio of a NASA worker. text/html Donald James video/realvideo compadre.org:172 Learner ~^ Teacher NASA Quest Activity ~^ Reference ~^ Curriculum support ~^ Lesson or Activity Middle School Pathway at ENC The NSDL Middle School Pathway at ENC is an evolving site tailored to the needs of mathematics, science, and technology educators. On the site, ENC offers a middle school view into excellent online materials from the National Science Digital Library (NSDL). In this first phase of the project, teachers can examine three electronic publications in which content specialists spotlight superior digital resources and offer teaching tips for important topics. Teachers Middle School ~^ "
				+ "2003-10-10T18:17:17Z ~^ 2003-12-05T14:34:21Z ~^ 2005-12-28T13:57:26Z ~^ 2003-10-10T18:17:16Z");
		addField(document, DOCUMENT_LAST_UPDATED, "2007-05-05T01:14:00Z");

		return document;
	}

	public static final String URLNQThree = "http://quest.arc.nasa.gov/";
	/**
	 * @return
	 */
	public static Document getDocumentNQThree() {
		Document document = new Document();
		addField(document, RESOURCE_IDENTIFIER, "http://quest.arc.nasa.gov/");
		addField(document, DOCUMENT_CREATED, "2000-01-01T01:01:01Z");
		addField(document, METADATA_LAST_MODIFIED, "2007-04-03T01:35:50Z");

		addField(document, METADATA_SOURCE, "oai:nsdl.org:2200-20061002172429873T ~^ 0 ~^ http://quest.arc.nasa.gov/");
		addField(document, DC_PUBLISHER, "0 ~^ NASA Ames Educational Technology Team");
		addField(document, DC_TYPE_DCMITYPE, "Event ~^ 0");
		addField(document, DC_DESCRIPTION, "0 ~^ NASA Quest is dedicated to bringing NASA people and science to classrooms through the internet. NASA Quest is a resource for educators and kids interested in meeting and learning about NASA people and space science. ~^ Check out this site for activities related to NASA's science and engineering projects . Topics range from solving air traffic control problems to designing a new planet, and there's something for inquisitive minds of all ages. Also, every week you can read a bio of a NASA worker.");
		addField(document, DC_FORMAT_IMT, "text/html ~^ 0");
		addField(document, DC_CREATOR, "0 ~^ Donald James");
		addField(document, DC_LANGUAGE_RFC3066, "en ~^ 0");
		addField(document, DC_RIGHTS, "0 ~^ Has a copyright or other restriction. ~^ Copyright");
		addField(document, DC_FORMAT, "0 ~^ video/realvideo");
		addField(document, DC_IDENTIFIER, "0 ~^ compadre.org:172");
		addField(document, DCT_AUDIENCE, "0 ~^ Learner ~^ Teacher");
		addField(document, DC_TITLE, "0 ~^ NASA Quest");
		addField(document, DC_TYPE, "0 ~^ Activity ~^ Reference ~^ Curriculum support ~^ Lesson or Activity");
		addField(document, IN_COLLECTION, "oai:nsdl.org:crs:1007936 ~^ 0");
		addField(document, COLL_IMAGE_URL, "0 ~^ http://crs.nsdl.org/brands/1007936.jpg");
		addField(document, COLL_IMAGE_WIDTH, "0 ~^ 100");
		addField(document, COLL_IMAGE_HEIGHT, "0 ~^ 35");
		addField(document, COLL_IMAGE_ALT_TEXT, "0 ~^ Middle School Pathway at ENC");
		addField(document, DC_TITLE, "0 ~^ Middle School Pathway at ENC");
		addField(document, DC_DESCRIPTION, "0 ~^ The NSDL Middle School Pathway at ENC is an evolving site tailored to the needs of mathematics, science, and technology educators. On the site, ENC offers a middle school view into excellent online materials from the National Science Digital Library (NSDL). In this first phase of the project, teachers can examine three electronic publications in which content specialists spotlight superior digital resources and offer teaching tips for important topics.");
		addField(document, DCT_MEDIATOR, "0 ~^ Teachers");
		addField(document, DCT_EDLEVEL_NSDL_EDLEVEL, "Middle School ~^ 0");
		addField(document, COMPOUND_GENRE, "0 ~^ Event text/html video/realvideo Activity ~^ Reference ~^ Curriculum support ~^ Lesson or Activity");
		addField(document, COMPOUND_AUDIENCE, "0 ~^ Learner ~^ Teacher Teachers Middle School");
		addField(document, COMPOUND_AGENT, "0 ~^ NASA Ames Educational Technology Team Donald James");
		addField(document, COMPOUND_TITLE, "0 ~^ NASA Quest Middle School Pathway at ENC");
		addField(document, COMPOUND_DESCRIPTION, "0 ~^ NASA Quest is dedicated to bringing NASA people and science to classrooms through the internet. NASA Quest is a resource for educators and kids interested in meeting and learning about NASA people and space science. ~^ Check out this site for activities related to NASA's science and engineering projects . Topics range from solving air traffic control problems to designing a new planet, and there's something for inquisitive minds of all ages. Also, every week you can read a bio of a NASA worker. The NSDL Middle School Pathway at ENC is an evolving site tailored to the needs of mathematics, science, and technology educators. On the site, ENC offers a middle school view into excellent online materials from the National Science Digital Library (NSDL). In this first phase of the project, teachers can examine three electronic publications in which content specialists spotlight superior digital resources and offer teaching tips for important topics.");

		addField(document, METADATA_SOURCE, "oai:nsdl.org:2200-20061002193307574T ~^ 1 ~^ http://quest.arc.nasa.gov/");
		addField(document, DC_SUBJECT, "1 ~^ Science - Space/Astronomy ~^ Kindergarten ~^ Early Elementary ~^ Later Elementary ~^ Middle School ~^ High School ~^ space sciences ~^ astronomy ~^ space exploration ~^ solar system");
		addField(document, DC_DESCRIPTION, "1 ~^ This site \"brings NASA people and science to K-12 classrooms via the Internet.\" The site includes chat opportunities, live broadcasts, and video series. The site provides a schedule of events with appropriate grade levels indicated and suggested classroom activities.");
		addField(document, DC_CREATOR, "1 ~^ National Aeronautics and Space Administration (NASA)");
		addField(document, DC_RIGHTS, "1 ~^ Metadata may be used without restrictions as long as the oai identifier remains attached to it.");
		addField(document, DC_TITLE, "1 ~^ NASA Quest");
		addField(document, DC_TYPE, "1 ~^ Lesson/activity plans ~^ Student Email interaction (includes Keypals, Ask an Expert services) ~^ Video");
		addField(document, IN_COLLECTION, "oai:nsdl.org:crs:4708 ~^ 1");
		addField(document, COLL_IMAGE_URL, "1 ~^ http://crs.nsdl.org/brands/merit.jpg");
		addField(document, COLL_IMAGE_WIDTH, "1 ~^ 100");
		addField(document, COLL_IMAGE_HEIGHT, "1 ~^ 35");
		addField(document, COLL_IMAGE_ALT_TEXT, "1 ~^ Michigan Teacher Network");
		addField(document, DC_TITLE, "1 ~^ Michigan Teacher Network");
		addField(document, DC_DESCRIPTION, "1 ~^ Michigan Teacher Network supports Michigan K-12 educators in the successful use of technology by providing best practice, professional development, and evaluated curriculum resources. Curriculum materials are correlated to Michigan Curriculum Framework content standards.");
		addField(document, DCT_AUDIENCE, "1 ~^ Teachers");
		addField(document, DCT_MEDIATOR, "1 ~^ Teachers");
		addField(document, DCT_EDLEVEL_NSDL_EDLEVEL, "Grades Pre-K to 12 ~^ 1");
		addField(document, COMPOUND_GENRE, "1 ~^ Lesson/activity plans ~^ Student Email interaction (includes Keypals, Ask an Expert services) ~^ Video");
		addField(document, COMPOUND_SUBJECT, "1 ~^ Science - Space/Astronomy ~^ Kindergarten ~^ Early Elementary ~^ Later Elementary ~^ Middle School ~^ High School ~^ space sciences ~^ astronomy ~^ space exploration ~^ solar system");
		addField(document, COMPOUND_AUDIENCE, "1 ~^ Teachers Teachers Grades Pre-K to 12");
		addField(document, COMPOUND_AGENT, "1 ~^ National Aeronautics and Space Administration (NASA)");
		addField(document, COMPOUND_TITLE, "1 ~^ NASA Quest Michigan Teacher Network");
		addField(document, COMPOUND_DESCRIPTION, "1 ~^ This site \"brings NASA people and science to K-12 classrooms via the Internet.\" The site includes chat opportunities, live broadcasts, and video series. The site provides a schedule of events with appropriate grade levels indicated and suggested classroom activities. Michigan Teacher Network supports Michigan K-12 educators in the successful use of technology by providing best practice, professional development, and evaluated curriculum resources. Curriculum materials are correlated to Michigan Curriculum Framework content standards.");

		addField(document, METADATA_SOURCE, "oai:nsdl.org:crs:4726 ~^ 2 ~^ http://quest.arc.nasa.gov/");
		addField(document, DC_PUBLISHER, "2 ~^ United States. National Aeronautics and Space Administration. Ames Research Center");
		addField(document, DC_SUBJECT, "2 ~^ NASA; education; quest; space science; science; space; education; resource; educator; teacher; kid; k-12; space team; aerospace; solar system; deep space; lesson plan; webcast; events; space shuttle; mars; rockets; astronauts; apollo; support; community; newsletters; about nasa");
		addField(document, DC_TYPE_DCMITYPE, "Collection ~^ 2");
		addField(document, DC_TYPE_DCMITYPE, "InteractiveResource ~^ 2");
		addField(document, DC_DESCRIPTION, "2 ~^ NASA Quest is dedicated to bringing NASA people and science to classrooms through the internet via Space Team Online, Aerospace Team Online, Solar System Online, and Deep Space Online. NASA Quest is the ultimate resource for educators and kids interested in meeting and learning about NASA people and space science. These NASA Quest projects allow students to share in the excitement of NASA's authentic scientific and engineering pursuits like flying the shuttle and International Space Station, exploring distant planets with amazing spacecraft, and aeronautics/airplane research.");
		addField(document, DC_FORMAT_IMT, "text/html ~^ 2");
		addField(document, DC_FORMAT_IMT, "video ~^ 2");
		addField(document, DC_DATE_W3CDTF, "2001-02-06 ~^ 2");
		addField(document, DC_SUBJECT_LCSH, "Science--Study and teaching--United States ~^ 2");
		addField(document, DC_SUBJECT_LCSH, "Solar system ~^ 2");
		addField(document, DC_SUBJECT_GEM, "Space sciences ~^ 2");
		addField(document, DC_LANGUAGE_RFC3066, "en ~^ 2");
		addField(document, DC_TITLE, "2 ~^ NASA Quest");
		addField(document, DCT_EDLEVEL_NSDL_EDLEVEL, "Grades Pre-K to 12 ~^ 2");
		addField(document, DCT_MEDIATOR, "2 ~^ Teachers");
		addField(document, DCT_EXTENT, "2 ~^ 10636 bytes");
		addField(document, IN_COLLECTION, "oai:nsdl.org:nsdl:4002 ~^ 2");
		addField(document, COLL_IMAGE_URL, "2 ~^ http://crs.nsdl.org/brands/nasaquest.jpg");
		addField(document, COLL_IMAGE_WIDTH, "2 ~^ 100");
		addField(document, COLL_IMAGE_HEIGHT, "2 ~^ 30");
		addField(document, COLL_IMAGE_ALT_TEXT, "2 ~^ NASA Quest");
		addField(document, COMPOUND_GENRE, "2 ~^ Collection InteractiveResource text/html video");
		addField(document, COMPOUND_SUBJECT, "2 ~^ NASA; education; quest; space science; science; space; education; resource; educator; teacher; kid; k-12; space team; aerospace; solar system; deep space; lesson plan; webcast; events; space shuttle; mars; rockets; astronauts; apollo; support; community; newsletters; about nasa Science--Study and teaching--United States Solar system Space sciences");
		addField(document, COMPOUND_AGENT, "2 ~^ United States. National Aeronautics and Space Administration. Ames Research Center");
		addField(document, COMPOUND_TITLE, "2 ~^ NASA Quest");
		addField(document, COMPOUND_DESCRIPTION, "2 ~^ NASA Quest is dedicated to bringing NASA people and science to classrooms through the internet via Space Team Online, Aerospace Team Online, Solar System Online, and Deep Space Online. NASA Quest is the ultimate resource for educators and kids interested in meeting and learning about NASA people and space science. These NASA Quest projects allow students to share in the excitement of NASA's authentic scientific and engineering pursuits like flying the shuttle and International Space Station, exploring distant planets with amazing spacecraft, and aeronautics/airplane research.");
		addField(document, COMPOUND_AUDIENCE, "2 ~^ Grades Pre-K to 12 ~^ Teachers");

		// KLUGE -- TOTALLY BOGUS -- This is a lot shorter than expected!
		addField(document, ALL_FIELDS, "United States. National Aeronautics and Space Administration. Ames Research Center NASA; education; quest; space science; science; space; education; resource; educator; teacher; kid; k-12; space team; aerospace; solar system; deep space; lesson plan; webcast; events; space shuttle; mars; rockets; astronauts; apollo; support; community; newsletters; about nasa Collection InteractiveResource NASA Quest is dedicated to bringing NASA people and science to classrooms through the internet via Space Team Online, Aerospace Team Online, Solar System Online, and Deep Space Online. NASA Quest is the ultimate resource for educators and kids interested in meeting and learning about NASA people and space science. These NASA Quest projects allow students to share in the excitement of NASA's authentic scientific and engineering pursuits like flying the shuttle and International Space Station, exploring distant planets with amazing spacecraft, and aeronautics/airplane research. text/html video 2001-02-06 Science--Study and teaching--United States Solar system Space sciences NASA Quest");
		addField(document, ALL_FIELDS, "Donald James text/html NASA Quest Middle School Pathway at ENC NASA Ames Educational Technology Team Event compadre.org:172 NASA Quest is dedicated to bringing NASA people and science to classrooms through the internet. NASA Quest is a resource for educators and kids interested in meeting and learning about NASA people and space science. Check out this site for activities related to NASA's science and engineering projects . Topics range from solving air traffic control problems to designing a new planet, and there's something for inquisitive minds of all ages. Also, every week you can read a bio of a NASA worker. The NSDL Middle School Pathway at ENC is an evolving site tailored to the needs of mathematics, science, and technology educators. On the site, ENC offers a middle school view into excellent online materials from the National Science Digital Library (NSDL). In this first phase of the project, teachers can examine three electronic publications in which content specialists spotlight superior digital resources and offer teaching tips for important topics. Teachers Middle School video/realvideo Activity Reference Curriculum support Lesson or Activity Learner Teacher");
		addField(document, ALL_FIELDS, "National Aeronautics and Space Administration (NASA) NASA Quest Michigan Teacher Network Science - Space/Astronomy Kindergarten Early Elementary Later Elementary Middle School High School space sciences astronomy space exploration solar system This site \"brings NASA people and science to K-12 classrooms via the Internet.\" The site includes chat opportunities, live broadcasts, and video series. The site provides a schedule of events with appropriate grade levels indicated and suggested classroom activities. Michigan Teacher Network supports Michigan K-12 educators in the successful use of technology by providing best practice, professional development, and evaluated curriculum resources. Curriculum materials are correlated to Michigan Curriculum Framework content standards. Teachers Grades Pre-K to 12 Lesson/activity plans Student Email interaction (includes Keypals, Ask an Expert services) Video Teachers");
		addField(document, ALL_FIELDS, "Grades Pre-K to 12 ~^ Teachers ~^ 10636 bytes");
		addField(document, DOCUMENT_LAST_UPDATED, "2002-02-02T02:02:02Z");

		return document;
	}
	public static final String URLNQTwoModded = "http://quest.arc.nasa.gov/";
	/**
	 * @return
	 */
	public static Document getDocumentNQTwoModded() {
		Document document = new Document();
		addField(document, RESOURCE_IDENTIFIER, "http://quest.arc.nasa.gov/");
		addField(document, DOCUMENT_CREATED, "2000-01-01T01:01:01Z");

		addField(document, METADATA_SOURCE, "oai:nsdl.org:2200-20061002172429873T ~^ 0 ~^ http://quest.arc.nasa.gov/");
		addField(document, DC_PUBLISHER, "0 ~^ NASA Ames Educational Technology Team");
		addField(document, DC_TYPE_DCMITYPE, "Event ~^ 0");
		addField(document, DC_DESCRIPTION, "0 ~^ NASA Quest is dedicated to bringing NASA people and science to classrooms through the internet. NASA Quest is a resource for educators and kids interested in meeting and learning about NASA people and space science. ~^ Check out this site for activities related to NASA's science and engineering projects . Topics range from solving air traffic control problems to designing a new planet, and there's something for inquisitive minds of all ages. Also, every week you can read a bio of a NASA worker.");
		addField(document, DC_FORMAT_IMT, "text/html ~^ 0");
		addField(document, DC_CREATOR, "0 ~^ Donald James");
		addField(document, DC_LANGUAGE_RFC3066, "en ~^ 0");
		addField(document, DC_RIGHTS, "0 ~^ Has a copyright or other restriction. ~^ Copyright");
		addField(document, DC_FORMAT, "0 ~^ video/realvideo");
		addField(document, DC_IDENTIFIER, "0 ~^ compadre.org:172");
		addField(document, DCT_AUDIENCE, "0 ~^ Learner ~^ Teacher");
		addField(document, DC_TITLE, "0 ~^ NASA Quest");
		addField(document, DC_TYPE, "0 ~^ Activity ~^ Reference ~^ Curriculum support ~^ Lesson or Activity");
		addField(document, IN_COLLECTION, "oai:nsdl.org:crs:1007936 ~^ 0");
		addField(document, COLL_IMAGE_URL, "0 ~^ http://crs.nsdl.org/brands/1007936.jpg");
		addField(document, COLL_IMAGE_WIDTH, "0 ~^ 100");
		addField(document, COLL_IMAGE_HEIGHT, "0 ~^ 35");
		addField(document, COLL_IMAGE_ALT_TEXT, "0 ~^ Middle School Pathway at ENC");
		addField(document, DC_TITLE, "0 ~^ Middle School Pathway at ENC");
		addField(document, DC_DESCRIPTION, "0 ~^ The NSDL Middle School Pathway at ENC is an evolving site tailored to the needs of mathematics, science, and technology educators. On the site, ENC offers a middle school view into excellent online materials from the National Science Digital Library (NSDL). In this first phase of the project, teachers can examine three electronic publications in which content specialists spotlight superior digital resources and offer teaching tips for important topics.");
		addField(document, DCT_MEDIATOR, "0 ~^ Teachers");
		addField(document, DCT_EDLEVEL_NSDL_EDLEVEL, "Middle School ~^ 0");
		addField(document, COMPOUND_GENRE, "0 ~^ Event text/html video/realvideo Activity ~^ Reference ~^ Curriculum support ~^ Lesson or Activity");
		addField(document, COMPOUND_AUDIENCE, "0 ~^ Learner ~^ Teacher Teachers Middle School");
		addField(document, COMPOUND_AGENT, "0 ~^ NASA Ames Educational Technology Team Donald James");
		addField(document, COMPOUND_TITLE, "0 ~^ NASA Quest Middle School Pathway at ENC");
		addField(document, COMPOUND_DESCRIPTION, "0 ~^ NASA Quest is dedicated to bringing NASA people and science to classrooms through the internet. NASA Quest is a resource for educators and kids interested in meeting and learning about NASA people and space science. ~^ Check out this site for activities related to NASA's science and engineering projects . Topics range from solving air traffic control problems to designing a new planet, and there's something for inquisitive minds of all ages. Also, every week you can read a bio of a NASA worker. The NSDL Middle School Pathway at ENC is an evolving site tailored to the needs of mathematics, science, and technology educators. On the site, ENC offers a middle school view into excellent online materials from the National Science Digital Library (NSDL). In this first phase of the project, teachers can examine three electronic publications in which content specialists spotlight superior digital resources and offer teaching tips for important topics.");

		addField(document, METADATA_LAST_MODIFIED, "2007-04-03T01:35:50Z");

		addField(document, METADATA_SOURCE, "oai:nsdl.org:2200-20061002193307574T ~^ 1 ~^ http://quest.arc.nasa.gov/");
		addField(document, DC_PUBLISHER, "1 ~^ Added Publisher");
		addField(document, DC_SUBJECT, "1 ~^ New Science - Space/Astronomy ~^ New Kindergarten");
		addField(document, DC_DESCRIPTION, "1 ~^ New description");
		addField(document, DC_CREATOR, "1 ~^ New National Aeronautics and Space Administration (NASA)");
		addField(document, DC_TITLE, "1 ~^ New Title1 ~^ New Title2");
		addField(document, DC_TYPE, "1 ~^ New type1 ~^ New type2");
		addField(document, IN_COLLECTION, "oai:nsdl.org:crs:4708 ~^ 1");
		addField(document, COLL_IMAGE_URL, "1 ~^ http://crs.nsdl.org/brands/merit.jpg");
		addField(document, COLL_IMAGE_WIDTH, "1 ~^ 100");
		addField(document, COLL_IMAGE_HEIGHT, "1 ~^ 35");
		addField(document, COLL_IMAGE_ALT_TEXT, "1 ~^ Michigan Teacher Network");
		addField(document, DC_TITLE, "1 ~^ Michigan Teacher Network");
		addField(document, DC_DESCRIPTION, "1 ~^ Michigan Teacher Network supports Michigan K-12 educators in the successful use of technology by providing best practice, professional development, and evaluated curriculum resources. Curriculum materials are correlated to Michigan Curriculum Framework content standards.");
		addField(document, DCT_AUDIENCE, "1 ~^ Teachers");
		addField(document, DCT_MEDIATOR, "1 ~^ Teachers");
		addField(document, DCT_EDLEVEL_NSDL_EDLEVEL, "Grades Pre-K to 12 ~^ 1");
		addField(document, COMPOUND_GENRE, "1 ~^ New type1 ~^ New type2");
		addField(document, COMPOUND_SUBJECT, "1 ~^ New Science - Space/Astronomy ~^ New Kindergarten");
		addField(document, COMPOUND_AUDIENCE, "1 ~^ Teachers Teachers Grades Pre-K to 12");
		addField(document, COMPOUND_AGENT, "1 ~^ Added Publisher New National Aeronautics and Space Administration (NASA)");
		addField(document, COMPOUND_TITLE, "1 ~^ New Title1 ~^ New Title2 Michigan Teacher Network");
		addField(document, COMPOUND_DESCRIPTION, "1 ~^ New description Michigan Teacher Network supports Michigan K-12 educators in the successful use of technology by providing best practice, professional development, and evaluated curriculum resources. Curriculum materials are correlated to Michigan Curriculum Framework content standards.");

		addField(document, ALL_FIELDS, "Added Publisher New Science - Space/Astronomy ~^ New Kindergarten New description New National Aeronautics and Space Administration (NASA) New Title1 ~^ New Title2 New type1 ~^ New type2 Michigan Teacher Network Michigan Teacher Network supports Michigan K-12 educators in the successful use of technology by providing best practice, professional development, and evaluated curriculum resources. Curriculum materials are correlated to Michigan Curriculum Framework content standards. Teachers Teachers Grades Pre-K to 12 NASA Ames Educational Technology Team Event NASA Quest is dedicated to bringing NASA people and science to classrooms through the internet. NASA Quest is a resource for educators and kids interested in meeting and learning about NASA people and space science. ~^ Check out this site for activities related to NASA's science and engineering projects . Topics range from solving air traffic control problems to designing a new planet, and there's something for inquisitive minds of all ages. Also, every week you can read a bio of a NASA worker. text/html Donald James video/realvideo compadre.org:172 Learner ~^ Teacher NASA Quest Activity ~^ Reference ~^ Curriculum support ~^ Lesson or Activity Middle School Pathway at ENC The NSDL Middle School Pathway at ENC is an evolving site tailored to the needs of mathematics, science, and technology educators. On the site, ENC offers a middle school view into excellent online materials from the National Science Digital Library (NSDL). In this first phase of the project, teachers can examine three electronic publications in which content specialists spotlight superior digital resources and offer teaching tips for important topics. Teachers Middle School");
		addField(document, DOCUMENT_LAST_UPDATED, "2002-02-02T02:02:02Z");

		return document;
	}

	public static final String URLNQTwoMinusFirst = "http://quest.arc.nasa.gov/";
	/**
	 * @return
	 */
	public static Document getDocumentNQTwoMinusFirst() {
		Document document = new Document();
		addField(document, RESOURCE_IDENTIFIER, "http://quest.arc.nasa.gov/");
		addField(document, DOCUMENT_CREATED, "2000-01-01T01:01:01Z");

		addField(document, METADATA_SOURCE, "oai:nsdl.org:2200-20061002193307574T ~^ 1 ~^ http://quest.arc.nasa.gov/");
		addField(document, DC_SUBJECT, "1 ~^ Science - Space/Astronomy ~^ Kindergarten ~^ Early Elementary ~^ Later Elementary ~^ Middle School ~^ High School ~^ space sciences ~^ astronomy ~^ space exploration ~^ solar system");
		addField(document, DC_DESCRIPTION, "1 ~^ This site \"brings NASA people and science to K-12 classrooms via the Internet.\" The site includes chat opportunities, live broadcasts, and video series. The site provides a schedule of events with appropriate grade levels indicated and suggested classroom activities.");
		addField(document, DC_CREATOR, "1 ~^ National Aeronautics and Space Administration (NASA)");
		addField(document, DC_RIGHTS, "1 ~^ Metadata may be used without restrictions as long as the oai identifier remains attached to it.");
		addField(document, DC_TITLE, "1 ~^ NASA Quest");
		addField(document, DC_TYPE, "1 ~^ Lesson/activity plans ~^ Student Email interaction (includes Keypals, Ask an Expert services) ~^ Video");
		addField(document, IN_COLLECTION, "oai:nsdl.org:crs:4708 ~^ 1");
		addField(document, COLL_IMAGE_URL, "1 ~^ http://crs.nsdl.org/brands/merit.jpg");
		addField(document, COLL_IMAGE_WIDTH, "1 ~^ 100");
		addField(document, COLL_IMAGE_HEIGHT, "1 ~^ 35");
		addField(document, COLL_IMAGE_ALT_TEXT, "1 ~^ Michigan Teacher Network");
		addField(document, DC_TITLE, "1 ~^ Michigan Teacher Network");
		addField(document, DC_DESCRIPTION, "1 ~^ Michigan Teacher Network supports Michigan K-12 educators in the successful use of technology by providing best practice, professional development, and evaluated curriculum resources. Curriculum materials are correlated to Michigan Curriculum Framework content standards.");
		addField(document, DCT_AUDIENCE, "1 ~^ Teachers");
		addField(document, DCT_MEDIATOR, "1 ~^ Teachers");
		addField(document, DCT_EDLEVEL_NSDL_EDLEVEL, "Grades Pre-K to 12 ~^ 1");
		addField(document, COMPOUND_GENRE, "1 ~^ Lesson/activity plans ~^ Student Email interaction (includes Keypals, Ask an Expert services) ~^ Video");
		addField(document, COMPOUND_SUBJECT, "1 ~^ Science - Space/Astronomy ~^ Kindergarten ~^ Early Elementary ~^ Later Elementary ~^ Middle School ~^ High School ~^ space sciences ~^ astronomy ~^ space exploration ~^ solar system");
		addField(document, COMPOUND_AUDIENCE, "1 ~^ Teachers Teachers Grades Pre-K to 12");
		addField(document, COMPOUND_AGENT, "1 ~^ National Aeronautics and Space Administration (NASA)");
		addField(document, COMPOUND_TITLE, "1 ~^ NASA Quest Michigan Teacher Network");
		addField(document, COMPOUND_DESCRIPTION, "1 ~^ This site \"brings NASA people and science to K-12 classrooms via the Internet.\" The site includes chat opportunities, live broadcasts, and video series. The site provides a schedule of events with appropriate grade levels indicated and suggested classroom activities. Michigan Teacher Network supports Michigan K-12 educators in the successful use of technology by providing best practice, professional development, and evaluated curriculum resources. Curriculum materials are correlated to Michigan Curriculum Framework content standards.");

		addField(document, METADATA_LAST_MODIFIED, "2007-04-03T01:35:50Z");

		addField(document, ALL_FIELDS, "Science - Space/Astronomy ~^ Kindergarten ~^ Early Elementary ~^ Later Elementary ~^ Middle School ~^ High School ~^ space sciences ~^ astronomy ~^ space exploration ~^ solar system This site \"brings NASA people and science to K-12 classrooms via the Internet.\" The site includes chat opportunities, live broadcasts, and video series. The site provides a schedule of events with appropriate grade levels indicated and suggested classroom activities. National Aeronautics and Space Administration (NASA) NASA Quest Lesson/activity plans ~^ Student Email interaction (includes Keypals, Ask an Expert services) ~^ Video Michigan Teacher Network Michigan Teacher Network supports Michigan K-12 educators in the successful use of technology by providing best practice, professional development, and evaluated curriculum resources. Curriculum materials are correlated to Michigan Curriculum Framework content standards. Teachers Teachers Grades Pre-K to 12");
		addField(document, DOCUMENT_LAST_UPDATED, "2002-02-02T02:02:02Z");

		return document;
	}

	public static final String URLNQTwoMinusBoth = "http://quest.arc.nasa.gov/";
	/**
	 * @return
	 */
	public static Document getDocumentNQTwoMinusBoth() {
		Document document = new Document();
		addField(document, RESOURCE_IDENTIFIER, "http://quest.arc.nasa.gov/");
		addField(document, DOCUMENT_CREATED, "2000-01-01T01:01:01Z");

		// KLUGE -- TOTALLY BOGUS -- NONE OF THIS SHOULD REMAIN!!!
		addField(document, METADATA_SOURCE, "oai:nsdl.org:2200-20061002172429873T ~^ 0 ~^ http://quest.arc.nasa.gov/");
		addField(document, DC_PUBLISHER, "0 ~^ NASA Ames Educational Technology Team");
		addField(document, DC_TYPE_DCMITYPE, "Event ~^ 0");
		addField(document, DC_DESCRIPTION, "0 ~^ NASA Quest is dedicated to bringing NASA people and science to classrooms through the internet. NASA Quest is a resource for educators and kids interested in meeting and learning about NASA people and space science. ~^ Check out this site for activities related to NASA's science and engineering projects . Topics range from solving air traffic control problems to designing a new planet, and there's something for inquisitive minds of all ages. Also, every week you can read a bio of a NASA worker.");
		addField(document, DC_FORMAT_IMT, "text/html ~^ 0");
		addField(document, DC_CREATOR, "0 ~^ Donald James");
		addField(document, DC_LANGUAGE_RFC3066, "en ~^ 0");
		addField(document, DC_RIGHTS, "0 ~^ Has a copyright or other restriction. ~^ Copyright");
		addField(document, DC_FORMAT, "0 ~^ video/realvideo");
		addField(document, DC_IDENTIFIER, "0 ~^ compadre.org:172");
		addField(document, DCT_AUDIENCE, "0 ~^ Learner ~^ Teacher");
		addField(document, DC_TITLE, "0 ~^ NASA Quest");
		addField(document, DC_TYPE, "0 ~^ Activity ~^ Reference ~^ Curriculum support ~^ Lesson or Activity");
		addField(document, IN_COLLECTION, "oai:nsdl.org:crs:1007936 ~^ 0");
		addField(document, COLL_IMAGE_URL, "0 ~^ http://crs.nsdl.org/brands/1007936.jpg");
		addField(document, COLL_IMAGE_WIDTH, "0 ~^ 100");
		addField(document, COLL_IMAGE_HEIGHT, "0 ~^ 35");
		addField(document, COLL_IMAGE_ALT_TEXT, "0 ~^ Middle School Pathway at ENC");
		addField(document, DC_TITLE, "0 ~^ Middle School Pathway at ENC");
		addField(document, DC_DESCRIPTION, "0 ~^ The NSDL Middle School Pathway at ENC is an evolving site tailored to the needs of mathematics, science, and technology educators. On the site, ENC offers a middle school view into excellent online materials from the National Science Digital Library (NSDL). In this first phase of the project, teachers can examine three electronic publications in which content specialists spotlight superior digital resources and offer teaching tips for important topics.");
		addField(document, DCT_MEDIATOR, "0 ~^ Teachers");
		addField(document, DCT_EDLEVEL_NSDL_EDLEVEL, "Middle School ~^ 0");
		addField(document, COMPOUND_GENRE, "0 ~^ Event text/html video/realvideo Activity ~^ Reference ~^ Curriculum support ~^ Lesson or Activity");
		addField(document, COMPOUND_AUDIENCE, "0 ~^ Learner ~^ Teacher Teachers Middle School");
		addField(document, COMPOUND_AGENT, "0 ~^ NASA Ames Educational Technology Team Donald James");
		addField(document, COMPOUND_TITLE, "0 ~^ NASA Quest Middle School Pathway at ENC");
		addField(document, COMPOUND_DESCRIPTION, "0 ~^ NASA Quest is dedicated to bringing NASA people and science to classrooms through the internet. NASA Quest is a resource for educators and kids interested in meeting and learning about NASA people and space science. ~^ Check out this site for activities related to NASA's science and engineering projects . Topics range from solving air traffic control problems to designing a new planet, and there's something for inquisitive minds of all ages. Also, every week you can read a bio of a NASA worker. The NSDL Middle School Pathway at ENC is an evolving site tailored to the needs of mathematics, science, and technology educators. On the site, ENC offers a middle school view into excellent online materials from the National Science Digital Library (NSDL). In this first phase of the project, teachers can examine three electronic publications in which content specialists spotlight superior digital resources and offer teaching tips for important topics.");

		addField(document, METADATA_LAST_MODIFIED, "2007-04-03T01:35:50Z");

		addField(document, ALL_FIELDS, "NASA Ames Educational Technology Team Event NASA Quest is dedicated to bringing NASA people and science to classrooms through the internet. NASA Quest is a resource for educators and kids interested in meeting and learning about NASA people and space science. ~^ Check out this site for activities related to NASA's science and engineering projects . Topics range from solving air traffic control problems to designing a new planet, and there's something for inquisitive minds of all ages. Also, every week you can read a bio of a NASA worker. text/html Donald James video/realvideo compadre.org:172 Learner ~^ Teacher NASA Quest Activity ~^ Reference ~^ Curriculum support ~^ Lesson or Activity Middle School Pathway at ENC The NSDL Middle School Pathway at ENC is an evolving site tailored to the needs of mathematics, science, and technology educators. On the site, ENC offers a middle school view into excellent online materials from the National Science Digital Library (NSDL). In this first phase of the project, teachers can examine three electronic publications in which content specialists spotlight superior digital resources and offer teaching tips for important topics. Teachers Middle School");
		addField(document, DOCUMENT_LAST_UPDATED, "2002-02-02T02:02:02Z");

		return document;
	}

	/**
	 * Added these to figure out the problem with ED-LEVEL.
	 */
	public static final String URLmatDL = "http://matdl.org/";
	public static Document getDocumentMatDL() {
		Document document = new Document();
		addField(document, RESOURCE_IDENTIFIER, "http://matdl.org/");
		addField(document, DOCUMENT_CREATED, "2000-01-01T01:01:01Z");

		addField(document, METADATA_SOURCE, "oai:nsdl.org:crs:433248 ~^ 0 ~^ http://matdl.org/");
		addField(document, DC_TITLE, "0 ~^ Materials Digital Library Pathway");
		addField(document, DCT_ALTERNATIVE, "0 ~^ MatDL ~^ MatDL Pathway ~^ matdl.org");
		addField(document, DC_DESCRIPTION, "0 ~^ A very, very long description. A totally long one. Really, really long.");
		addField(document, DC_CONTRIBUTOR, "0 ~^ National Institute of Standards and Technology. Materials Science and Engineering Lab. ~^ Massachusetts Institute of Technology. Materials Science and Engineering Dept. ~^ University of Michigan. Materials Science and Engineering Dept. ~^ University of Michigan. Chemical Engineering Dept. ~^ Kent State University. Materials Informatics Lab. ~^ Iowa State University. Materials Science and Engineering Dept. ~^ Purdue University. School of Materials Engineering.");
		addField(document, DC_SUBJECT, "0 ~^ Materials research ~^ Materials science ~^ Materials education ~^ Soft matter");
		addField(document, DC_SUBJECT_LCSH, "Nanoscience ~^ 0");
		addField(document, DC_SUBJECT_LCSH, "Materials science ~^ 0");
		addField(document, DC_SUBJECT_LCSH, "Materials ~^ 0");
		addField(document, DC_SUBJECT_LCSH, "Materials science--Study and teaching ~^ 0");
		addField(document, DC_SUBJECT_LCSH, "Materials science--Research ~^ 0");
		addField(document, DC_SUBJECT_GEM, "Physical sciences ~^ 0");
		addField(document, DC_TYPE_DCMITYPE, "Collection ~^ 0");
		addField(document, DC_TYPE_DCMITYPE, "Text ~^ 0");
		addField(document, DC_LANGUAGE_RFC3066, "en ~^ 0");
		addField(document, DCT_AUDIENCE, "0 ~^ Educator ~^ Learner ~^ Researcher");
		addField(document, DCT_EDLEVEL, "0 ~^ Graduate/Professional");
		addField(document, DCT_EDLEVEL_NSDL_EDLEVEL, "Undergraduate (Lower Division) ~^ 0");
		addField(document, DCT_EDLEVEL_NSDL_EDLEVEL, "Undergraduate (Upper Division) ~^ 0");
		addField(document, DCT_EDLEVEL_NSDL_EDLEVEL, "Higher Education ~^ 0");
		addField(document, DC_FORMAT_IMT, "text/html ~^ 0");

		addField(document, COMPOUND_AGENT, "0 ~^ National Institute of Standards and Technology. Materials Science and Engineering Lab. ~^ Massachusetts Institute of Technology. Materials Science and Engineering Dept. ~^ University of Michigan. Materials Science and Engineering Dept. ~^ University of Michigan. Chemical Engineering Dept. ~^ Kent State University. Materials Informatics Lab. ~^ Iowa State University. Materials Science and Engineering Dept. ~^ Purdue University. School of Materials Engineering.");
		addField(document, COMPOUND_AUDIENCE, "0 ~^ Educator ~^ Learner ~^ Researcher ~^ Graduate/Professional ~^ Undergraduate (Lower Division) ~^ Undergraduate (Upper Division) ~^ Higher Education");
		addField(document, COMPOUND_DESCRIPTION, "0 ~^ A very, very long description. A totally long one. Really, really long.");
		addField(document, COMPOUND_GENRE, "0 ~^ Collection ~^ Text ~^ text/html");
		addField(document, COMPOUND_TITLE, "0 ~^ Materials Digital Library Pathway ~^ MatDL ~^ MatDL Pathway ~^ matdl.org");
		addField(document, COMPOUND_SUBJECT, "0 ~^ Materials research ~^ Materials science ~^ Materials education ~^ Soft matter ~^ Nanoscience ~^ Materials science ~^ Materials ~^ Materials science--Study and teaching ~^ Materials science--Research ~^ Physical sciences");
				
		addField(document, IN_COLLECTION, "oai:nsdl.org:nsdl:4002 ~^ 0");
		addField(document, COLL_IMAGE_URL, "0 ~^ http://crs.nsdl.org/brands/433248.jpg");
		addField(document, COLL_IMAGE_WIDTH, "0 ~^ 100");
		addField(document, COLL_IMAGE_HEIGHT, "0 ~^ 30");
		addField(document, COLL_IMAGE_ALT_TEXT, "0 ~^ Materials Digital Library Pathway");

		addField(document, METADATA_LAST_MODIFIED, "2007-08-11T02:42:08Z");

		addField(document, ALL_FIELDS, "A very, very long description. A totally long one. Really, really long. ~^ National Institute of Standards and Technology. Materials Science and Engineering Lab. ~^ Massachusetts Institute of Technology. Materials Science and Engineering Dept. ~^ University of Michigan. Materials Science and Engineering Dept. ~^ University of Michigan. Chemical Engineering Dept. ~^ Kent State University. Materials Informatics Lab. ~^ Iowa State University. Materials Science and Engineering Dept. ~^ Purdue University. School of Materials Engineering. ~^ Physical sciences ~^ Nanoscience ~^ Materials science ~^ Materials ~^ Materials science--Study and teaching ~^ Materials science--Research ~^ text/html ~^ Materials Digital Library Pathway ~^ MatDL ~^ MatDL Pathway ~^ matdl.org ~^ Materials research ~^ Materials science ~^ Materials education ~^ Soft matter ~^ Educator ~^ Learner ~^ Researcher ~^ Graduate/Professional ~^ Undergraduate (Lower Division) ~^ Undergraduate (Upper Division) ~^ Higher Education ~^ Collection ~^ Text");
		addField(document, DOCUMENT_LAST_UPDATED, "2007-08-11T02:42:08Z");

		return document;
	}

	private static Field assembleField(LuceneFieldSpec spec, String value) {
		return new Field(spec.getName(), value, spec.getStore(), spec.getIndex());
	}

	private static void addField(Document document, LuceneFieldSpec spec, String value) {
		document.add(assembleField(spec, value));
		if (spec.isStemmable()) {
			document.add(assembleField(spec.getStemmedSpec(), value));
		}
	}

	private ExpectedDocuments() {
		// nothing to instantiate here.
	}
}
