/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package org.nsdl.search.testoaiparsing;

import static org.nsdl.search.lucene.SearchIndexFieldSpecs.COLL_IMAGE_ALT_TEXT;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.COLL_IMAGE_HEIGHT;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.COLL_IMAGE_URL;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.COLL_IMAGE_WIDTH;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.COMPOUND_AGENT;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.COMPOUND_AUDIENCE;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.COMPOUND_DESCRIPTION;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.COMPOUND_GENRE;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.COMPOUND_SUBJECT;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.COMPOUND_TITLE;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DCT_AUDIENCE;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DCT_EDLEVEL_NSDL_EDLEVEL;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DCT_MEDIATOR;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DC_CREATOR;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DC_DESCRIPTION;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DC_FORMAT;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DC_FORMAT_IMT;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DC_IDENTIFIER;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DC_LANGUAGE_RFC3066;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DC_PUBLISHER;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DC_RIGHTS;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DC_SUBJECT;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DC_TITLE;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DC_TYPE;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DC_TYPE_DCMITYPE;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DOCUMENT_CREATED;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DOCUMENT_LAST_UPDATED;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.IN_COLLECTION;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.METADATA_LAST_MODIFIED;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.METADATA_SOURCE;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.RESOURCE_IDENTIFIER;

import org.apache.lucene.document.Document;
import org.apache.lucene.document.Field;
import org.nsdl.search.lucene.LuceneFieldSpec;

/**
 * 
 * @author jblake
 */
public class ExpectedIndexedDocuments {
	public static final Document NQ_2_METADATAS;
	static {
		Document document = new Document();
		addField(document, RESOURCE_IDENTIFIER, "http://quest.arc.nasa.gov/");
		addField(document, DOCUMENT_CREATED, "2006-12-01T23:31:09Z");
		addField(document, METADATA_LAST_MODIFIED, "2007-04-03T01:35:50Z");
		addField(document, DOCUMENT_LAST_UPDATED, "");
		addField(document, METADATA_SOURCE,
				"oai:nsdl.org:2200-20061002172429873T ~^ 0 ~^ http://quest.arc.nasa.gov/");
		addField(document, DC_PUBLISHER,
				"0 ~^ NASA Ames Educational Technology Team");
		addField(document, DC_TYPE_DCMITYPE, "Event ~^ 0");
		addField(
				document,
				DC_DESCRIPTION,
				"0 ~^ NASA Quest is dedicated to bringing NASA people and science to classrooms through the internet. NASA Quest is a resource for educators and kids interested in meeting and learning about NASA people and space science. ~^ Check out this site for activities related to NASA's science and engineering projects . Topics range from solving air traffic control problems to designing a new planet, and there's something for inquisitive minds of all ages. Also, every week you can read a bio of a NASA worker.");
		addField(document, DC_FORMAT_IMT, "text/html ~^ 0");
		addField(document, DC_CREATOR, "0 ~^ Donald James");
		addField(document, DC_LANGUAGE_RFC3066, "en ~^ 0");
		addField(document, DC_RIGHTS,
				"0 ~^ Has a copyright or other restriction. ~^ Copyright");
		addField(document, DC_FORMAT, "0 ~^ video/realvideo");
		addField(document, DC_IDENTIFIER, "0 ~^ compadre.org:172");
		addField(document, DCT_AUDIENCE, "0 ~^ Learner ~^ Teacher");
		addField(document, DC_TITLE, "0 ~^ NASA Quest");
		addField(document, DC_TYPE,
				"0 ~^ Activity ~^ Reference ~^ Curriculum support ~^ Lesson or Activity");
		addField(document, IN_COLLECTION, "oai:nsdl.org:crs:1007936 ~^ 0");
		addField(document, COLL_IMAGE_URL,
				"0 ~^ http://crs.nsdl.org/brands/1007936.jpg");
		addField(document, COLL_IMAGE_WIDTH, "0 ~^ 100");
		addField(document, COLL_IMAGE_HEIGHT, "0 ~^ 35");
		addField(document, COLL_IMAGE_ALT_TEXT,
				"0 ~^ Middle School Pathway at ENC");
		addField(document, DC_TITLE, "0 ~^ Middle School Pathway at ENC");
		addField(
				document,
				DC_DESCRIPTION,
				"0 ~^ The NSDL Middle School Pathway at ENC is an evolving site tailored to the needs of mathematics, science, and technology educators. On the site, ENC offers a middle school view into excellent online materials from the National Science Digital Library (NSDL). In this first phase of the project, teachers can examine three electronic publications in which content specialists spotlight superior digital resources and offer teaching tips for important topics.");
		addField(document, DCT_MEDIATOR, "0 ~^ Teachers");
		addField(document, DCT_EDLEVEL_NSDL_EDLEVEL, "Middle School ~^ 0");
		addField(
				document,
				COMPOUND_GENRE,
				"0 ~^ Event text/html video/realvideo Activity ~^ Reference ~^ Curriculum support ~^ Lesson or Activity");
		addField(document, COMPOUND_AUDIENCE,
				"0 ~^ Learner ~^ Teacher Teachers Middle School");
		addField(document, COMPOUND_AGENT,
				"0 ~^ NASA Ames Educational Technology Team Donald James");
		addField(document, COMPOUND_TITLE,
				"0 ~^ NASA Quest Middle School Pathway at ENC");
		addField(
				document,
				COMPOUND_DESCRIPTION,
				"0 ~^ NASA Quest is dedicated to bringing NASA people and science to classrooms through the internet. NASA Quest is a resource for educators and kids interested in meeting and learning about NASA people and space science. ~^ Check out this site for activities related to NASA's science and engineering projects . Topics range from solving air traffic control problems to designing a new planet, and there's something for inquisitive minds of all ages. Also, every week you can read a bio of a NASA worker. The NSDL Middle School Pathway at ENC is an evolving site tailored to the needs of mathematics, science, and technology educators. On the site, ENC offers a middle school view into excellent online materials from the National Science Digital Library (NSDL). In this first phase of the project, teachers can examine three electronic publications in which content specialists spotlight superior digital resources and offer teaching tips for important topics.");
		addField(document, METADATA_SOURCE,
				"oai:nsdl.org:2200-20061002193307574T ~^ 1 ~^ http://quest.arc.nasa.gov/");
		addField(
				document,
				DC_SUBJECT,
				"1 ~^ Science - Space/Astronomy ~^ Kindergarten ~^ Early Elementary ~^ Later Elementary ~^ Middle School ~^ High School ~^ space sciences ~^ astronomy ~^ space exploration ~^ solar system");
		addField(
				document,
				DC_DESCRIPTION,
				"1 ~^ This site \"brings NASA people and science to K-12 classrooms via the Internet.\" The site includes chat opportunities, live broadcasts, and video series. The site provides a schedule of events with appropriate grade levels indicated and suggested classroom activities.");
		addField(document, DC_CREATOR,
				"1 ~^ National Aeronautics and Space Administration (NASA)");
		addField(
				document,
				DC_RIGHTS,
				"1 ~^ Metadata may be used without restrictions as long as the oai identifier remains attached to it.");
		addField(document, DC_TITLE, "1 ~^ NASA Quest");
		addField(
				document,
				DC_TYPE,
				"1 ~^ Lesson/activity plans ~^ Student Email interaction (includes Keypals, Ask an Expert services) ~^ Video");
		addField(document, IN_COLLECTION, "oai:nsdl.org:crs:4708 ~^ 1");
		addField(document, COLL_IMAGE_URL,
				"1 ~^ http://crs.nsdl.org/brands/merit.jpg");
		addField(document, COLL_IMAGE_WIDTH, "1 ~^ 100");
		addField(document, COLL_IMAGE_HEIGHT, "1 ~^ 35");
		addField(document, COLL_IMAGE_ALT_TEXT, "1 ~^ Michigan Teacher Network");
		addField(document, DC_TITLE, "1 ~^ Michigan Teacher Network");
		addField(
				document,
				DC_DESCRIPTION,
				"1 ~^ Michigan Teacher Network supports Michigan K-12 educators in the successful use of technology by providing best practice, professional development, and evaluated curriculum resources. Curriculum materials are correlated to Michigan Curriculum Framework content standards.");
		addField(document, DCT_AUDIENCE, "1 ~^ Teachers");
		addField(document, DCT_MEDIATOR, "1 ~^ Teachers");
		addField(document, DCT_EDLEVEL_NSDL_EDLEVEL, "Grades Pre-K to 12 ~^ 1");
		addField(
				document,
				COMPOUND_GENRE,
				"1 ~^ Lesson/activity plans ~^ Student Email interaction (includes Keypals, Ask an Expert services) ~^ Video");
		addField(
				document,
				COMPOUND_SUBJECT,
				"1 ~^ Science - Space/Astronomy ~^ Kindergarten ~^ Early Elementary ~^ Later Elementary ~^ Middle School ~^ High School ~^ space sciences ~^ astronomy ~^ space exploration ~^ solar system");
		addField(document, COMPOUND_AUDIENCE,
				"1 ~^ Teachers Teachers Grades Pre-K to 12");
		addField(document, COMPOUND_AGENT,
				"1 ~^ National Aeronautics and Space Administration (NASA)");
		addField(document, COMPOUND_TITLE,
				"1 ~^ NASA Quest Michigan Teacher Network");
		addField(
				document,
				COMPOUND_DESCRIPTION,
				"1 ~^ This site \"brings NASA people and science to K-12 classrooms via the Internet.\" The site includes chat opportunities, live broadcasts, and video series. The site provides a schedule of events with appropriate grade levels indicated and suggested classroom activities. Michigan Teacher Network supports Michigan K-12 educators in the successful use of technology by providing best practice, professional development, and evaluated curriculum resources. Curriculum materials are correlated to Michigan Curriculum Framework content standards.");

		NQ_2_METADATAS = document;
	}

	private static void addField(Document document, LuceneFieldSpec spec,
			String value) {
		document.add(assembleField(spec, value));
	}

	private static Field assembleField(LuceneFieldSpec spec, String value) {
		return new Field(spec.getName(), value, spec.getStore(), spec
				.getIndex());
	}

	private ExpectedIndexedDocuments() {
		// nothing to instantiate.
	}
}
