/*
 * -----------------------------------------------------------------------------
 *
 * License and Copyright: 
 *
 * The contents of this file are subject to the Educational Community License 
 * (the "License"); you may not use this file except in compliance with the 
 * License. You may obtain a copy of the License at 
 * http://www.opensource.org/licenses/ecl1.txt.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The entire file consists of original code.  Copyright &copy; 2002-2008 by 
 * The Rector and Visitors of Cornell University. All rights reserved.
 *
 * -----------------------------------------------------------------------------
 */

package samples;

import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DCT_AUDIENCE_NSDL_EDLEVEL;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.*;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DC_DESCRIPTION;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DC_FORMAT_IMT;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DC_SUBJECT;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DC_SUBJECT_LCSH;
import static org.nsdl.search.lucene.SearchIndexFieldSpecs.DC_TITLE;

import java.lang.reflect.Field;
import java.util.Date;

import org.nsdl.search.lucene.searchdoc.SearchDocument;
import org.nsdl.search.lucene.searchdoc.SearchDocumentMetadata;
import org.nsdl.search.processoai.OaiCollectionInfo;
import org.nsdl.searchtools.common.DateUtil;

/**
 * Some {@link SearchDocument}s to use in the unit tests.
 * 
 * @author jblake
 */
public class SampleSearchDocuments {
	/**
	 * A document with one metadata record.
	 */
	public static SearchDocument getFrogExploratoriumDocument() {
		SearchDocumentMetadata md1 = new SearchDocumentMetadata(
				"oai:nsdl.org:2200-20061005112122039T",
				"http://www.exploratorium.edu/frogs");
		// <datestamp>2007-01-14T07:27:02Z</datestamp>
		md1.addFieldValue(DC_TITLE, "Exploratorium: Frogs");
		md1.addFieldValue(DC_SUBJECT, "Adaptable frog");
		md1.addFieldValue(DC_SUBJECT, "Amphibians");
		md1.addFieldValue(DC_SUBJECT, "Deformed frogs");
		md1.addFieldValue(DC_SUBJECT, "Endangered");
		md1.addFieldValue(DC_SUBJECT, "Exploratorium");
		md1.addFieldValue(DC_SUBJECT, "Frogs");
		md1.addFieldValue(DC_SUBJECT, "Frogs and toads");
		md1.addFieldValue(DC_SUBJECT, "Frogs exhibition");
		md1.addFieldValue(DC_SUBJECT, "Frogs frogs");
		md1.addFieldValue(DC_SUBJECT, "Rain forest");
		md1.addFieldValue(DC_DESCRIPTION, "Frogs @ The Exploratorium: "
				+ "An online exhibition exploring the amazing, "
				+ "adaptable frog.");
		md1.setCollInfo(new OaiCollectionInfo("oai:nsdl.org:crs:496444",
				"http://crs.nsdl.org/brands/496444.jpg", "100", "30",
				"New Scientist Web Links: Current picks"));

		SearchDocument doc = new SearchDocument(
				"http://www.exploratorium.edu/frogs");
		doc.addMetadataSource(md1);
		setDocumentLastUpdated(doc, DateUtil.getInstance().now());
		return doc;
	}

	/**
	 * A document with two metadata records.
	 */
	public static SearchDocument getFrogDissectionDocument() {
		SearchDocumentMetadata md1 = new SearchDocumentMetadata(
				"oai:nsdl.org:2200-20061002165020337T",
				"http://www-itg.lbl.gov/vfrog");
		// <datestamp>2007-01-13T18:46:49Z</datestamp>
		md1.addFieldValue(DC_TITLE, "Virtual Frog Dissection Kit");
		md1.addFieldValue(DC_SUBJECT, "Animations");
		md1.addFieldValue(DC_SUBJECT, "CAI");
		md1.addFieldValue(DC_SUBJECT, "COMPUTER-ASSISTED INSTRUCTION");
		md1.addFieldValue(DC_SUBJECT, "DISSECTION");
		md1.addFieldValue(DC_SUBJECT, "FROGS");
		md1.addFieldValue(DC_SUBJECT, "Images");
		md1.addFieldValue(DC_SUBJECT, "K-12");
		md1.addFieldValue(DC_SUBJECT, "Photographs");
		md1.addFieldValue(DC_SUBJECT, "Photos");
		md1.addFieldValue(DC_SUBJECT, "Pictorial works");
		md1.addFieldValue(DC_SUBJECT, "SECONDARY");
		md1.addFieldValue(DC_SUBJECT, "Secondary education");
		md1.addFieldValue(DC_SUBJECT, "Web");
		md1.addFieldValue(DC_SUBJECT_LCSH, "Anatomy");
		md1.addFieldValue(DC_SUBJECT_LCSH, "DISSECTION -- LABORATORY MANUALS");
		md1.addFieldValue(DC_SUBJECT_LCSH, "FROGS -- ANATOMY");
		md1.addFieldValue(DC_SUBJECT_LCSH, "FROGS -- PHYSIOLOGY");
		md1.addFieldValue(DC_DESCRIPTION, "Dissect a virtual frog.");
		md1.setCollInfo(new OaiCollectionInfo("oai:nsdl.org:crs:367822",
				"http://crs.nsdl.org/brands/367822.jpg", "100", "20",
				"INFOMINE: Scholarly Internet Resource Collections"));

		SearchDocumentMetadata md2 = new SearchDocumentMetadata(
				"oai:nsdl.org:2200-20061005112146167T",
				"http://www-itg.lbl.gov/vfrog");
		// <datestamp>2007-01-14T07:27:08Z</datestamp>
		md2.addFieldValue(DC_TITLE, "Virtual Frog Dissection Kit Version 2.0");
		md2.addFieldValue(DC_SUBJECT, "Dissection kit version virtual frog");
		md2.addFieldValue(DC_SUBJECT, "Frog dissection");
		md2.addFieldValue(DC_SUBJECT, "Frog dissection K-12 education");
		md2.addFieldValue(DC_SUBJECT, "Frog dissection kit version virtual");
		md2.addFieldValue(DC_SUBJECT, "Home page");
		md2.addFieldValue(DC_SUBJECT, "Kit version virtual frog dissection");
		md2.addFieldValue(DC_SUBJECT, "Version virtual frog dissection kit");
		md2.addFieldValue(DC_SUBJECT, "Virtual frog");
		md2.addFieldValue(DC_SUBJECT, "Virtual frog dissection kit");
		md2.addFieldValue(DC_SUBJECT, "Virtual frog dissection kit version");
		md2.addFieldValue(DC_DESCRIPTION, "Virtual Frog Dissection Kit This "
				+ "award-winning interactive program is part of the \""
				+ "Whole Frog\" project. You can interactively dissect a "
				+ "(digitized) frog named Fluffy, make movies, and play the "
				+ "Virtual Frog Builder Game. The interactive Web pages are "
				+ "available in a number of languages.");
		md2.setCollInfo(new OaiCollectionInfo("oai:nsdl.org:crs:496435",
				"http://crs.nsdl.org/brands/496435.jpg", "100", "30",
				"SCORE Science - Kids Corner"));

		SearchDocument doc = new SearchDocument("http://www-itg.lbl.gov/vfrog");
		doc.addMetadataSource(md1);
		doc.addMetadataSource(md2);
		setDocumentLastUpdated(doc, DateUtil.getInstance().now());

		return doc;
	}

	/**
	 * A document with a funky resource identifier. Contains a sequence that
	 * looks like an encoding. Make sure that it is not decoded on the way out.
	 */
	public static SearchDocument getFunkyUriDocument() {
		SearchDocumentMetadata md1 = new SearchDocumentMetadata(
				"oai:nsdl.org:2200-20080723200543805T",
				"http://dx.doi.org/10.1663/0013-0001(2002)056%5B0303:BMMIET%5D2.0.CO;2");
		// <datestamp>2007-01-14T07:27:02Z</datestamp>
		md1.addFieldValue(DC_CREATOR, "Jenny McCune");
		md1.addFieldValue(DC_CREATOR, "Hew D. V. Prendergast");
		md1.addFieldValue(DC_FORMAT_IMT, "application/pdf");
		md1
				.addFieldValue(
						DC_TITLE,
						"Betula makes music in Europe: Three birch horns from Kew?s economic botany collections");
		md1.addFieldValue(DCT_AUDIENCE_NSDL_EDLEVEL, "Graduate");
		md1.addFieldValue(DC_SUBJECT, "Life Sciences");
		md1.addFieldValue(DC_SUBJECT, "Plant Sciences");
		md1
				.addFieldValue(DC_SUBJECT,
						"Plant Systematics/Taxonomy/Biogeography");
		md1.addFieldValue(DC_SUBJECT, "Plant Anatomy/Development");
		md1.addFieldValue(DC_SUBJECT, "Plant Physiology");
		md1.setCollInfo(new OaiCollectionInfo("oai:nsdl.org:crs:2577221",
				"http://nsdl.org/images/brands/2577221.jpg", "100", "35",
				"SpringerLink Online Journals"));

		SearchDocument doc = new SearchDocument(
				"http://dx.doi.org/10.1663/0013-0001(2002)056%5B0303:BMMIET%5D2.0.CO;2");
		doc.addMetadataSource(md1);
		setDocumentLastUpdated(doc, DateUtil.getInstance().now());
		return doc;
	}

	/**
	 * A document with a funky resource identifier. Contains special characters.
	 * Make sure that they are not encoded on the way out.
	 */
	public static SearchDocument getFunkyUriDocument2() {
		String url = "http://www.informaworld.com/openurl?genre=article"
				+ "&doi=10.1080/00016350601137236"
				+ "&magic=nsdl||04EC22774EDFF581DEDB03A88EF4BB8E";
		SearchDocumentMetadata md1 = new SearchDocumentMetadata(
				"oai:nsdl.org:2200-20080619200524060T", url);
		// <datestamp>2007-01-14T07:27:02Z</datestamp>
		md1.addFieldValue(DC_DESCRIPTION, "Objective. To evaluate the...");
		md1.addFieldValue(DCT_IS_PART_OF, "urn:ISSN:0001-6357");
		md1.addFieldValue(DCT_IS_PART_OF, "urn:EISSN:1502-3850");
		md1.addFieldValue(DC_LANGUAGE_RFC3066, "EN");
		md1.addFieldValue(DC_CREATOR, "Fumitake Tsue");
		md1.addFieldValue(DC_CREATOR, "Yutaka Takahashi");
		md1.addFieldValue(DC_CREATOR, "Hiroshi Shimizu");
		md1.addFieldValue(DC_TITLE, "Reinforcing effect of "
				+ "glass-fiber-reinforced composite on flexural "
				+ "strength at the proportional limit of denture "
				+ "base resin");
		md1.addFieldValue(DC_SUBJECT, "Denture base resin");
		md1.addFieldValue(DC_SUBJECT, "fiber-reinforced composites");
		md1.addFieldValue(DC_SUBJECT,
				"flexural strengths at proportional limit");
		md1.addFieldValue(DC_SUBJECT, "reinforcing effect");
		md1.addFieldValue(DC_SUBJECT, "reinforcing efficiency");
		md1.addFieldValue(DCT_AUDIENCE_NSDL_EDLEVEL, "Graduate");
		md1.addFieldValue(DCT_BIBLIOGRAPHIC_CITATION,
				"Acta Odontologica Scandinavica 65(3), 141-148. (2007)");
		md1.addFieldValue(DC_PUBLISHER, "Informa Healthcare");
		md1.addFieldValue(DCT_ISSUED_W3CDTF, "2007");
		md1.addFieldValue(DC_TYPE_DCMITYPE, "Text");

		md1
				.setCollInfo(new OaiCollectionInfo(
						"oai:nsdl.org:ncs:NSDL-COLLECTION-000-003-111-950",
						"http://nsdl.org/images/brands/NSDL-COLLECTION-000-003-111-950.jpg",
						"100", "30", "Taylor and Francis Group"));

		SearchDocument doc = new SearchDocument(url);
		doc.addMetadataSource(md1);
		setDocumentLastUpdated(doc, DateUtil.getInstance().now());
		return doc;
	}

	private static void setDocumentLastUpdated(SearchDocument doc, Date date) {
		try {
			Field dluField = SearchDocument.class
					.getDeclaredField("documentLastUpdated");
			dluField.setAccessible(true);
			dluField.set(doc, date);
		} catch (SecurityException e) {
			throw new RuntimeException("Failed to set 'documentLastUpdated'", e);
		} catch (NoSuchFieldException e) {
			throw new RuntimeException("Failed to set 'documentLastUpdated'", e);
		} catch (IllegalArgumentException e) {
			throw new RuntimeException("Failed to set 'documentLastUpdated'", e);
		} catch (IllegalAccessException e) {
			throw new RuntimeException("Failed to set 'documentLastUpdated'", e);
		}
	}

	private SampleSearchDocuments() {
		// Nothing here to instantiate.
	}

}
